import Article from "@/components/Article";

const ArticleArthritisAndExercise = () => {
  return (
    <Article
      title="Arthritis and Exercise"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        In the 1980’s the idea of including exercise as part of a treatment plan
        was seen as a radical approach to the management of arthritis.
      </p>
      <p>
        Marion Minor, PhD, thought otherwise. In 1989 she conducted a study with
        120 arthritic patients with osteoarthritis and rheumatoid arthritis. The
        patients were randomly assigned to aerobic walking, aerobic aquatics, or
        to a control group of nonaerobic range of motion exercises. The duration
        of the study was for 12 weeks.
      </p>
      <p>
        The results showed that the aquatics and walking exercise groups showed
        significant improvement over the control group in their capacitiy to do
        aerobics, 50-foot walking time, depression, anxiety, and physical
        activity after the 12-week program.
      </p>
      <p>
        “Participants said that they were gaining back control on their lives,
        and not subject to the whim of the disease,” Minor said. “This provides
        a good prototype for self-management and problem-solving, the types of
        things that can further improve the condition of people with arthritis.”
        (1)
      </p>
      <p>
        Around the same time in Denmark researchers were also looking into
        physical training as a way of helping rheumatoid arthritis patients.
        They looked at a graduated exercises going from 2 times per week of
        aerobics and strengthening exercises to eventually progressing to
        strenuous exercises over an 8-week period.
      </p>
      <p>
        The results were encouraging in this study also. The patients had
        significantly fewer swollen joints than before. Exercising the muscles
        of the swollen joints resulted in more than a 35% decrease in the number
        of swollen joints. (2) The Denmark study showed that improving muscle
        strength also improved the affected joint. This was further confirmed in
        other studies.
      </p>
      <p>
        One particular study looked at the effect of strengthening the knee
        muscles of patients with arthritis of the knee joint. In this trial 20
        volunteers with knee joint arthritis were randomly assigned to a
        treatment group (10 people) or to a control group (10 people). The
        treatment group completed six sets of five strong contractions three
        times per week for a period of 8 weeks.
      </p>
      <p>
        At the end of the study the treatment group as compared to the control
        group showed a a significant decrease in pain and stiffness and a
        significant increase in the ability to move. There was also a
        significant decline in the Osteoarthritis Screening Index and the
        Arthritis Impact Measurement Scale. (3)
      </p>
      <p>
        Other areas of exercise therapy for arthritis have also been
        investigated. One such area was to determine whether high or low
        intensity exercises were more effective.
      </p>
      <p>
        100 patients with moderately severe rheumatoid arthritis were randomly
        assigned to (a) intensive group exercises that included full weight
        bearing and also conditioning exercises on a stationary bike; (b) range
        of motion exercises and isometric exercises group; (c) individual
        isometric and range of motion; and (d) home instructions for isometric
        and range of motion exercises. The study ran for 12 weeks.
      </p>
      <p>
        There was about a 17% increase in aerobic capacity strength and joint
        mobility in the high intensity exercise as compared to the other
        exercise groups. When the patients stopped their exercise training
        whatever gains they had achieved in physical capacity disappeared.(4)
      </p>
      <p>
        In a study published in the Journal of the American Medical Association
        researchers looked at whether a structured exercise program would help
        older people with arthritis of the knee. 439 adults, aged 60 or older,
        took part in either an aerobic exercise program, a resistance exercise
        program, and a health education program. 83% of the people completed the
        18 month study.
      </p>
      <p>
        The results showed that the aerobic exercise group had 10% lower scores
        on the physical disability questionnaire, a 12% lower score on the knee
        pain questionnaire, improved performance on the 6-minute walk test, and
        also had improved the time it took to carry 10 pounds as compared to the
        health education group. The resistance exercise group also showed
        improvements but not as good as the aerobic exercise group. (5)
      </p>
      <p>
        Even though exercise is now considered standard treatment for arthritis
        it is not widely prescribed. In a study involving 110 elderly persons
        with chronic hip and knee pain, fewer than half had received the medical
        advice to exercise. Arthritis specialists did much better in prescribing
        exercise than the primary care physician. Further, those patients who
        were told to exercise by their physician were making an attempt to do so
        but only 10% were doing the exercises in a way that would be
        therapeutic. (6)
      </p>
      <p>
        <strong>References:</strong>
      </p>
      <p>
        (1) Efficacy of physical conditioning exercise in patients with
        rheumatoid arthritis and osteoarthritis. Minor MA, Hewett JE, Webel RR,
        Anderson SK, Kay DR. Arthritis Rheum 1989 Nov;32(11):1396-1405
      </p>
      <p>
        (2) The effect of physical training on patients with rheumatoid
        arthritis: changes in disease activity, muscle strength and aerobic
        capacity. A clinically controlled minimized cross-over study. Lyngberg
        K, Danneskiold-Samsoe B, Halskov O. Clin Exp Rheumatol 1988
        Jul;6(3):253-260
      </p>
      <p>
        (3) Effects of muscle-strength training on the functional status of
        patients with osteoarthritis of the knee joint. Schilke JM, Johnson GO,
        Housh TJ, O’Dell JR. Nurs Res 1996 Mar;45(2):68-72
      </p>
      <p>
        (4) Comparison of high and low intensity training in well controlled
        rheumatoid arthritis. Results of a randomised clinical trial. van den
        Ende CH, Hazes JM, le Cessie S, Mulder WJ, Belfor DG, Breedveld FC,
        Dijkmans BA. Ann Rheum Dis 1996 Nov;55(11):798-805
      </p>
      <p>
        (5) A randomized trial comparing aerobic exercise and resistance
        exercise with a health education program in older adults with knee
        osteoarthritis. The Fitness Arthritis and Seniors Trial. Ettinger WH Jr,
        Burns R, Messier SP, Applegate W, Rejeski WJ, Morgan T, Shumaker S,
        Berry MJ, O’Toole M, Monu J, Craven T. JAMA 1997 Jan 1;277(1):25-31
      </p>
      <p>
        (6) Joint exercises in elderly persons with symptomatic osteoarthritis
        of the hip or knee. Performance patterns, medical support patterns, and
        the relationship between exercising and medical care. Dexter PA.
        Arthritis Care Res 1992 Mar;5(1):36-41
      </p>
    </Article>
  );
};

export default ArticleArthritisAndExercise;
