import Article from "@/components/Article";
import fiveElements from "@/public/content/acupuncture_elements.png";
import Image from "next/image";

const ArticleFiveElementAcupuncture = () => {
  return (
    <Article
      title="Five Element Acupuncture"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        Five element acupuncture has been part of Chinese medicine since the
        10th century BC. The concepts first appeared in several books on
        philosophy such as Shu Ching and the Li Chi and the Guan Dzu. The first
        medical writings were found in 200 BC by the Nei Chin Su Wen. It was
        later discussed by Shu Nan Ching. Five element concepts are not only of
        medical theory but an integral aspect of all Chinese cosmetology and
        philosophy.
      </p>
      <p>
        The five element system divides the healing experience into five
        distinct groupings called elements. The five elements include wood,
        which relates to the liver and gall bladder; fire, which relates to the
        heart, small intestine, triple heater, and master of the
        heart/pericardium; earth, which relates to the spleen and stomach; metal
        which relates to the lung and colon; water, which relates to the kidney
        and bladder.
      </p>
      <p>
        The levels of function range from biochemical processes to the function
        of the organism as a whole. This includes behavior, psychological state,
        relationships, career choices, and the like. The diagnosis of the five
        elements in a clinical setting is done through the use of a system of
        correspondences. Each element has a series of correspondence involving
        the macrocosm, the season, the time of day, the climatic condition, the
        microcosm, the taste in food, the emotional state, their color, body
        odor, body orifice, sense organ, body tissue, and the corresponding
        organ system.
      </p>
      <p>
        The Nei Chin Su Wen describes the macro to microcosm of the wood element
        as such:
      </p>
      <p>
        <em>
          The east creates the wind, the wind creates the wood, the wood creates
          the sour flavor, the sour flavor strengthens the liver, the liver
          nourishes the muscles, the liver governs the eyes, they eyes see the
          darkness and the mystery of heaven and they discover the tao, the
          right way among mankind.
        </em>
      </p>
      <h2>Section A | Correspondences</h2>
      <p>
        Each element has associated pathological conditions. These pathological
        conditions can reflect a dysfunction in a specific element but they do
        not identify the acupuncture diagnosis necessarily.
      </p>
      <ul>
        <li>
          <strong>Wood</strong> has the following diagnostic symptoms and
          pathology: headaches, migraines, conjunctivitis, myofascial pain,
          ligament injuries, sexual dysfunction, paraplegia, gall bladder
          disease, liver disease, fatigue, insomnia, hypoglycemia
        </li>
        <li>
          <strong>Fire </strong>has the following diagnostic symptoms and
          pathology: insomnia, hearing problems, Belle’s Palsy, trigeminal
          neuralgia, cerebral vascular accidents, anemias, fatigue, sexual
          dysfunction.
        </li>
        <li>
          <strong>Earth</strong> has the following diagnostic symptoms and
          pathology: gynecological disease and dysfunction, headaches, irritable
          bowel syndrome, gastritis, sinusitis, eating disorders.
        </li>
        <li>
          <strong>Metal</strong> has the following diagnostic symptoms and
          pathology: asthma, colitis, allergic rhinitis, and eczema.
        </li>
        <li>
          <strong>Water</strong> as the following diagnostic symptoms and
          pathology: hypertension, gastritis, hearing disorders, spinal
          disorders, cystitis and low back disorders.
        </li>
      </ul>
      <p>
        Further correspondences with five elements include the emotional state,
        which is of great clinical usefulness when assessing the elements.
      </p>
      <p>The abnormal emotional aspects are as follows:</p>
      <ul>
        <li>
          <strong>Wood </strong>is frustration, anxiety, and anger
        </li>
        <li>
          <strong>Fire</strong> is the lack of or excessive joy
        </li>
        <li>
          <strong>Earth</strong> is the excessive need for sympathy, excessive
          introspection, and obsessional thinking
        </li>
        <li>
          <strong>Metal </strong>is grief, sadness, and melancholia
        </li>
        <li>
          <strong>Water</strong> is fear
        </li>
      </ul>
      <div className="flex justify-center">
        <Image
          src={fiveElements}
          alt="Diagram of the five elements of acupuncture"
        />
      </div>
      <h2>Section B | Fire</h2>
      <p>
        Within each element there are officials. Officials are described as
        defined not by physical properties but by specific roles in the
        processing, storage, and distribution of vital energy and therefore the
        maintenance of life.
      </p>
      <p>
        In the fire element the organ/official the heart is the supreme
        controller. The fire element the organ/official the small intestine is
        the official and controller of transforming matter, separating the pure
        from the unpure. The fire element the organ/official the pericardium is
        the heart protector and circulation sex official. In fire element the
        organ/official the triple heater is the official of balance and harmony.
      </p>
      <p>
        <strong>Organs: </strong>Heart, Small Intestine, Pericardium, Triple
        Heater
      </p>
      <p>
        <strong>Physical: </strong>Heart and cardiovacular function, autonomic
        nervous system, digestisve function, peripheral circulation
      </p>
      <p>
        <strong>Psychological: </strong>Sorting and separating, boundaries,
        self-expression, joy and happiness, love, warmth, relationships,
        affection, sexuality, excitement, animation, enthusiasm, activity and
        passion
      </p>
      <p>
        <strong>Physical Pathology: </strong>Cardiac disease, circulatory
        disease, arrhythmias, irritable bowel syndrome, small bowel disease,
        insomnia, environmental illness, dysatonomias, fatigue, neck and upper
        back pain
      </p>
      <p>
        <strong>Psychological Pathology: </strong>Relationship difficulties,
        self-protective but wants intimacy, depression and absence of joy,
        dysphoria, unhappiness, anxiety, insomnia, doubt and hesitation,
        confusion and
      </p>
      <table>
        <tbody>
          <tr>
            <td>Color</td>
            <td>Red</td>
          </tr>
          <tr>
            <td>Sound</td>
            <td>Laughter</td>
          </tr>
          <tr>
            <td>Smell</td>
            <td>Scorched</td>
          </tr>
          <tr>
            <td>Emotion</td>
            <td>Joy/Lack of Joy</td>
          </tr>
          <tr>
            <td>Officials</td>
            <td>Heart, Pericardium, S. Intestine, 3 Heaters</td>
          </tr>
          <tr>
            <td>Season</td>
            <td>Summer</td>
          </tr>
          <tr>
            <td>Climate</td>
            <td>Heat</td>
          </tr>
          <tr>
            <td>Directions</td>
            <td>south</td>
          </tr>
          <tr>
            <td>Sense</td>
            <td>Tonge</td>
          </tr>
          <tr>
            <td>Fortifies</td>
            <td>Arteries</td>
          </tr>
          <tr>
            <td>Opening</td>
            <td>Ears</td>
          </tr>
          <tr>
            <td>Manifests</td>
            <td>Complexion</td>
          </tr>
          <tr>
            <td>Taste</td>
            <td>Bitter</td>
          </tr>
          <tr>
            <td>Time</td>
            <td>11 am – 3 pm; 7 pm – 11 pm</td>
          </tr>
        </tbody>
      </table>
      <h2>Section C | Water</h2>
      <p>
        In the water element, the organ official bladder is the controller and
        storage of water and the water element the kidney organ official is the
        controller of water.
      </p>
      <p>
        <strong>Organs</strong>: Kidney, Bladder
      </p>
      <p>
        <strong>Physical</strong>: Bones, teeth, all secretions, endocrine
        system, brain, urinary tract, kidneys, hearing, head hair, DNA,
        procreation
      </p>
      <p>
        <strong>Psychological</strong>: Reserves and resources, trust and faith,
        ability to overcome, will power, self-actualization, intelligence and
        cleverness, capacities, self-preservation, power, survival and
        persistence, setting limits, taking risks
      </p>
      <p>
        <strong>Physical Pathology</strong>: All urinary tract disorders,
        interstitial cystitis, adrenal insufficiency, all pituitary disorders,
        osteoarthritis, rheumatoid arthritis, aging, lumbar and cervical spine,
        most back pain syndromes, hypertension, fatigue, constitutional
        weakness, poor libido
      </p>
      <p>
        <strong>Psychological Pathology</strong>: Mistrust, fear, paranoia,
        overwhelmed, surrenders, lack of faith, lack of reserves, poor flow and
        movement, withdraws and isolates, needs reassurance
      </p>
      <p>
        <strong>Water Element Correspondences</strong>
      </p>
      <table>
        <tbody>
          <tr>
            <td>Color</td>
            <td>Blue</td>
          </tr>
          <tr>
            <td>Sound</td>
            <td>Groaning</td>
          </tr>
          <tr>
            <td>Smell</td>
            <td>Putrid</td>
          </tr>
          <tr>
            <td>Emotion</td>
            <td>Fear</td>
          </tr>
          <tr>
            <td>Officials</td>
            <td>Kidneys, Bladder</td>
          </tr>
          <tr>
            <td>Season</td>
            <td>Winter</td>
          </tr>
          <tr>
            <td>Climate</td>
            <td>Cold</td>
          </tr>
          <tr>
            <td>Directions</td>
            <td>North</td>
          </tr>
          <tr>
            <td>Sense</td>
            <td>Ears</td>
          </tr>
          <tr>
            <td>Fortifies</td>
            <td>Bones</td>
          </tr>
          <tr>
            <td>Opening</td>
            <td>Anus, Urethra</td>
          </tr>
          <tr>
            <td>Manifests</td>
            <td>Head Hair</td>
          </tr>
          <tr>
            <td>Taste</td>
            <td>Salty</td>
          </tr>
          <tr>
            <td>Time</td>
            <td>3 pm – 7 pm</td>
          </tr>
        </tbody>
      </table>
      <h2>Section D | Wood</h2>
      <p>
        In the wood element the organ/official the gall bladder is the official
        of decision-making and wise judgment. In the wood element the
        organ/official the liver is the controller of planning.
      </p>
      <p>
        <strong>Organs: </strong>Gall Bladder, Liver
      </p>
      <p>
        <strong>Physical: </strong>Muscles and tendons, eyes and visual system,
        biliary tract
      </p>
      <p>
        <strong>Psychological: </strong>Planning, organization, decisions,
        direction, coordination, transformation and change, emotional
        expression, flexibility
      </p>
      <p>
        <strong>Physical Pathology: </strong>Migraine, headaches, fibromyalgia,
        musculoskeletal problems, PMS, biliary disease, digestive disorders, eye
        diseases
      </p>
      <p>
        <strong>Psychological Pathology: </strong>Anger, anxiety, insomnia,
        indecision and paralysis, drug abuse, need for control, frustration,
        needs to challenge
      </p>
      <p>
        <strong>Wood Element Correspondences</strong>
      </p>
      <table>
        <tbody>
          <tr>
            <td>Color</td>
            <td>Green</td>
          </tr>
          <tr>
            <td>Sound</td>
            <td>Shouting</td>
          </tr>
          <tr>
            <td>Smell</td>
            <td>Rancid</td>
          </tr>
          <tr>
            <td>Emotion</td>
            <td>Anger</td>
          </tr>
          <tr>
            <td>Officials</td>
            <td>Liver, Gall Bladder</td>
          </tr>
          <tr>
            <td>Season</td>
            <td>Spring</td>
          </tr>
          <tr>
            <td>Climate</td>
            <td>Windy</td>
          </tr>
          <tr>
            <td>Directions</td>
            <td>East</td>
          </tr>
          <tr>
            <td>Sense</td>
            <td>Eyes</td>
          </tr>
          <tr>
            <td>Fortifies</td>
            <td>Nails</td>
          </tr>
          <tr>
            <td>Opening</td>
            <td>Eyes</td>
          </tr>
          <tr>
            <td>Manifests</td>
            <td>Nails</td>
          </tr>
          <tr>
            <td>Taste</td>
            <td>Sour</td>
          </tr>
          <tr>
            <td>Time</td>
            <td>11 pm – 3 am</td>
          </tr>
        </tbody>
      </table>
      <h2>Section E | Metal</h2>
      <p>
        In the metal element the organ/official the lung is the controller of
        receiving pure chi from the heavens. In the metal element the
        organ/official the colon is the controller of drainage and drags.
      </p>
      <p>
        <strong>Organs: </strong>Lungs, Large Intestine
      </p>
      <p>
        <strong>Physical: </strong>Skin, nose, resistance to infections,
        perspiration, circadian rhythms
      </p>
      <p>
        <strong>Psychological: </strong>Resilience, strength, endurance,
        self-worth, capacity to grieve, elimination and letting go, inspiration,
        values, spirituality, father, meaningfulness, purpose
      </p>
      <p>
        <strong>Physical Pathology: </strong>Asthma, bronchitis, recurrent
        respiratory infections, all lung disorders, rhinitis, ulcerativve
        colitis, diarrhea, constipation, eczema and all skin disorders, poor
        endurance and fatigue
      </p>
      <p>
        <strong>Psychological Pathology: </strong>Perfectionist, withdrawn and
        cut off, needs companionship, cruel, wants revenge, lacks inspiration,
        regrets, rigid, grief, depression, inflexible
      </p>
      <p>
        <strong>Metal Element Correspondences</strong>
      </p>
      <table>
        <tbody>
          <tr>
            <td>Color</td>
            <td>White</td>
          </tr>
          <tr>
            <td>Sound</td>
            <td>Weeping</td>
          </tr>
          <tr>
            <td>Smell</td>
            <td>Rotten</td>
          </tr>
          <tr>
            <td>Emotion</td>
            <td>Greif</td>
          </tr>
          <tr>
            <td>Officials</td>
            <td>Lungs, Large Intestine</td>
          </tr>
          <tr>
            <td>Season</td>
            <td>Autumn</td>
          </tr>
          <tr>
            <td>Climate</td>
            <td>Dryness</td>
          </tr>
          <tr>
            <td>Directions</td>
            <td>West</td>
          </tr>
          <tr>
            <td>Sense</td>
            <td>Nose</td>
          </tr>
          <tr>
            <td>Fortifies</td>
            <td>Skin</td>
          </tr>
          <tr>
            <td>Opening</td>
            <td>Nose</td>
          </tr>
          <tr>
            <td>Manifests</td>
            <td>Body Hair</td>
          </tr>
          <tr>
            <td>Taste</td>
            <td>Pungent, Acrid</td>
          </tr>
          <tr>
            <td>Time</td>
            <td>3 am – 7 am</td>
          </tr>
        </tbody>
      </table>
      <h2>Section F | Earth</h2>
      <p>
        In the earth element the organ/offical the stomach is the controller of
        rottening and ripening. The earth element organ/official the spleen is
        the controller of transport.
      </p>
      <p>
        <strong>Organs: </strong>Spleen, Stomach
      </p>
      <p>
        <strong>Physical: </strong>Upper digestive tract, blood formation,
        immune system, metabolism of food, gynecological function, fertility,
        mouth, sinuses, subcutaneous tissue
      </p>
      <p>
        <strong>Psychological: </strong>Nourishment, contentment, stability,
        security, mothering, centerdness, fulfillment, groundedness, empathy and
        caring
      </p>
      <p>
        <strong>Physical Pathology: </strong>Sinusitis, frontal headaches, all
        gynecological problems, infertility, fluid retention, fatigue, diabetes,
        hypoglycemia, ulcer disease, functional dyspepsia, malabsorption,
        obesity, malnourished
      </p>
      <p>
        <strong>Psychological Pathology: </strong>Eating disorders, selfishness,
        obsessive compulsive disorders, opinionated, stubborn, insecure, craves
        attention and understanding, excessive worry, feels deprived
      </p>
      <p>
        <strong>Earth Element Correspondences</strong>
      </p>
      <table>
        <tbody>
          <tr>
            <td>Color</td>
            <td>Yellow</td>
          </tr>
          <tr>
            <td>Sound</td>
            <td>Singing</td>
          </tr>
          <tr>
            <td>Smell</td>
            <td>Fragrant</td>
          </tr>
          <tr>
            <td>Emotion</td>
            <td>Sympathy</td>
          </tr>
          <tr>
            <td>Officials</td>
            <td>Spleen, Stomach</td>
          </tr>
          <tr>
            <td>Season</td>
            <td>Late Summer</td>
          </tr>
          <tr>
            <td>Climate</td>
            <td>Humidity</td>
          </tr>
          <tr>
            <td>Directions</td>
            <td>Center</td>
          </tr>
          <tr>
            <td>Sense</td>
            <td>Mouth</td>
          </tr>
          <tr>
            <td>Fortifies</td>
            <td>Flesh</td>
          </tr>
          <tr>
            <td>Opening</td>
            <td>Mouth</td>
          </tr>
          <tr>
            <td>Manifests</td>
            <td>Lips</td>
          </tr>
          <tr>
            <td>Taste</td>
            <td>Sweet</td>
          </tr>
          <tr>
            <td>Time</td>
            <td>7 am – 11 am</td>
          </tr>
        </tbody>
      </table>
      <h2>Section G | Example</h2>
      <p>
        For example, the gall bladder is responsible for what is exact and just
        and the determinations and decisions stem from that whereas the liver
        holds the office of general assessing circumstances and conceptions of
        plans. If these officials are poorly functioning the effect may be
        indecisiveness, lack of initiative, anger, and frustration or
        hypochondriasis. The ability to make appropriate plans is affected and
        disturbance in the blueprint for functioning on the cellular level such
        as diabetes on a global level such as drug addiction might be the
        outcome. According to the Nei Ching the wood element provides the
        ability to discover the tao, the right way. This allows the person to
        have healthy decision-making, planning, and a balance in
        well-coordinated lifestyle. The wood element is associated with new
        ideas, the spring, the new growth, and the sense of renewal that goes
        with that season. The emotion associated with wood is anger, which is
        generated by the frustration of being blocked in setting out on these
        new paths.
      </p>
      <p>
        The <em>Nei Ching </em>states of wood, “colors they create that bring
        color, and they give to the human voice the ability to form a shouting
        sound, in times of excitement they grant the capacity for control, and
        of the emotions they create anger.”
      </p>
      <p>
        In five element acupuncture, illness occurs when the officials are
        unable to overcome either internal, such as excessive emotions, or
        external, such as injuries, surgery, climatic conditions, or inherited
        perverse energies. What appears to a physician at the onset of a present
        illness is often a combination of a long sequence of energetic
        disturbances in the officials of the elements.
      </p>
      <p>
        A five element acupuncture physician in the physical examination focuses
        on the correspondences available to the patient, facial color, the sound
        of the voice, emotions expressed, the odor of the torso, and the general
        presentation of the person. Importance is made in the traditional pulse
        diagnosis with the emphasis on the individualization of the twelve
        officials. The history is thorough and complete and emphasizes
        chronological events. The goal of the evaluation is to determine the
        official which is the causative factor, that aspect of the energetic
        system which is at the root of the imbalance overall for the patient.
      </p>
      <p>
        The causative factors are either inherited or an acquired condition. If
        acquired it is often the result of childhood experiences that created
        disequilibrium. Traumas from the physical, emotional, infectious, and
        climatic nature will then bring on the causative factor or pathological
        state with the symptoms occurring then.
      </p>
      <h2>Section H | 5-Element Laws</h2>
      <p>
        There are several laws in acupuncture that determines what the
        configuration of what the patient’s symptoms may be. These laws include
        the law of creating that is the shen cycle, the loq of control that is
        the KO cycle, midday and midnight cycle, and mother-child cycle.
      </p>
      <p>
        The shen cycle is best understood in the macrocosmic images of the five
        elements. The wood produces plants and trees that is wood, wood brings
        forth fiver, fire produces ashes that is soil (earht), soil brings forth
        metal, when heated metal produces steam that is water.
      </p>
      <p>
        The controlling cycle, KO cycle, is illustrated as follows: water
        overcomes fire, fire melts the metal, metal in the form of a knife
        overcomes wood, wood as in the form of a spade overcomes soil (earth),
        soil in the form of a dike subdues the water.
      </p>
      <p>
        In illness, for example, of the wood an imbalance of this element would
        cause symptoms to be seen in the wood in the fire through the shen cycle
        or in the earth through the KO cycle.
      </p>
      <p>
        The outer arrows represent the movement of the shen cycle. The inner
        arrows represent the movement of the KO cycle.
      </p>
      <h2>Section I | Conclusion</h2>
      <p>
        J. R. Worsley, an English professor of acupuncture, a leading exponent
        of five element acupuncture came up with the concept that is important
        in today’s medical practice that is the level of illness. The levels
        reflect the depth of the illness within the person physical, mental, or
        spiritual.
      </p>
      <p>
        In our society today there are many people with chronic illnesses on
        what could be called a spiritual level. These patients appear unwilling
        to change, seem empty of purpose or commitment, and create a deep drain
        on the physicians and the medical system. Patients with mental level
        illness are constantly trying to figure out their problems and often are
        obsessed with the needs to understand what is happening. A physical
        level illness actually represents the smallest percentage of the
        patients seen in today’s modern medical practice.
      </p>
      <p>
        Once the causative factors are established, the level of illness is
        understood, the laws of acupuncture are fully comprehended then
        treatment will proceed in a very effective manner.
      </p>
      <p>
        For example, in a case of a wood element for what might be expected to
        be improved is judgment, healthier decision making, less hostility, less
        need for control, clearer vision of future needs. From these changes a
        myriad of physiological and psychological pathologies can improve as the
        wood element returns to normal functioning on all these levels.
      </p>
      <p>
        The improvement and function of one official of an element will lead to
        a dramatic changes in the individuals overall well being. When the
        twelve officials are all in a state of balance then one is well suited
        to deal with the challenges of human control.
      </p>
      <p>
        When a physician is dealing with a complex patient with a multifaceted
        problem, it is a challenge to place the information in context that can
        lead to effective treatment. It is in this aspect that the five element
        acupuncture is most persuasive. The current ideas of spsycho-neural
        immunology are seen within the five element concepts of causative factor
        officials in level of illness. Both physical and emotional symptoms can
        be placed within the diagnostic framework and the most significant of
        all aspects of the five element approach is that it allows us to treat
        the patient/person who has the disease as well as the symptoms
        themselves.
      </p>
    </Article>
  );
};

export default ArticleFiveElementAcupuncture;
