import LearnMoreButton from "@/components/LearnMoreButton";
import View from "@/components/View";
import childInCast from "@/public/content/child_in_cast.jpg";
import childWithCold from "@/public/content/child_with_cold.jpg";
import infant from "@/public/content/infant.jpg";
import sickChild from "@/public/content/sick_child.jpg";
import downSyndrome from "@/public/content/down_syndrome.jpg";
import Image from "next/image";
import Card from "@/components/Card";

const PediatricCare = () => {
  const imageClass = "w-full md:max-w-md rounded-lg drop-shadow-2xl";
  const pClass = "my-8";
  return (
    <View
      bg_color="bg-primary-300"
      txt_color="text-primary-500"
      id="pediatriccare"
    >
      <h1>Pediatrics</h1>
      <div className="grid md:grid-cols-2 place-items-center gap-y-20 my-10">
        <Card>
          <h2>Digestive Problems</h2>
          <p className={pClass}>
            Osteopathic treatment offers a holistic approach to childhood health
            problems. For newborns, misaligned abdominal fascia causing
            digestive issues can be corrected, promoting normal digestion.
            Injuries to the lower back or sacrum can lead to digestive troubles,
            and osteopathic care targets the pelvic diaphragm to restore proper
            function, particularly vital after injuries or surgery. Vague
            complaints like tummy aches and nausea find relief through this
            approach. Osteopathic treatment provides a comprehensive way to
            alleviate childhood digestive and urinary issues, supporting
            healthier development.
          </p>
          <LearnMoreButton href="/articles/pediatric-digestive-problems">
            Keep reading about osteopathy and digestion
          </LearnMoreButton>
        </Card>
        <Image src={sickChild} alt="Sick Child" className={imageClass} />

        <Image
          src={downSyndrome}
          alt="Diagram of down syndrome chromosomes"
          className={imageClass}
        />
        <Card>
          <h2>Down Syndrome</h2>
          <p className={pClass}>
            Osteopathic manipulative treatment (OMT) can benefit individuals
            with Down syndrome by improving body structure and function
            interrelation. Down syndrome, caused by a third copy of chromosome
            21, involves developmental and muscle tone challenges. OMT can
            address structural anomalies contributing to characteristic facial
            features and health complications. OMT can improve sinus and
            respiratory issues, growth delays, and motor skill development by
            addressing cranial shape, neural pathways, and skeletal
            abnormalities.
          </p>
          <LearnMoreButton href="/articles/pediatric-down-syndrome">
            Learn more about OMT and down syndrome
          </LearnMoreButton>
        </Card>

        <Card>
          <h2>Orthopedic Problems</h2>
          <p className={pClass}>
            Childhood orthopedic problems are often seen in the lower
            extremities like feet, legs, knees, and hips. Birth-related stress
            or prolonged growth can lead to various issues. Osteopathic
            manipulative treatment (OMT) can help correct structural problems
            caused by birth complications or other factors. OMT can address
            conditions like congenital hip issues, tibial torsion, gait
            abnormalities, and sports injuries, promoting healthy structural
            growth and preventing long-term problems.
          </p>
          <LearnMoreButton href="/articles/pediatric-orthopedic-problems">
            Discover how OMT can alleviate orthopedic issues
          </LearnMoreButton>
        </Card>
        <Image
          src={childInCast}
          alt="Child with a broken ankle"
          className={imageClass}
        />

        <Image
          src={childWithCold}
          alt="Child with a cold"
          className={imageClass}
        />
        <Card>
          <h2>Respiratory Health</h2>
          <p className={pClass}>
            The common cold is an opportunity for a child's immune system to
            develop, but complications like pneumonia can be problematic.
            Osteopathic manipulative treatment (OMT) can prevent complications
            by addressing lymphatic drainage, muscle tension, and structural
            issues related to respiratory health. OMT can also aid in
            respiratory allergies and asthma by optimizing rib cage and
            diaphragm function, reducing the need for medication and improving
            immune responses.
          </p>
          <LearnMoreButton href="/articles/pediatric-respiratory-health">
            Dive deeper into respitory health and osteopathy
          </LearnMoreButton>
        </Card>

        <Card>
          <h2>Treatment for Newborns</h2>
          <p className={pClass}>
            Osteopathic treatment for newborns aims to correct structural
            stresses caused by the birth process. Birth complications can lead
            to various issues, and osteopathic manipulative treatment (OMT)
            helps babies recover and develop optimally. OMT addresses skull and
            nerve issues caused by birth, helping to resolve irritability,
            developmental delays, and other problems.
          </p>
          <LearnMoreButton href="/articles/pediatric-treatment-for-newborns">
            Learn more about OMT and infants
          </LearnMoreButton>
        </Card>
        <Image src={infant} alt="Infant baby" className={imageClass} />
      </div>
    </View>
  );
};

export default PediatricCare;
