import Article from "@/components/Article";
import ReplaceLink from "@/components/ReplaceLink";
import Link from "next/link";

const ArticleInternationalAcupunctureBibliography = () => {
  return (
    <Article
      title="International Acupuncture Bibliography"
      author="Compiled by Dr. Andre Lentz and Dr. Terry Oleson."
    >
      <Link href="https://auriculotherapy.net" className="italic mb-2 block">
        Visit auriculotherapy.net for more information.
      </Link>
      <h2>Table of Contents</h2>
      <div>
        <div className="font-bold">
          1.0 General Acupuncture and Auriculotherapy
        </div>
        <ul>
          <li>
            <ReplaceLink href="#sec1dot1">
              1.1 General Description and Clinical Textbooks
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec1dot2">
              1.2 Acupuncture History and Theories
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec1dot3">
              1.3 Clinical Observations
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec1dot4">
              1.4 Clinical Techniques and Procedures
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec1dot5">
              1.5 Contraindications, Complications, Adverse Reactions
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec1dot6">
              1.6 General Editorials and Letters to the Editor
            </ReplaceLink>
          </li>
        </ul>
        <div className="font-bold">2.0 Clinical Research Areas</div>
        <ul>
          <li>
            <ReplaceLink href="#sec2dot1">
              2.1 Clinical Research Methods
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec2dot2">
              2.2 Systematic Reviews and Meta-Analyses
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec2dot3">
              2.3 Surveys of Patients and Practitioners, Qualitative Research
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec2dot4">
              2.4 Auricular Diagnosis, Tongue Diagnosis, Oriental Pulse
              Diagnosis
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec2dot5">
              2.5 Auricular Medicine, VAS, RAC, Nogier Phases, Dental Foci
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec2dot6">
              2.6 Acupuncture with Herbal Remedies and Homeopathy
            </ReplaceLink>
          </li>
        </ul>
        <div className="font-bold">3.0 Addiction and Substance Abuse</div>
        <ul>
          <li>
            <ReplaceLink href="#sec3dot1">
              3.1 General Addiction, NADA Protocol
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec3dot2">
              3.2 Alcohol Abuse, Alcoholism, Sedative Abuse
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec3dot3">
              3.3 Opiate Abuse, Heroin, Morphine, Methadone
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec3dot4">
              3.4 Stimulant Abuse, Cocaine, Methamphetamine, Hallucinogens
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec3dot5">
              3.5 Smoking Cessation, Nicotine Addiction
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec3dot6">3.6 Weight Loss, Obesity</ReplaceLink>
          </li>
        </ul>
        <div className="font-bold">4.0 Pain Disorders</div>
        <ul>
          <li>
            <ReplaceLink href="#sec4dot1">
              4.1 General Pain, Myofascial Pain, Fibromyalgia
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec4dot2">
              4.2 Back Pain, Sciatica, Lumbago, Hip, Buttocks
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec4dot3">
              4.3 Migraines, Tension Headaches, Cluster Headaches
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec4dot4">
              4.4 Neck and Shoulder Tension, Cervical Pain, Torticollis,
              Whiplash
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec4dot5">
              4.5 Extremities Pain: Foot, Ankle, Knee, Hand, Wrist, Carpal
              Tunnel
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec4dot6">
              4.6 Arthritis: Osteoarthritis, Rheumatoid Arthritis
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec4dot7">
              4.7 Dental Pain, TMJ Disorder, Toothaches, Gingivitis, Trigeminal
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec4dot8">
              4.8 Analgesia, Anesthesia, Surgery, Post-Operative Pain,
              Post-Operative
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec4dot9">4.9 Burns, Wound Care</ReplaceLink>
          </li>
        </ul>
        <div className="font-bold">6.0 Psychological Disorders</div>
        <ul>
          <li>
            <ReplaceLink href="#sec6dot1">
              6.1 General Psychiatry and Psychology
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec6dot2">
              6.2 Schizophrenia, Psychosis, Hallucinations
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec6dot3">
              6.3 Depression, Mood Disorders
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec6dot4">
              6.4 Insomnia, Anxiety, Stress, Psychosomatic Disorders
            </ReplaceLink>
          </li>
        </ul>
        <div className="font-bold">7.0 Visceral Disorders</div>
        <ul>
          <li>
            <ReplaceLink href="#sec7dot1">
              7.1 Asthma, Bronchitis, Rhinitis, Sinusitis, Coughs, Hiccups
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec7dot2">
              7.2 Cardiovascular Disorders, Coronary Disorders, Angina, Cardiac
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec7dot3">
              7.3 Hypertension, Blood Pressure, Sympathomimetic Vascular Effects
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec7dot4">
              7.4 Gastro-Intestinal, Constipation, Diarrhea, Colitis, Ulcer, IBD
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec7dot5">
              7.5 Liver Disease, Cirrhosis, Bilary Stones, Gall Bladder
              Disorders
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec7dot6">
              7.6 Urological Disorders of Kidney or Bladder, Prostate Problems
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec7dot7">
              7.7 Gynecology, Dysmenorrhea, PMS, Menopause, Pelvic Pain
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec7dot8">
              7.8 Obstetrics, Labor, Pregnancy, Infertility, Impotency, Uterine
            </ReplaceLink>
          </li>
        </ul>
        <div className="font-bold">
          8.0 Endocrine Hormones and Immune Disorders
        </div>
        <ul>
          <li>
            <ReplaceLink href="#sec8dot1">
              8.1 General Endocrinology and Hormones
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec8dot2">
              8.2 Diabetes, Pancreatitis, Hypoglycemia
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec8dot3">
              8.3 Thyroid Disorder, Thyroxine, Adrenal Disorder, ACTH, Cortisol
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec8dot4">
              8.4 Allergies, Immunity, Hypersensitivity, Anti-Inflammatory
              Disoirders
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec8dot5">8.5 Cancer, Oncology</ReplaceLink>
          </li>
        </ul>
        <div className="font-bold">
          9.0 Behavioral and Physiological Research
        </div>
        <ul>
          <li>
            <ReplaceLink href="#sec9dot1">
              9.1 Veterinary Acupuncture and Animal Studies
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec9dot2">
              9.2 Experimental Pain Threshold and Induced Physical Symptoms
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec9dot3">
              9.3 Endorphin Release, Enkephalins, Dynorphins, Naloxone Reversal
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec9dot4">
              9.4 Body Physiology, Biochemistry, Neuroanatomical Studies, Neuron
            </ReplaceLink>
          </li>
          <li>
            <ReplaceLink href="#sec9dot5">
              9.5 EEG, Evoked Potentials, MRI Scans, PET Scans, SPECT
            </ReplaceLink>
          </li>
        </ul>
      </div>

      <hr />

      <h2 id="sec1dot1">1.1 General Description and Clinical Textbooks</h2>
      <p>
        Auriculotherapy. [No authors listed] <em>JAMA</em>. 1984 Oct 12;
        252(14): 1855-1857
      </p>
      <p>
        Bagnis JP, Francois IR. L’auriculotherapie a la clinique des Bruyeres.{" "}
        <em>Revue d’auriculomedicine</em> no 23 Apr 1981 Journal Article French
        France
      </p>
      <p>
        Bahr FR, Reis, Stranbe, Strittmatter, Suwanda. <em>Skriptum fur die</em>{" "}
        <em>Aufbaustuff</em> <em>aller Akupunktuverfahren</em> (Stufe/Ohr und
        Korperakupunktur). 1983
      </p>
      <p>
        Bahr FR. <em>Aurikulopunktur</em>. Satas, Belgique Book German
      </p>
      <p>
        Bahr FR. <em>Introduction to scientific acupuncture.</em> MI : The
        German Academy for Auricular Medicine. 1978 book
      </p>
      <p>
        Bahr FR.{" "}
        <em>
          Systematik und praktikum der wissenschaftlichen ohrarakupuktur fair
          fortgeschrittenne
        </em>{" "}
        Edicion dr Bahr 1986
      </p>
      <p>
        Bahr FR.{" "}
        <em>
          Systematik und praktikum der wissenschaftlichen ohrarakupuktur fiir
          fortgeschrittenne und experten
        </em>{" "}
        Edicion dr Bahr 1987.
      </p>
      <p>
        Bahr FR.{" "}
        <em>The clinical practice of scientific auricular acupuncture.</em>{" "}
        Kalamazoo, NU The German Academy for Auricular Medicine. 1977 book
      </p>
      <p>
        Bahr FR. <em>Wissenschaftliche ohrakupunktur in der praxis</em>.
        Heidelberg: Verlag fur Medizin Dr. Ewald Fischer. 1977.-105 S.
      </p>
      <p>
        Bossy J. <em>Los microsystemass de la acupuntura</em>. Masson (1987)
      </p>
      <p>
        Bossy J. Pratrandal D, Taillandier J.{" "}
        <em>Les microsystemes de l’acupuncture</em>. Masson (1984)
      </p>
      <p>
        Bourdiol RJ, Nogier P, Bahr FR.{" "}
        <em>Localisations auriculaires (planches).</em> Maisonneuve. 1977.
        planche French
      </p>
      <p>
        Bourdiol RJ. <em>Auriculosomatology</em>. Maisonneuve Moulins-les Metz,
        France: 1983 book English
      </p>
      <p>
        Bourdiol RJ. <em>E1ements d’auriculotherapie</em>. Maisonneuve,
        Moulins-les Metz, 1980. Book French
      </p>
      <p>
        Bourdiol RJ. <em>Elements of auriculotherapy</em>. Maisonneuve. France
        book English
      </p>
      <p>
        Bourdiol RJ. <em>Reflexotherapie somatique.</em> Maisonneuve, 1983, Book
        French
      </p>
      <p>
        Bricot B. Enseignement au niveau du C.I.E.S. (troubles de la statique).
        Points de neutralisation des troubles de la statique. C.I.E.S
      </p>
      <p>
        Bricot B. L’auriculotherapie. (site internet du Glem){" "}
        <em>Annales du G.L.E.M.</em> (1996)
      </p>
      <p>
        Buchholz W. <em>Praxis der Franzosischen ohrakupunktur</em>. D. Munks
        Verlag fur Medizin, Krefeld, 1979 Buttigieg Ch. Soignez vous par
        l’oreille M _ 1984
      </p>
      <p>
        Chan P. <em>Ear acupressure</em>. Monterey Park -. Chan’s Corporation.
        1981 Book
      </p>
      <p>
        Chen K. <em>Handbook to Chinese auricular therapy, 1st ed.</em> Beijing
        Foreign Languages Press 1991 238 p Book
      </p>
      <p>
        Debef J. Where do you belong auriculotherapy ?{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM.
      </p>
      <p>
        Farah M. Soins traditionnels par le pavilion de l’oreille en Tunisie
        <em>
          . Annales du Troisieme Symposium International d’Auriculotherapie et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France
      </p>
      <p>
        Flament C. Auriculo-medecine et acupuncture.{" "}
        <em>Revue d’auriculomedicine </em>no. 14 Jan 1979 Journal Article French
        France
      </p>
      <p>
        Flament C. De quelques cas d’echecs en acupuncture.
        <em> Revue d’auriculomedicine </em>no. 30 Jan 1983 Jounal Article French
        France.
      </p>
      <p>
        Giobglas L. <em>Traite d’acupuncture auriculaire</em>. Maloine 1986.
        Book
      </p>
      <p>
        Glosemeyer HA. <em>Die Auriculo Akupuntur</em>. Veriag Muller &amp;
        Steinicke, Munchen 1981 German
      </p>
      <p>
        Greenlee, D. <em>The healing ear: intermediate auricular therapy.</em>{" "}
        Kelseyville, CA: Earthen Vessel. 1995
      </p>
      <p>
        Helms, J.{" "}
        <em>Acupuncture energetics: a clinical approach for physicians</em>.
        Berkeley, CA: Medical Acupuncture Published 1995
      </p>
      <p>
        Huang H. <em>Ear acupuncture.</em> Emmaus,.Pennsylvania -. Rodale Press
        1974 Book
      </p>
      <p>
        Inconnu <em>Atlas of standard auricular points</em>. Satas, Belgique.
        Carte/Poster Beijing.
      </p>
      <p>
        Inconnu <em>Chart of Chinese auricular points</em>. Satas, Belgique.
        Beijing.
      </p>
      <p>
        Inconnu <em>Chinese auricular points chart</em>. Satas, Belgique.
        Beijing.
      </p>
      <p>
        Inconnu Report of the working group on Auricular Acupunture Nomenclature
        World Health Organization Lyon France 28 30. Nov. 1990
      </p>
      <p>
        Jarricot H. <em>L’auriculotherapie</em> Revue Meridiens, 1973
      </p>
      <p>
        Jarricot H. <em>Projections viscero-cutanees</em>. Metameres
        thoraco-abdominales. <em>Minerva medica</em> 1975. p. 42-58.
      </p>
      <p>
        Jarricot H.{" "}
        <em>
          Somatotopie du pavillon auriculaire congres mondial d’acupuncture.
        </em>{" "}
        Paris, 1969.
      </p>
      <p>
        Joyeux MC. <em>Etude critique de l’auriculotherapie these</em>,
        Grenoble, 1974.
      </p>
      <p>
        Julienne B, Mallard A. Relationship of auriculomedicine and acupuncture.{" "}
        <em>Annales du G.L.E.M.</em> (1998)
      </p>
      <p>
        Julienne B. Quelques remarques d’ordre pratique.{" "}
        <em>Revue d’auriculomedicine</em> no 16 Jul 1979 Journal Article French
        France
      </p>
      <p>
        Keibel F.{" "}
        <em>
          Developpement de l’oreille exteme- manuel d’embryologie humaine.
        </em>
      </p>
      <p>
        Ken C, Yongqiang C. <em>Handbook to Chinese auricular therapy</em>.
        Beijing, China: Foreign Languages Press. 1991
      </p>
      <p>
        Konig G, Wancura I. <em>Einfuhrung in die Chinesische ohrakupunktur</em>
        . Heidelberg: Karl F. Haug. 1993
      </p>
      <p>
        Konig G, Wancura I. <em>Neue Chinesische akupunctur.</em>{" "}
        Wien-Munchen-Bern: Verlag W. Maudrich. 1975.
      </p>
      <p>
        Kovacs J. H. <em>Auriculomedicine en consultation</em>. Journaliere
        Maloine. 1983. Book French
      </p>
      <p>
        Kropei H. <em>Systematik der ohrakupunktur.</em> Theorie und Praxis.
        Stuttgart: Hippokrates Veriag. 1952.
      </p>
      <p>
        Kropei H.{" "}
        <em>The fundamentals of ear acupuncture. Second revised edition</em>.
        Heidelberg, Germany Karl F. Haug Verlag GmbH. 1984 book
      </p>
      <p>
        Kropej <em>Systematik der ohrakupunktur.</em> Haug vedag Satas,
        Belgique. 1977
      </p>
      <p>
        Leclerc BA. <em>Auriculomedicine</em>. Auteur / GLEM 1998 Book French
      </p>
      <p>
        Liao S, Lee M, Ng L.{" "}
        <em>Principles and practice of contemporary acupuncture. </em>New York:
        Marcel Dekker. 1994 book
      </p>
      <p>
        Lu HC. <em>The Chinese verlans of modern acupuncture</em>. Canada 1973.
      </p>
      <p>
        Marignan M.{" "}
        <em>
          Etat actuel des travaux de standardisation de l’auriculotherapy par
          l’Organisation Mondiale de la Sante Asclepios.
        </em>{" "}
        1993 Book French
      </p>
      <p>
        Marignan M. Is contemporary medicine real
        <em>
          ? Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 French GLEM
      </p>
      <p>
        Marignan M. L’auriculotherapie: etat actuel des travaux de
        standardisation de l’organisation mondiale de la sante report of the
        working group on auricular acupuncture nomenclature. WHO 1991.{" "}
        <em>
          Report of the working group on auricular acupuncture nomenclature.
        </em>{" "}
        Lyon, France, 28-3 0 Nov 1990
      </p>
      <p>
        Marignan M. Les nouveaux objets de la science.{" "}
        <em>Sciences et Medecines Nouvelles</em> Vol I No 3 Journal Article
        French Cable Edition
      </p>
      <p>
        Martinez FV. El desafio de le auriculoterapia el hombre reflejado en su
        oreja. <em>Mandala Ediciones</em> 1999 book Spanish Madrid
      </p>
      <p>
        Martinez FV.{" "}
        <em>
          El desafio de le auriculoterapia : el hombre reflejado en su oreja.
        </em>{" "}
        Mandala Ediciones 1999 book Spanish Madrid
      </p>
      <p>
        Martinez FV. <em>Introduccion a la auriculoterapia</em>. Alter Edition
        1989/1990 4 volumes Proelsa SA p’ de Gracia 69 4′ dpcho 9 Barcelonna
        Alter Mateolnurfia 30.28036 Madrid Spain, Espagne
      </p>
      <p>
        Nahemkis A, Smith B. <em>Ear acupuncture therapy</em>. Long Beach: Alba
        Press. 1975 book
      </p>
      <p>
        Niboyet JE.{" "}
        <em>
          Rapport au ministre de la Sante concernant les medicines alternatives.
        </em>{" "}
        Pafis, 1984. Book French
      </p>
      <p>
        Nogier P, Bourdiol R, Corcelle . Auriculotherapy. <em>Chir Dent</em> Fr
        1976 Mar 17;46(296):61-3 Medline 78168409 Journal article French
      </p>
      <p>
        Nogier P, Nogier R. <em>L’homme dans l’oreille</em>: Maisonneuve 1981
        Book French
      </p>
      <p>
        Nogier P, Nogier R. The man in the ear. Moulins-les Metz, France :
        Maisonneure book
      </p>
      <p>
        Nogier P. <em>Aspect actuel de la reflexotherapie auriculaire</em>.
        Clermont Ferrand . 1959. French
      </p>
      <p>
        Nogier P. Auriculo-medecine et acupuncture (suite).{" "}
        <em>Revue d’auriculomedicine </em>no. 11 Apr 1978 Journal Article French
        France
      </p>
      <p>
        Nogier P. Auriculo-medecine et acupuncture
        <em>. Revue d’auriculomedicine </em>no. 10 Jan 1978 Journal Article
        French
      </p>
      <p>
        Nogier P. <em>Complement des points reflexes auriculaires.</em>{" "}
        Maisonneuve , 1989. Book
      </p>
      <p>
        Nogier P. Flament <em>Revue d’auriculomedicine </em>no. 13 Oct l978
        Journal Article French France
      </p>
      <p>
        Nogier P. <em>From auriculotherapy to auriculomedicine.</em> Moulins-les
        Metz, France: Maisonneuve. 1983 book
      </p>
      <p>
        Nogier P. Frontieres externes. <em>Revue d’auriculomedicine</em> no. 4
        Jul 1976 Journal Article French France
      </p>
      <p>
        Nogier P. <em>Introduction pratique a l’auriculotherapie</em>.
        Maisonneuve, 1977. Book French
      </p>
      <p>
        Nogier P. La rangon d’une decouverte. <em>Revue d’auriculomedicine</em>{" "}
        no I 1 Apr 1978 Journal Article French France
      </p>
      <p>
        Nogier P. L’auriculo-medecine fait le point.{" "}
        <em>Revue d’auriculomedicine</em> no. 15 Apr 1979 Journal Article French
        France
      </p>
      <p>
        Nogier P. <em>L’auriculotheapie journeees d’informations</em>. Turin
        1974. Book French
      </p>
      <p>
        Nogier P. L’auriculotherapie face i la medecine traditionnelle.{" "}
        <em>Revue d’auriculomedicine</em> no 24 Jul 1981 Journal Article French
        France
      </p>
      <p>
        Nogier P. <em>L’auriculotherapie</em>. Lyon Mediterranee Medical, 1971,
        Book French
      </p>
      <p>
        Nogier P. Le malade et son medecin. <em>Revue d’auriculomedicine</em> no
        9 Oct 1977 Journal Article French France
      </p>
      <p>
        Nogier P. Le pavilion de l’oreille{" "}
        <em>Journees d’acupuncture de Marseille</em>, 1956. French
      </p>
      <p>
        Nogier P. <em>Points reflexes auriculaires.</em> Maisonneuve, 1987 1987
        Book
      </p>
      <p>
        Nogier P. <em>Points reflexes du pavilion</em>. La Bourboule, 1957
        French
      </p>
      <p>
        Nogier P. Pourquoi une introduction a l’auriculotherapie?{" "}
        <em>Revue d’auriculomedicine</em> no. 7 Apr 1977 Journal Article French
        France
      </p>
      <p>
        Nogier P.{" "}
        <em>
          Presentation, development perspectives de l’auriculotherapie journee.
        </em>{" "}
        Internationale Lyon, 1966. French
      </p>
      <p>
        Nogier P. Quelques pensees de Rene Leriche.{" "}
        <em>Revue d’auriculomedicine</em> no 34 Jan 1984 Journal Article French
        France
      </p>
      <p>
        Nogier P. <em>Reflexe du pavillion de l’oreille coll</em>oque. Lyonnais,
        1962. Book French
      </p>
      <p>
        Nogier P. <em>Traite d’Auriculotherapie.</em> Maisonneuve, 1969. Book
        French
      </p>
      <p>
        Nogier R. A standard international acupuncture nomenclature
        <em>. Sciences et Medecines Nouvelles</em> Vol I N’3 GLEM Journal
        Article French
      </p>
      <p>
        Oleson T. A standardised nomenclature for comparing Chinese and French
        auricular acupuncture points.{" "}
        <em>
          Annales du Premier Symposium International d’Auriculotherapie et
          d’Auricutomedecine
        </em>{" "}
        Lyon France: GLEM
      </p>
      <p>
        Oleson T.{" "}
        <em>
          Auriculotherapy manual : Chinese and Western systems of ear
          acupuncture.
        </em>{" "}
        1996 Health Care Alternatives : Los Angeles, California. 1996 244 pages
        Los Angeles, California. Book English
      </p>
      <p>
        Pagani GM.{" "}
        <em>
          Le maillon reliant l’auriculo medecine a l’acupuncture traditionnelle
        </em>
        . Siret 1978. Book French
      </p>
      <p>
        Panareo M. Hypoconvergences oculaires et auriculotherapy.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auiculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM French GLEM
      </p>
      <p>
        Pesikov Y, Rybalko S. <em>Auricular acupuncture: clinical atlas.</em>{" "}
        Donetsk, Ukraine : Three Dragons Press. 1994 Book
      </p>
      <p>
        Printemps A. <em>Pourquoi se soigner par auriculomedicine.</em> Gueniot
        Editeur 52201 Langres, FR 1994 Book French
      </p>
      <p>
        Reis A.{" "}
        <em>
          Verdeckte punktlokalisation der Ohrakupunktur der akupunktura
          auriculotherapeut
        </em>
        .1992. 3 31-35
      </p>
      <p>
        Ricard F.{" "}
        <em>Auriculotherapie, sympathicotherapie et medecine chinoise</em> 1984
      </p>
      <p>
        Roccia L. Current status of acupuncture and auriculotherapy.{" "}
        <em>Minerva Med</em> 1979 Dec 15; 70 ( 56): 3875-7 Medline 80143595
        Journal article Italian
      </p>
      <p>
        Romoli M. Differences in western and eastern ear acupuncture.{" "}
        <em>World Congress of Scientific Acupuncture</em>, 2, 1986, English
      </p>
      <p>
        Rosenstiel HP, Amar M. <em>L’auriculotherapie sans aiguilles</em>.
        Robert Laffont , 1987.
      </p>
      <p>
        Roths A. Auriculotherapie et stomatologie.{" "}
        <em>Revue d’auriculomedicine</em> no. 17 Oct 1979 JournalArticle French
        France
      </p>
      <p>
        Rouxeville Y. Ma premiere experience d’auriculotherapy.{" "}
        <em>Revue d’auriculomedicine</em> no. 28 Jul 1982 Journal Article French
        France
      </p>
      <p>
        Sagne R. La pyramide de la maladie. <em>Revue d’auriculomedicine</em>{" "}
        no. 35 Apr 1984 Journal Article French France
      </p>
      <p>
        Santaro M. <em>L’acupuncture par l’oreille</em>. Maloine, Paris 1974
        French
      </p>
      <p>
        Schmid HD.{" "}
        <em>
          Ohrakupunktur in der zahn mund undkkieferheilkunde der akupunkturarzt
          auriculotherapeut
        </em>{" "}
        1993 2 26-41.
      </p>
      <p>
        Sponzilli O. La reflessologia emozionale nelle pratica medica e
        psicoterapica : un nuovo approccio all’auriculoterapia{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM Italian
      </p>
      <p>
        Strittmatter B.{" "}
        <em>
          Grundsatzliches zur ohrakupunktur bei linkshandern der akupunkturarzt
          auriculoth
        </em>
        erapeut. 1992 N’3 36/44
      </p>
      <p>
        Van Gelder A. <em>Stategieen 2, Auriculotherapie.</em> Satas, Belgique.
      </p>
      <p>
        Van Gelder A. <em>Stategieen 3 Auriculomedicine</em>. Satas, Belgique.
      </p>
      <p>
        Van Gelder A.{" "}
        <em>Strategiedn in de ooracupunctuur: deel 2 auriculotherapie.</em>{" "}
        Utrecht : Uitgevefij Lemma. 1992 book
      </p>
      <p>
        Veith I. <em>The yellow emperor’s classic of internal medicine</em>.
        Berkeley: University of California Pres. 1972 book
      </p>
      <p>
        Vu Giang M. <em>Auriculotherapy infirm</em>. Fr 1980 Apr;( 214):23-7
        Medline 80181367 Journal article French
      </p>
      <p>
        Wertsch schrecke <em>Ohrakupunktur fur die praxis</em>.
        Biologische-Medizinische Verlag 1979 German
      </p>
      <p>
        Wexu M. <em>Auriculotherapie</em> (NL) Satas, Belgique.
      </p>
      <p>
        Wexu M.{" "}
        <em>
          The ear, gateway to balancing the body : a modern guide to ear acupu
        </em>
        ncture. Satas, Belgique. New York: ASI Publishers. 1975 193 p New York:
        ASI Publishers;
      </p>
      <p>
        Zulueta C. Nuevo punto de Auei.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Merciere 69002 Lyon
      </p>

      <h2 id="sec1dot2">1.2 Acupuncture History and Theories</h2>
      <p>
        Bourdiol RJ. Les douleurs reflexes de la peau.{" "}
        <em>Revue d’auriculomedicine</em> no. 7 Apr 1977 Journal Article French
        France
      </p>
      <p>
        Bourdiol RJ. Mes adieux a mon maittre Paul Nogier.{" "}
        <em>Revue d’auriculomedicine</em> no. 25 Oct 1981 Journal Article French
        France
      </p>
      <p>
        Bourdiol RJ. Vers une nouvelle conception de la medecine vertebrate{" "}
        <em>Revue d’auriculomedicine</em> no. 7 Apr 1977 Journal Article French
        France
      </p>
      <p>
        Cantoni G, Pontigny JA.{" "}
        <em>Recherche scientifique francaise et acupuncture.</em> Sainte-Ruffine
        (France): 1989 276 book French Maisonneuve
      </p>
      <p>
        Chang JJ, Fisch J, Popp FA. <em>Biophotons</em>. Kiewer Academic 1998.
      </p>
      <p>
        Couleni P. Un cas de blocage du corps calleux.{" "}
        <em>Revue d’auriculomedicine</em> no I I Apr 1978 Journal Article French
        France
      </p>
      <p>
        Durinyan A propos de quelques mecanismes physiologiques mis en’eu par la
        medicine auriculaire <em>Revue d’auriculomedicine</em> t? 15 Jan 1980
        Journal Article French France
      </p>
      <p>
        George T, Lewith M.{" "}
        <em>
          The history of acupuncture in the west : acupuncture its place in
          western medical science
        </em>
        . Thorsons Publlishing Group
      </p>
      <p>
        Ho MW, Popp FA, Wamke U.{" "}
        <em>Biolectric dynamics and biocommunication.</em> World Scientific
        1994.
      </p>
      <p>
        Hsa E.{" "}
        <em>
          The history and development of auriculotherapy, acupuncture in
          medicine.
        </em>{" "}
        1992 Vol X supplement Page 109 Newton House
      </p>
      <p>
        Kastner D. Auriculomedecine, Yi-King et code genetioue.{" "}
        <em>
          Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France: 27,28,29 May 1994 French
      </p>
      <p>
        Kenyon J. An introduction to quantum biology. <em>Coherence</em> 1998 :
        The 2nd international IAAMER congress on: auricular diagnostics &amp;
        therapy Oisterwijk, The Netherlands September 19-21, 1997 English
        Netherlands
      </p>
      <p>
        Kessous Y. De l’auriculotherapy i la guerison energetique.{" "}
        <em>Medicine et Energie</em> Mortagne , 1992.
      </p>
      <p>
        Kessous Y. Pour en fir avec la theorie neurologique.et commencer avec la
        theorie energetique
        <em>
          . Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France : Haug editeur Bruxelles. 27,28,29 May 1994
      </p>
      <p>
        Kirsh M. In memorian Dr. Paul Nogier.{" "}
        <em>International J of Auricular Medicine</em> (IJAM) ISSN 0793-3150
        1996
      </p>
      <p>
        Bourdiol RJ. Les douleurs reflexes de la peau.{" "}
        <em>Revue d’auriculomedicine</em> no. 7 Apr 1977 Journal Article French
        France
      </p>
      <p>
        Bourdiol RJ. Mes adieux a mon maittre Paul Nogier.{" "}
        <em>Revue d’auriculomedicine</em> no. 25 Oct 1981 Journal Article French
        France
      </p>
      <p>
        Bourdiol RJ. Vers une nouvelle conception de la medecine vertebrate{" "}
        <em>Revue d’auriculomedicine</em> no. 7 Apr 1977 Journal Article French
        France
      </p>
      <p>
        Cantoni G, Pontigny JA.{" "}
        <em>Recherche scientifique francaise et acupuncture.</em> Sainte-Ruffine
        (France): 1989 276 book French Maisonneuve
      </p>
      <p>
        Chang JJ, Fisch J, Popp FA. <em>Biophotons</em>. Kiewer Academic 1998.
      </p>
      <p>
        Couleni P. Un cas de blocage du corps calleux.{" "}
        <em>Revue d’auriculomedicine</em> no I I Apr 1978 Journal Article French
        France
      </p>
      <p>
        Durinyan A propos de quelques mecanismes physiologiques mis en’eu par la
        medicine auriculaire <em>Revue d’auriculomedicine</em> t? 15 Jan 1980
        Journal Article French France
      </p>
      <p>
        George T, Lewith M.{" "}
        <em>
          The history of acupuncture in the west : acupuncture its place in
          western medical science
        </em>
        . Thorsons Publlishing Group
      </p>
      <p>
        Ho MW, Popp FA, Wamke U.{" "}
        <em>Biolectric dynamics and biocommunication.</em> World Scientific
        1994.
      </p>
      <p>
        Hsa E.{" "}
        <em>
          The history and development of auriculotherapy, acupuncture in
          medicine.
        </em>{" "}
        1992 Vol X supplement Page 109 Newton House
      </p>
      <p>
        Kastner D. Auriculomedecine, Yi-King et code genetioue.{" "}
        <em>
          Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France: 27,28,29 May 1994 French
      </p>
      <p>
        Kenyon J. An introduction to quantum biology. <em>Coherence</em> 1998 :
        The 2nd international IAAMER congress on: auricular diagnostics &amp;
        therapy Oisterwijk, The Netherlands September 19-21, 1997 English
        Netherlands
      </p>
      <p>
        Kessous Y. De l’auriculotherapy i la guerison energetique.{" "}
        <em>Medicine et Energie</em> Mortagne , 1992.
      </p>
      <p>
        Kessous Y. Pour en fir avec la theorie neurologique.et commencer avec la
        theorie energetique
        <em>
          . Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France : Haug editeur Bruxelles. 27,28,29 May 1994
      </p>
      <p>
        Kirsh M. In memorian Dr. Paul Nogier.{" "}
        <em>International J of Auricular Medicine</em> (IJAM) ISSN 0793-3150
        1996
      </p>
      <p>
        Navach JH. Application of the platyheiminthes experiment model to
        demonstrate the relay function of acupuncture points in humans.{" "}
        <em>Nogier Seminar,</em> Montreal, Quebec October, 1984
      </p>
      <p>
        Navach JH. Biological model of 902 nanometer soft-laser tissue
        penetration, tissue reaction relative to exposure time, scatter in
        tissue, and the shielding effect of various materials
        <em>. International Congress of Acupuncture and Applied Techniques</em>,
        Sorrento, Italy September 12, 1982
      </p>
      <p>
        Navach JH. Biological models of electromagnetic transmission of
        information
        <em>. International Congress of Acupuncture and Applied Techniques</em>,
        Sorrento, Italy September 10, 1982.
      </p>
      <p>
        Niboyet JE. VIII es Journees germano-latines d’acupuncture et
        d’auriculotherapie, vingt-cinquieme anniversaire de la decouvertes de
        l’auriculotherapy par le Dr Paul Nogier.{" "}
        <em>Revue d’auriculomedicine</em> no. 25 Oct 1981 Journal Article French
        France
      </p>
      <p>
        Nogier P. Action indirecte d’une premiere cete.{" "}
        <em>Revue d’auriculomedicine.</em> no. 11 Apr 1978 Journal Article
        French France
      </p>
      <p>
        Nogier P. Cicatrice d’episiotomie. <em>Revue d’audculomedicine.</em> no.
        27 Apr 1982 Journal Article French France
      </p>
      <p>
        Nogier P. Entretiens au cabinet medical.{" "}
        <em>Revue d’auriculomedicine.</em> no 2 Jan 1976 Journal Article French
        France
      </p>
      <p>
        Nogier P. Fac-simile de documents chinois.{" "}
        <em>Revue d’auriculomedicine</em> no. 21 Oct 1980 Journal Article French
        France
      </p>
      <p>
        Nogier P. Fac-simile. ” Bulletin de la Societe d’Acupuncture ” May 1956{" "}
        <em>Revue d’auriculomedicine</em> no. 21 Oct 1980 Journal Article French
        France
      </p>
      <p>
        Nogier P. Le systeme de vigilance. <em>Revue d’auriculomedicine</em> no.
        4 Jul 1976 Journal Article French France
      </p>
      <p>
        Nogier P. L’energie reticulee. Remarques et experiences.{" "}
        <em>Revue d’auriculomedicine</em> no. 19 Apr 1980 Journal Article French
        France
      </p>
      <p>
        Nogier P. Les pouls chinois. <em>Revue d’auriculomedicine</em> no. 35
        Apr 1984 Journal Article French
      </p>
      <p>
        Nogier P. Nos entretiens au cabinet medical : gene provoquee par un
        pace-maker. <em>Revue d’auriculomedicine</em> no 1 Sept 1975 Journal
        Article French France
      </p>
      <p>
        Nogier P. Nos entretiens au cabinet medical : troubles de la sensibilite
        d’un talon. <em>Revue d’auriculomedicine</em> no 1 Sept 1975
        JournalArticle French France
      </p>
      <p>
        Nogier P. Nos entretiens au cabinet medical: arthrose de la hanche.{" "}
        <em>Revue d’auriculomedicine</em> no 1 Sept 1975 Journal Article French
        France
      </p>
      <p>
        Nogier P. Petite histoire de l’auriculo-medecine.{" "}
        <em>Revue d’auriculomedicine</em> no. 2 Janv 1976 Journal Article French
      </p>
      <p>
        Nogier P. Reponse de Dr Nogier au discours de parrainage du Dr Nogier (I
        I septembre 198 1). <em>Revue d’auriculomedicine</em> no. 25 Oct 1981
        Journal Article France
      </p>
      <p>
        Nogier P. Une nouvelle hypothese sur la structure des etres vivants: la
        notion de reseau. <em>Revue d’auriculomedicine</em> no 15 Apr 1979
        JournalArticle France
      </p>
      <p>
        Patterson MA. Neuroelectric Therapy: The new approach to drug treatment
        and its scientific basis. Subtle energies and energy medicine: Emerging
        theory and practice
        <em>
          , Proceedings of the 1st Innvention of the Society for the Study of
          Subtle Energies and Energy Medicin
        </em>
        e 1991 June 21-25 pp. 76-79
      </p>
      <p>
        Piro D. Methodologie holo-energetique.
        <em>
          {" "}
          Annales du Premier Symposium International d’Audculotherapie et
          d’Auriculomedicine
        </em>{" "}
        Lyon France: Haug editeur Bruxelles. 27,28,29 May 1994 GLEM French
      </p>
      <p>
        Reynaud A. La these ou la vie.. dun fetus!{" "}
        <em>Revue d’auriculomedicine</em> no. 10 Jan 1978 Journal Article French
        France
      </p>
      <p>
        Rietveld WJ. Biological clocks in health and disease. <em>Coherence</em>{" "}
        1998 : the 2nd international IAAMER congress on: auricular diagnostics
        &amp; therapy Oisterwijk, September 19-21, English Netherlands
      </p>
      <p>
        Strittmatter B, Klowersa R.{" "}
        <em>
          Hilfslinien in der ohrakupunktur der akupunkturarzt //
          auriculotherapeut
        </em>
        . 1993 no. 4: 9-23
      </p>
      <p>
        Tiller WA. Augmented electromagnetic waves and qi energy.{" "}
        <em>
          First International Concensus Conference on Acupuncture,
          Auriculotherapy and Auricular Medicine
        </em>{" "}
        Las Vegas, Nevada, August, 1999
      </p>

      <h2 id="sec1dot3">1.3 Clinical Observations</h2>
      <p>
        Braemer C. Mes experiences concernant les axes blancs.{" "}
        <em>Revue d’auriculomedicine</em> no. 13 Oct l978 Journal Article French
        France.
      </p>
      <p>
        Dahout C. Cinq cas traitds par polartrons unidirectionnels.{" "}
        <em>Revue d’auriculomedicine</em> no 32 Jul 1983 Journal Article French
        France <strong> </strong>
      </p>

      <p>
        Degraix M. Les cas de Marie Degraix. <em>Revue d’auriculomedicine</em>{" "}
        no 30 Jan 1983 Journal Article French France
      </p>
      <p>
        Degraix M. Les points d’adaptation selon deux observations.{" "}
        <em>Revue d’auriculomedicine</em> no. 35 Apr 1994 Journal Article French
        France
      </p>
      <p>
        Degraix Roux A. Observations a propos du polartron.{" "}
        <em>Revue d’auriculomedicine</em> no 32 Jul 1983 Journal Article French
        France <strong> </strong>
      </p>

      <p>
        Delfau 2 cas du Docteur Delfau. <em>Revue d’auriculomedicine</em> no 30
        Jan 1983 Journal Article French France
      </p>
      <p>
        Delpuech JP. Cas clinique et filtre tissulaire.{" "}
        <em>Revue d’auriculomedicine</em> no. 29 Oct 1982 Journal Article French
        France
      </p>
      <p>
        Denjean Massia. Quatre cas. <em>Revue d’auriculomedicine </em>no. 28 Jul
        1982 Journal Article French France
      </p>
      <p>
        Dillon M, Lucas C. Auricular stud acupuncture in palliative care
        patients. <em>Palliat Med</em> 1999 May; 13(3): 253-4 Medline 99403962.
      </p>
      <p>
        Drahi A. Deux observations cliniques.{" "}
        <em>Revue d’auriculomedicin.e </em>no. 9 Oct 1977 Journal Article French
        France
      </p>
      <p>
        Finaldi Un cas du Docteur Finaldi. <em>Revue d’auriculomedicin.e</em>{" "}
        no. 32 Jul 1983 Journal Article French France
      </p>
      <p>
        Flament C. A propos d’une enquete, deux observations.{" "}
        <em>Revue d’auriculomedecin.e</em> no. 34 Jan 1984 Journal Article
        French France.
      </p>
      <p>
        Flament C. Une douleur, une cicatrices une aiguille, guerison.{" "}
        <em>Revue d’auriculomedicin.e</em> no. 12 Jul 1978 Journal Article
        French France
      </p>
      <p>
        Franchina A. Les cas d’angeto Franchina.{" "}
        <em>Revue d’auriculomedicin.e</em> no. 32 Jul 1983 Journal Article
        French France
      </p>
      <p>
        Jarricot H. Observations singulieres en auriculotherapy.{" "}
        <em>Joumees de Besancon</em>, 1971.
      </p>
      <p>
        Julienne L. Ose du forum de juin 96 controverse i propos d’un exp.{" "}
        <em>Annales du G.L.E.M</em>. (1996)
      </p>
      <p>
        Lentz A. <em>Advanced techniques.</em> Publication by author 1996 book
        English France
      </p>
      <p>
        Lentz A. Auriculomedicine vision sgatiate de renerce en au.{" "}
        <em>Annales du G.L.E.M.</em> (1995)
      </p>
      <p>
        Lentz A. Espace, temps et forces fondamentales Andre.{" "}
        <em>Annales du G.L.E.M.</em> (1995)
      </p>
      <p>
        Lentz A. La loi des contrastes et la loi de symetrie.{" "}
        <em>Annales du G.L.E.M.</em> (1995)
      </p>
      <p>
        Lentz A. La regulation des transferts par l’A.R.T.{" "}
        <em>Annales du G.L.E.M.</em> (1997) 66
      </p>
      <p>
        Lentz A. L’art et les trois systemes. <em>Annales du G.L.E.M.</em>{" "}
        (1997) 66
      </p>
      <p>
        Lentz A. Les cicatrices. <em>Bulletin de liaison de I’AMABF</em> no. 2
        Juin 1982
      </p>
      <p>
        Lentz A. Les deux systemes. <em>Annales du G.L.E.M.</em> (1996)
      </p>
      <p>
        Lentz A. Memoire des recherches de 1979 i 1982 diff-use en 10 ex. i
        quelques chercheurs en Auriculomedicine
      </p>
      <p>
        Lentz A. Vision spatiale de l’energie en auriculomedicine.{" "}
        <em>Annales du G.L.E.M</em>. (1995)
      </p>
      <p>
        Lentz J. Controverse i propos dun exposd du Forum de juin 96.{" "}
        <em>Annales du G.L.E.M.</em> (1996)
      </p>
      <p>
        Limonat de Kerimel Y. Les cinq cas du Docteur Limonat de Kerimel.{" "}
        <em>Revue d’auriculomedicin.e</em> no. 29 Oct 1982 Journal Article
        French France
      </p>
      <p>
        Lugeux J. Edeme du membre infefieur et premiere cete.{" "}
        <em>Revue d’auriculomedicine </em>no. 34 Jan 1984 Journal Article French
        France.
      </p>
      <p>
        Marignan M. Les cinq cas de M. Marignan.{" "}
        <em>Revue d’auriculomedicine</em> no. 29 Oct l982 Journal Article French
        France
      </p>
      <p>
        Marignan M. Observations d’auricuriomedicine.{" "}
        <em>Revue d’auriculomedicine</em> no. 34 Jan 1984 Journal Article French
        France
      </p>
      <p>
        Nogier P. 12 examen d’un malade. <em>Revue d’auriculomedicine</em> no. 3
        Apr 1976 Journal Article France
      </p>
      <p>
        Nogier P. L’auriculotherapy et la kinesitherapie.{" "}
        <em>Revue d’auriculomedicine</em> no 13 Oct l978 Journal article French
        France
      </p>
      <p>
        Nogier P. Le blocage de la premiere cote (suite).{" "}
        <em>Revue d’auriculomedicine</em> no 7 Apr 1977 Journal Article France
      </p>
      <p>
        Nogier P. Les eclipses visuelles. <em>Revue d’auriculomedicine</em> no 7
        Apr 1977 Journal Article French France
      </p>
      <p>
        Nogier P. L’examen d’un malade. Comment le congevoir en
        auriculomedicine? <em>Revue d’auriculomedicine</em> no 6 Jan 1977
        Journal Article French France
      </p>
      <p>
        Nogier P. L’examen d’un malade. <em>Revue d’auriculomedicine</em> no. 3
        Apr 1976 Journal Article French France
      </p>
      <p>
        Nogier P. Observations cliniques. <em>Revue d’auriculomed</em>icine. no
        7 Apr 1977 Journal Article Frencc France
      </p>
      <p>
        Nogier P. Observations medicales – une fausse precore cete.{" "}
        <em>Revue d’auriculomedecine.</em> no. 13 Oct l978 Journal Article
        French France
      </p>
      <p>
        Nogier P. Observations medicales. <em>Revue d’auriculomedicine.</em> no
        3 Apr 1976 Journal Article French France
      </p>
      <p>
        Nogier P. Peut-on parler d’energie mesurable.{" "}
        <em>Revue d’auriculomedicine</em> no. 5 Oct 1976 Journal Article French
        France
      </p>
      <p>
        Nogier P. Quelques observations medicales.{" "}
        <em>Revue d’auriculomedicin.e</em> no 5 Oct 1976 JournalArticle French
        France
      </p>
      <p>
        Nogier P. Surprise au cours dun examen.{" "}
        <em>Revue d’auriculomedecine.</em> no. 12 Jul 1978 Journal Article
        French France
      </p>
      <p>
        Nogier P. Un resultat dans la ” culotte de cheval. ”{" "}
        <em>Revue d’auricul</em>omedecine. no. 22 Jan 1981 Journal Article
        French France
      </p>
      <p>
        Nogier P. Une strange paralysis. <em>Revue d’auriculomedecine.</em> no.
        12 Jul 1978 Journal Article French France
      </p>
      <p>
        Nogier P. Elle se rongeait leg ongles.{" "}
        <em>Revue d’auriculomedicine.</em> no. 29 Oct l982 Journal Article
        French France
      </p>
      <p>
        Nogier P. et als. Cas cliniques. <em>Revue d’auriculomedicine</em>. no.
        4 Jul 1976 Journal Article French France
      </p>
      <p>
        Novak Leg observations du Docteur Novak.{" "}
        <em>Revue d’auriculomedicine</em> no. 30 Jan 1983 Journal Article French
        France
      </p>
      <p>
        Raynaud A. Une observation psychologique.{" "}
        <em>Revue d’auriculomidecine</em> no. 14 Jan 1979 Journal Article French
        France
      </p>
      <p>
        Rouxeuele Y. Quelques observations. <em>Revue d’auriculomedicine </em>
        no. 16 Jul 1979 Journal Article French France
      </p>
      <p>
        Rouxeuele Y. Trois observations. <em>Revue d’auriculomedicine</em> no.
        29 Oct l982 Journal Article French France<strong> </strong>
      </p>
      <p>
        Rouxeville Y. Quelques reflexions et remarques.{" "}
        <em>Revue d’auriculomedicine</em> no. 14 Jan 1979
      </p>
      <p>
        Saussus E. En revenant du Congres. <em>Revue d’auriculomedicine </em>no.
        12 Jul 1978 Journal Article French France
      </p>
      <p>
        Schneider R. Le point ” R ” de Bourdiol. <em>Revue d’auriculomedi</em>
        cine no. 31 Apr 1983 Journal Article French France
      </p>
      <p>
        Tournier Cinq cas d’auriculotherapie. <em>Revue d’auriculomedicine</em>{" "}
        no. 28 Jul 1982 Journal Article French France<strong> </strong>
      </p>
      <p>
        Van den BA. L’introduction i l’aycronto: diagnostic et therapeutique
        <em>
          . Annales du Premier Symposium International d’Auriculotherapy et
          d’Audculomedicine
        </em>{" "}
        Lyon France Haug editeur Bruxelles, 27,28,29 May 1994 GLEM
      </p>
      <p>
        Vigneron JL. Du port des bijoux au cours de l’examen en
        auriculomedicine. <em>Annates du G.L.E.M</em>. (1996)
      </p>
      <p>
        Viguie R. Observation de R. Viguie. <em>Revue d’auriculomedicine</em>{" "}
        no. 34 Jan 1984 Journal Article French France
      </p>
      <p>
        Villaverde JR, Enequez T. Entrevista a p. Nogier entrevue avec P. Nogier
        <em>. Biociencias revista de medicina integral</em>, 1985, no 1-2,
        184-194, 14
      </p>

      <h2 id="sec1dot4">1.4 Clinical Techniques and Procedures</h2>
      <p>
        Bahr FR. Methodes energetiques chinoises classiques et auriculomedicine
        <em>
          . Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000
      </p>
      <p>
        Bourdin D, Lesperres MJ, Fabre JJ, Castelain A. Stimulation des points
        d’acupuncture par une onde electromagnetique de tres haute frequence
        techniques et methodes. <em>Meridiens</em>,1985, no 69-70,185-190, ref
        1985 Acubase Disponible a la BIU de Nimes.
      </p>
      <p>
        Coblentz L. Auriculo-medecine et traitement des cicatrices.{" "}
        <em>Revue d’auriculomedicine</em> no. 6 Jan 1977 Journal Article French
        France
      </p>
      <p>
        Gomez OE. Uso de aguj as semipermanentes sus innovaciones una
        experiencia de quince.{" "}
        <em>
          Anos Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France: Haug editeur Bruxelles. 27,28,29 May 1994
      </p>
      <p>
        Julienne B, Mallard A. Nouvelles approches diagnostiques et
        therapeutiques. <em>Fascicule du Cours Superieur </em>no 8 Jan 1999
        Brochure French France
      </p>
      <p>
        Kiener E, Roths A. <em>Repertoire synthetiqu</em>e: acupuncture
        dentaire, auriculotherapie, reflexotherapie. Facio-Buccale
      </p>
      <p>
        Kovacs JH. <em>Votre oreille et ses secrets. </em>Retz, 1983 -1984. 1983
        -1984. Book French
      </p>
      <p>
        <em>Leclerc B. Precis</em> <em>d’auriculotherapie, tome I</em> (170
        pages). La technique, 1994. Auteur / GLEM 1994. Book French
      </p>
      <p>
        Lentz A. Technique des quatre systemes. <em>Annales du G.L.E.M.</em>{" "}
        (1996)
      </p>
      <p>
        Lentz A. Technique espace-temps brochure. Publiec par L’auteur 1995 book
        French
      </p>
      <p>
        Martinez FV. <em>Curso de tecnicas superiores en auriculomedina</em>.
        Proelsa SA mayo 1987 Proelsa SA p’ de Gracia 69 4′ dpcho 9 Barcelonna
        Spain, Espagne
      </p>
      <p>
        Nogier P, Gutierrez VJ. I{" "}
        <em>Mesa Nacional de auriculomedicina proelsa. </em>1987 Proelsa SA p de
        Gracia 69 4′ dpcho 9 Barcelonna Spain
      </p>
      <p>
        Nogier P. Le GIR 30. <em>Revue d’auriculomedicine</em> no. 23 Apr 1981
        Journal Article French France France
      </p>
      <p>
        Nogier P. Le GIR i curseur. <em>Revue d’auriculomedicine</em> no. 23
        Awil 1981 Journal Article French France
      </p>
      <p>
        Nogier P. Les rayons semi-coherents ou micro-lasers.{" "}
        <em>Revue d’auriculomedicine</em> no 6 Jan 1977 Journal Article French
        France
      </p>
      <p>
        Nogier P. L’utilisation des couleurs en auriculo-medecine.{" "}
        <em>Revue d’auriculomedicine</em> no 7 Apr 1977 Journal Article French
        France
      </p>
      <p>
        Nogier P. Plan de l’enseignement de l’auriculotherapie.{" "}
        <em>Revue d’auriculomedicine</em> no. 28 Jul 1982 Journal Article French
        France
      </p>
      <p>
        Nogier P. Un nouveau traitement de la spasmophilie.{" "}
        <em>Revue d’auriculomedicine</em> no. 2 Jan 1976 Journal Article French
        France
      </p>
      <p>
        Nogier R.{" "}
        <em>
          Introduction pratique a l’auriculo-medecine, la photo-perception
          cutanee.
        </em>{" "}
        Haug, 1993. Book French
      </p>
      <p>
        Piro C. Une nouvelle couleur qui semble interessante dans les troubles
        du sommeil <em>Revue d’auriculomedicine</em> no 14 Jan 1979 Journal
        Article French France
      </p>
      <p>
        Rouxeville Y. Etude de la recherche clectrique, etude des transferts.{" "}
        <em>Fascicule du Cours supeneur d’auriculomedecine</em> no. 6 May 98
        GLEM Brochure French France
      </p>
      <p>
        Schneider R. Une therapeutique improvisee.{" "}
        <em>Revue d’auriculomedicine</em> no. 31 Apr 1983 Journal Article French
        France
      </p>
      <p>
        Toureng JC. A propos de ” l’introduction pratique i 14 _{" "}
        <em>Revue d’auriculomedicine</em> no. 27 Apr 1982 Journal Article French
        France
      </p>
      <p>
        Vozianov AF, Pasechnikov SP, Kovtuniak ON. The laser reflexotherapy of
        patients with chronic prostatitis <em>Vrach Delo</em> 1991 Feb; (2):45-8
        Medfine 91280878 Journal article Russian USSR
      </p>
      <p>
        You F. <em>Pratique de l’acupuncture audculaire</em>. Satas, Belgique.
        <em> </em>
      </p>
      <p>
        <em> </em>
      </p>
      <p>
        <em> </em>Zhaohao W, Minghua L, Chichun C.{" "}
        <em>Pratique de l’acupuncture auriculaire.</em> Paris: Libraire You
        Feng. 1991
      </p>

      <h2 id="sec1dot5">
        1.5 Contraindications, Complications, Adverse Reactions
      </h2>
      <p>
        Allison G, Kravitz E. Letter: Auricular chondritis secondary to
        acupuncture. <em>New Engl J Med</em> 1975 Oct; 293 (15): 780 Medline
        76010689
      </p>
      <p>
        Bork K. Multiple lymphocytoma at the point of puncture as complication
        of acupuncture treatment. Traumatic origin of lymphocytoma.{" "}
        <em>Hautarzt</em> 1983 Oct-, 34 (10): 4 96-9 Medline 84060934 German
        <strong> </strong>
      </p>
      <p>
        Davis O, Powell W. Auricular perichondritis secondary to acupuncture.{" "}
        <em>Arch Otolaryngol</em> 1985 Nov 111 (11):770-1 Medline 86025050
      </p>
      <p>
        De Saboya R, Sylvia H. Metodologia da pesquisa clentifica nos transtomos
        psicoafetivos : um enfoque voltado para a integragao da auriculomedicina
        e da socionomia.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM Portugese
      </p>
      <p>
        Dervieux. <em>Dangers et miracles des boucies d’oreille.</em> Buchet
        Castel, 1984.
      </p>
      <p>
        Fayeton S. Les indications de l’auriculotherapy dans une clientele de
        generaliste. <em>Revue d’auriculomddecine</em> no. 15 Apr 1979 Journal
        Article French France
      </p>
      <p>
        Gilbert JG. Auricular complication of acupuncture.{" "}
        <em>New Engl Med J</em> 1987 Mar; 100(819):141-2 1987 Mar Medline
        88247023 <strong> </strong>
      </p>

      <p>
        Johansen M, Nielsen KO. Perichondritis of the ear caused by acupuncture.{" "}
        <em>Ugeskrifi for Laeger</em> 1990 no. 3 p. 152.
      </p>
      <p>
        Peacher WG. Adverse reactions, contraindications and complications of
        acupuncture and moxibustion. <em>Amer J Chin Med</em> 1975 Jan 3 (l):
        35-46 Medline 75125792 Journal article Review Eng
      </p>
      <p>
        Rouxeville Y. Approche du dilemme “cause ou consequence”en
        auriculotherapy (avec I’agiscop) et en auriculomedicine (avec le gir
        30). Site Internet du GLEM 1998
      </p>
      <p>
        Savage Jones H. Auricular complications of acupuncture.{" "}
        <em>J Laryngol Otol</em> 1985 Nov; 99 (11): 1143-5 Medline 86035800
      </p>
      <p>
        Sorensen T. Auricular perichondritis caused by acupuncture therapy
        (letter) <em>Ugeskr Laeger</em> 1990 Mar; 152 (11): 752-3 Medline
        90208962 Danish
      </p>
      <p>
        Tang C. Treatment of adverse reactions following facial cosmetic
        surgical abrasion with auricular pellet pressure.{" "}
        <em>J Tradit Chin Med</em> 1990 Sep; 10 (3): 196-8 Medline 91116906
      </p>
      <p>
        Umeh B. Ear acupuncture using semi-permanent needles: acceptability,
        prospects and problems in Nigeria. <em>Amer J Chin Med</em> 1988; 16
        (1-2): 67-70 Medline 89116128
      </p>

      <h2 id="sec1dot6">1.6 General Editorials and Letters to the Editor</h2>
      <p>
        Ackerman JM. Letter to the Editor: Bio-Information.{" "}
        <em>Frontier Perspectives</em> 1994 Vol. 4, No, 1 p. 4 e{" "}
        <em>Revue d’auriculomedicine</em> no. 23 Apr 1981 Journal Article French
        France
      </p>
      <p>
        Magnin P. Editorial (suite). <em>Revue d’auriculomedicine</em> no. 5 Oct
        1976 Journal Article French France
      </p>
      <p>
        Magnin P. Editorial. <em>Revue d’auriculomedicine</em> no. 3 Apr 1976
        Journal Article French France
      </p>
      <p>
        Magnin P. Editorial: La medecine de demain.{" "}
        <em>Revue d’auriculomedicine</em> no 4 Juil 76 Journal Article French
        France
      </p>
      <p>
        Magnin P. Vers une medicine plus humaine{" "}
        <em>Revue d’auriculomedicine</em> no. 17 Oct 1979 Journal Article French
        France
      </p>
      <p>
        Magnin P. Editorial (suite et fin) <em>Revue d’auriculomedicine</em> no.
        6 Jan 1977 Journal Article French France
      </p>
      <p>
        Magnin P. Editorial: L’auriculo-medecine vue par le Recteur P. Magnin
        (suite et fin) <em>Revue d’auriculomedicine</em> no. 13 Oct 1978 Journal
        Article French France
      </p>
      <p>
        Magnin P. Editorial: L’auriculo-medicine vue par le Recteur P. Magnin{" "}
        <em>Revue d’auriculomedicine</em> no. 12 Jul 78 Journal Article French
        France
      </p>
      <p>
        Magnin P. Editorial-Vers une medicine plus humaine (suite et fin){" "}
        <em>Revue d’auriculomedicine</em> no. 18 Jan 1980 Journal Article French
        France
      </p>
      <p>
        Nogier P. A propos d’un anniversaire. <em>Revue d’auriculomedicine</em>{" "}
        no. 21 Oct 1980 Journal Article French France
      </p>
      <p>
        Nogier P. Coup d’dventail sur l’auriculomedicine.{" "}
        <em>
          Annales du Prernier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France: Haug editeur Bruxelles. 27,28,29 May 1994 GLEM French
      </p>
      <p>
        Nogier P. Editorial. <em>Revue d’auriculomedicine</em> no 28 Jul 1982
        Journal Article French France
      </p>
      <p>
        Nogier P. Editorial. <em>Revue d’auriculomedicine</em> no 30 Jan 1983
        Journal Article French France
      </p>
      <p>
        Nogier P. Editorial. <em>Revue d’auriculomedicine</em> no 31 Apr 1983
        Journal Article French France<em> </em>
      </p>
      <p>
        <em> </em>
      </p>
      <p>
        <em> </em>Nogier P. Editorial. <em>Revue d’auriculomedicine</em> no. 20
        Jul 1980 Journal Article French France
      </p>
      <p>
        Nogier P. Editorial. <em>Revue d’auriculomedicine</em> no. 22 Jan 1981
        Journal Article French France
      </p>
      <p>
        Nogier P. Editorial. <em>Revue d’auriculomedicine</em> no 32 Jul 1983
        Journal Article French France
      </p>
      <p>
        Nogier P. Editorial: auriculo-mddecine et acupuncture.{" "}
        <em>Revue d’auriculomedicine</em> no 8 Jul 1977 Journal Article French
        France
      </p>
      <p>
        Nogier P. Editorial: Problemes actuels vus i travers
        l’auriculo-medicine. Chapitre II.-Le malade et ses mddicaments.{" "}
        <em>Revue d’auriculomedicine</em> no 10 Jan 1978 Journal Article France
      </p>
      <p>
        Nogier P. Editorial: Un anniversaire. <em>Revue d’auriculomedicine</em>{" "}
        no. 19 Apr 1980 Journal Article French France
      </p>
      <p>
        Nogier P. Face to face with auriculotherapy [letter].{" "}
        <em>Acupunct Electrother Res</em> 1983 8 (l): 99-100
      </p>
      <p>
        Nogier P. Face to face with auriculotherapy [letter].{" "}
        <em>Acupunct Electrother Res</em> 1983 8 (l) 99-100 Medline English
      </p>
      <p>
        Nogier P. Problemes actuels vus i travers l’auriculo-medicine. Chapitre
        Ill.-Le souci de I’autre pour le medecin.{" "}
        <em>Revue d’auriculomedicine</em> no I I Apr 1978 Journal Article France
      </p>
      <p>
        Nogier P. To speak on anniversary purpose.{" "}
        <em>Revue d’auriculomedicine</em> no. 21 Oct 1980 Journal Article French
        France
      </p>
      <p>
        Rouxeville Y. Rapport de la commission acupuncture auriculaire.{" "}
        <em>Congres FAFORMEC Nimes</em> 1998
      </p>

      <h2 id="sec2dot1">2.1 Clinical Research Methods</h2>
      <p>
        Bahr FR. Les origines de la methode: documents chinois.{" "}
        <em>Revue d’auriculomedicine</em> no. I Sept 1975 Journal Article French
        France
      </p>
      <p>
        Oleson T. Treatment outcome research in auriculotherapy.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Audculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 English GLEM
      </p>

      <h2 id="sec2dot2">2.2 Systematic Reviews and Meta-Analyses</h2>
      <p>
        Chen H. Recent studies on auriculoacupuncture and its mechanism.{" "}
        <em>J Tradit Chin Med</em> 1993 Jun 13(2): 129-43 Medline 94017931
        Journal article English China
      </p>
      <p>
        Inconnu .{" "}
        <em>
          NIH Consensus Development Conference on Acupuncture program and
          Abstracts
        </em>
        . 1997 November 3 5, National Institute of Health, Office of the
        Director, Continuing Medical Education, Bethesda, Maryland
      </p>
      <p>
        Riet G, Kleijnen J., Knipschild P. A meta-analysis of studies into the
        effect of acupuncture on addiction.{" "}
        <em>British J of General Practice</em> September, 1990 Vol. 40, pp.
        379-382.
      </p>
      <p>
        Russell J, Erickson MD.{" "}
        <em>Bibliography review of acupuncture articles in English</em>
      </p>

      <h2 id="sec2dot3">
        2.3 Surveys of Patients and Practitioners, Qualitative Research
      </h2>
      <p>
        Rouxeville Y. La situation de l’acupuncture auriculaire en France en
        1999. Une enquete de satisfaction relative aux pratiques et a l’opinion
        des medecins pratiquant enfrance en 1999.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000 Lyon
        </em>{" "}
        France 26,27,28 May 2000 GLEM French
      </p>

      <h2 id="sec2dot4">
        2.4 Auricular Diagnosis, Tongue Diagnosis, Oriental Pulse Diagnosis,
        Skin Color
      </h2>
      <p>
        Ikezono E. Objective analysis of ear acupuncture by biological methods
        and pulse diagnosis
        <em>
          . Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France: 27,28,29 May 1994 GLEM French
      </p>
      <p>
        Ikezono E. Objective digital analysis of pulse diagnosis using tonometry
        <em>
          . Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May GLEM English
      </p>
      <p>
        Nogier P. Un diagnostic i distance. <em>Revue d’auriculomedicine.</em>{" "}
        no. 11 Apr 1978 Journal Article French France
      </p>
      <p>
        Omura Y. New simple early diagnostic methods using Omuras “Bi-Digital
        O-Ring Dysfunction Localization Method” and acupuncture organ
        representation points, and their applications to the “drug and food
        compatibility test” for individual organs and to auricular diagnosis of
        internal organs. part 1. <em>Acupunct Electrother Res</em> 1981; 6 (4):
        23 954 Medline 82226927 English
      </p>
      <p>
        Portnov FG. Neurocybemetic concept of electropuncture auricular
        diagnosis and auricular therapy /concept neurocybemetiwue de I
        electropuncture auriculo diagnostic et auriculotheraphie .{" "}
        <em>Scandinavian J of acupuncture and electrotherapy</em>, 1992,vol.7,
        no 3-4, 91-93 English
      </p>
      <p>
        Portnov FG. Neurocybernetic concept of electropuncture auricular
        diagnosis and auricular therapy.{" "}
        <em>Scandinavian J of Acupuncture and Electrotherapy</em>,1992, vol.7,
        no3-4, 91-93 1992 Acubase Disponible a la BIU de Nimes, FAX (33/0) 4 66
        23 66 52, indiquer la Reference : English
      </p>
      <p>
        Riviere A. Auriculo-diagnostic. <em>Revue d’auriculomedicine</em> no 17
        Oct 1979 Journal Article French France
      </p>
      <p>
        Romoli M, Vettori F. Preliminary considerations on changes in
        pigmentation structure and vascularization of the outer ear in relation
        to chronic organic of functional disease. <em>Minerva Medica.</em> 1982
        Mar 31. 73
      </p>
      <p>
        Saku K, Mukaino Y, Ying H, Arakawa K. Characteristics of reactive
        electropermeable points on the auricles of coronary heart disease
        patients. <em>Clin Cardiol</em> 1993 May 16(5) 415-9.
      </p>
      <p>
        Timoschevski S. Metrological standardisation of pulse diagnostics
        methods by means of a new laser electronic pulse sensor, VAS research
        and classification of observable pulse reactions.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM English
      </p>
      <p>
        Vichniakova I. Le systeme d’information et de diagnostic auriculaire
        assists par ordinateur ” ACUS quatre ans de developpement.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapie et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM French
      </p>

      <h2 id="sec2dot5">
        2.5 Auricular Medicine, VAS, RAC, Nogier Phases, Dental Foci,
        Laterality, Oscillations
      </h2>
      <p>
        Ackerman JM, Lewis WM. Integration of VAS techniques with traditional
        Western medical techniques.{" "}
        <em>Coherence : International J of Integrated Medicine</em> ISSN
        1565-0138.
      </p>
      <p>
        Ackerman JM. Navach’s auricular medicine discoveries and beyond.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        2000 Lyon France 26,27,28 May 2000 GLEM Lyon Abstract de Congress
        English
      </p>
      <p>
        Ackerman JM. Navach’s biochemical and neurophysiologic aspects of the
        VAS
        <em>
          . International Consensus Conference on Acupuncture, Auriculotherapy
          and Auricular Medicine
        </em>{" "}
        Las Vegas, Nevada, August 12-16, 1999 1999 99 Conference Manual, pp.
        51-57.
      </p>
      <p>
        Ackerman JM. Proceedings of energy fields in medicine: a study of device
        technology based on acupuncture meridians and chi energy. 1988, The John
        E. Fetzer Foundation, Kalamazoo, Michigan.
      </p>
      <p>
        Ackerman JM. The biophysics and neurochemistry of the VAS : its
        relationship to healing (part one){" "}
        <em>Coherence 2/98 International J of Integrated Medicine</em> 1998 Part
        1: February, 1998; Part 11: January, 1999 issn 1565-0138 Journal Article
        English Netherlands
      </p>
      <p>
        Ackerman JM. The biophysics of the VAS, Chapter 1″, “The Phenomenon of
        Healing, Chapter 11, “Integration of VAS Techniques with Western Medical
        Techniques, Chapter III” (with Walter M. Lewis, M.D.). The John E.
        Fetzer Foundation, 9292 West KL Avenue, Kalamazoo, Michigan 49009, 1989
      </p>
      <p>
        Araripe Leda de Alencar C Andrade. Auricular medicine and
        psychopathology : a link among the major psychiatrics syndromes, the
        Torti’s phases and the phases of the emotional development of the
        individual in asocionomic view
        <em>
          . Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 English
      </p>
      <p>
        Bahr FR.{" "}
        <em>Riehrbuchreihe wissenschaftlich akupunktur und aurikulomedizin.</em>{" "}
        Verlag fur Medizin, Heidelberg, 1978
      </p>
      <p>
        Banos A. Le reflexe auriculo cardiaque comme moyen de diagnostic dans la
        pathologie abdominale.{" "}
        <em>Annales de la Societe d’Acupuncture d’Aquitaine</em>, 1992, no 13,
        37-42
      </p>
      <p>
        Banos A. L’utilisation du reflexe auriculo cardiaque dans le diagnostic
        en acupuncture.{" "}
        <em>Annales de la Societe d’Acupuncture d’Aquitaine.</em> 1989, no 5,
        1-6 Acubase Disponible a la BIU de Nimes
      </p>
      <p>
        Blanchon J. La medicine auriculaire : croyance ou science.{" "}
        <em>Annales du G.L.E.M</em>. (1995)
      </p>
      <p>
        Bourdiol R.J.{" "}
        <em>
          Le systeme nerveux en auriculo-medicine (suite). Revue
          d’auriculomedicine
        </em>{" "}
        no 9 Oct 1977 Journal Article French France
      </p>
      <p>
        Bourdiol RJ, Serfati M. <em>L’auriculo –somatotologie.</em> Maisonneuve,
        1981. 264 pages Book French
      </p>
      <p>
        Braemer C. Importance des foyers. <em>Revue d’auriculomedicine</em> no.
        26 Jan 1982 Journal Article French France
      </p>
      <p>
        Bricot B. Enregistrement du RAC. <em>Revue d’auriculomedicine.</em> no.
        12 Jul 78 Journal Article French France
      </p>
      <p>
        Chiollaz M, Larcher J. Etude du VAS par analyse spectrale.{" "}
        <em>Revue d’auriculomedicine</em> no 20 Jul 1980 (Travaux de M. Chiollaz
        et J. Larcher, ingenieurs en Traitement du Signal) (Service de B.
        Escudie, I.C.P.I.) Journal Article French
      </p>
      <p>
        Coutte A, Nogier R. Objectivite clinique du VAS.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM French
      </p>
      <p>
        Couture L. La lateralite et l’auriculomedecine a laterality and
        auricular medicine
        <em>
          . Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedecine
        </em>{" "}
        Lyon France : 27,28,29 May 1994 GLEM French
      </p>
      <p>
        Dassonville G. Histoire du collier toxique.{" "}
        <em>Sciences et Medecines Nouvelles</em> No I 1989 GLEM Journal Article
        French Cable Edition
      </p>
      <p>
        De Sousa A. Reflexions sur la reponse autonome circulatoire (ou RAC
        <em>
          ). Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France 27,28,29 May 1994 GLEM French
      </p>
      <p>
        Fayeton S. Au sujet de la lateralite. <em>Revue d’auriculomedicine</em>{" "}
        no. 13 Oct l978 Journal Article French France
      </p>
      <p>
        Fayeton S. Lateralite et orientation. <em>Revue d’auriculomedicine</em>{" "}
        no. 17 Oct 1979 JournalArticle French France
      </p>
      <p>
        Fiches G. Les frequences du Dr. Paul Nogier aux mecanismes
        physiologiques et patholoeques.{" "}
        <em>
          Annales du Premier Symposium International d’Auriculothdrapie et
          d’Auriculomedicine
        </em>{" "}
        Lyon France: 27,28,29 May 1994 GLEM French<strong> </strong>
      </p>
      <p>
        Fiches G. Un ” point maftre ” de 1’epiphyse.{" "}
        <em>Revue d’auriculomedicine</em> no. Jul 1983 Journal Article French
        France France
      </p>
      <p>
        Frinerman E, Dvorkin E. Is an “angiometric test” an adequate test for
        registering the vascular autonomic signal ? <em>Coherence</em> 1998
        Journal Article English Netherlands
      </p>
      <p>
        Frinerman E, Dvorkin E. Vascular autonomic signal (VAS): perspectives of
        computerized machinery registration
        <em>
          . International J of Auricular Medicine : 2nd annual conference of the
          medical society of acupunture of the Israeli Medical Association
        </em>{" "}
        1995 Bat-Yam, Israel English
      </p>
      <p>
        Granja CW, Eduardo Torti E. Phases and points of human psychism in
        auricular medicine: an integrative approach. Universal holographic
        cronosplatia -. an approachof human being comprehension on a pluri
        referential focusing.{" "}
        <em>
          Annates du Troisieme Symposium International d’Auriculotherapy et
          d’Audculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM
      </p>
      <p>
        Granja CW. A graduation course in auricular medicine and
        auriculotherapy: A socionomic proposal.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 English
      </p>
      <p>
        Habersack WG. Auriculomedicine-auriculotherapy. <em>Zahnarzt</em>, 1975
        Sep, 19:9, 348-50 Journal article German Germany{" "}
        <strong>Abstract </strong>
      </p>
      <p>
        Haubursin P. Bloce vertebral aigu et polarion unidirectionnel.{" "}
        <em>Revue d’auriculomedicine</em> no. 32 Jul 1983 Journal Article French
        France
      </p>
      <p>
        Haubursin P. Contractures. <em>Revue d’auriculomedicine</em> no. 32 Jul
        1983 Journal Article French France
      </p>
      <p>
        Haubursin P. Contusion et polartron. <em>Revue d’auriculomedicine</em>{" "}
        no. 32 Jul 1983 Journal Article French France
      </p>
      <p>
        Henry JC. Approche methodologique pour la mise en evidence du VAS (RAC).{" "}
        <em>Revue d’auriculomedicine</em> no. 18 Jan 1980 France
      </p>
      <p>
        Hofman SW. Energy reactivity detection with melanin (m) and
        “anti-melanin” (am) hypothesis. <em>Coherence</em> 1998 English
        Netherlands
      </p>
      <p>
        Hofman SW. Measurement of medication/intoxication effect, in vivo, using
        filter 15 (and the vas) 167 coherence 1/98 : The 2nd international
        IAAMER congress on: auricular diagnostics and therapy Oisterwijk, The
        Netherlands September 19-21, 1997 Oisterwijk, The Netherlands issn
        1565-0138 Gouda, The Netherlands Abstract de congres/Congress English
        Netherlands
      </p>
      <p>
        Hofman SW. The three tissue layers, new perspectives with precious
        stones.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM English
      </p>
      <p>
        Juliennc B, Mallard A. Mise ijour des localisations ectodermiques en
        phase 1, phase 2, et phase 3. <em>Annales du G.L.E.M.</em> (1998)
      </p>
      <p>
        Julienne B, Mallard A, Fiches G. Etude des relations entre
        auriculomedecine et substances homeopathiques, phytotherapiques,
        litotherapiques ainsi que granions et oligosols.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine </em>no 3 May 1997
        Brochure French France
      </p>
      <p>
        Julienne B, Mallard A, Fiches G. Un univers vibratoire.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine </em>no 3 May 1997
        Brochure French France
      </p>
      <p>
        Julienne B, Mallard A. Affections chroniques, zones exclues.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine </em>no 8 Jan 1999
        Brochure French France
      </p>
      <p>
        Julienne B, Mallard A. Correspondance entre les filtres couleurs Lee et
        aaes couleurs Kodak wratten boles anneaux tests tissulaires d’origine
        ectodermique -En fonction des deux e1ements precedents = utilisation des
        filtres couleurs Lee pour une approche diagnostique et therapeutique{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine </em>no 10 Oct 1999
        Brochure French France
      </p>
      <p>
        Julienne B, Mallard A. Filtres couleurs, filtres de phase, filtres de
        frontiers. <em>Fascicule du Cours Superieur d’Auriculomedecine </em>May
        1998 Brochure French France
      </p>
      <p>
        Julienne B, Mallard A. Le recruteur, locahsation en phase I du mesoderme
        et de 1’endoderme.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine</em> no 6 May 98
        Brochure French France
      </p>
      <p>
        Julienne B, Mallard A. Les differentes phases audculaires et
        periauriculaires, hypotheses concemant leur nombre et leur roble,
        applications diagnostiques et therapeutiques{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine </em>no 7 Oct 1998,
        Brochure French France
      </p>
      <p>
        Julienne B, Mallard A. Les representations reflexes auriculaires et
        periauriculaires etudiees par leurs correspondences frequentielles au
        moyen du Gir 30/ girlase et des couleurs Kodak Wratten selectionnees
        initialement par le Docteur Paul Nogier et coelaborateurs.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine </em>no 9 Juin 1999
        Brochure French France
      </p>
      <p>
        Julienne B, Mallard A. Les representations reflexes auriculaires et
        periauriculaires etudiees par leurs correspondences frequentielles, au
        moyen du Gir 30, Girlase et des couleurs Kodak Wratten.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 French
      </p>
      <p>
        Julienne B, Mallard A. Representation reflexes auriculaires du systeme
        nerveux central, du systeme nerveux vegetatif et des nerfs craniens.
        Representation reflexe auriculaire de ces trois systemes.
        <em> Fascicule du Cours Superieur d’Auriculomedecine</em> no 5 Jan 1998
        Brochure French France
      </p>
      <p>
        Julienne B, Mallard A. Representations reflexes de la region
        penauriculaire, en fonction de leur nature embryologique.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine </em>no 10 Oct 1999
        Brochure French France
      </p>
      <p>
        Julienne B, Mallard A. Representations reflexes ectodermiques,
        mesodermiques endodermiques dans les phases 1, 2,3.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine</em> no 8 Jan 1999
        Brochure French France
      </p>
      <p>
        Julienne B, Mallard A. Tous les points de fonction, definition,
        localisation -quelques points macitres.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine</em> no 8 Jan 1999
        Brochure French France
      </p>
      <p>
        Julienne B, Mallard A. Veux approches differentes de l’examen
        auriculaire i l’aide de: Vies neuromediateurs et les huiles essentielles
        2Aes acides amines.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine</em> no 9 Juin 1999,
        Brochure French France
      </p>
      <p>
        Julienne B. Mallard A. Relation auriculomedecine et acupuncture.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine</em> no. 2 Jan 1997
        Brochure French
      </p>
      <p>
        Julienne B; Mallard A. Les quatre forces qui regissent l’univers, les
        eaux dites miraculeuses, application i I’auriculo.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine</em> go 4 Novembre
        l997 GLEM, Brochure French France
      </p>
      <p>
        Julienne D, Mallard A. Deux abords differents de 1’examen du malade.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine </em>no 7 Oct 1998
        Brochure French France
      </p>
      <p>
        Jullenne B, Mallard A. Les representations reflexes auriculaires et
        periauriculaires des principaux tissus et organcs humains, en fonction
        de leur nature embryologique.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 French
      </p>
      <p>
        Klowersa R. L’importance pratique des localisations neurologiques du
        pavilion de l’oreille.{" "}
        <em>
          Annates du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 French
      </p>
      <p>
        Korthout A. Symptom-shift as a result of auriculotherapeutic
        intervention<em>. International J of Auricular Medicine</em> (IJAM) 1996
      </p>
      <p>
        La Ferla D, Romoli M. La sensation progagde : nouvelle frontiere pour
        l’auriculotherapy.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 French
      </p>
      <p>
        Leib S. Die Bioresonanztherapie (BRT) in{" "}
        <em>Auriculomedizin J of Auriculomedicine and Auriculopuncture</em>.
        Israel. 1991 N. 42 3-6 Limonat de Kerimet Note sur le diagnostic et le
        traitement des sutures criniennes. <em>Revue d’auriculomedicine</em> no.
        35 Apr 1984 Journal Article French France
      </p>
      <p>
        Leib S. Die drei funktionellen schichten Nogier’s und ihke
        kontrollpunkte<em>. J of Auricular Medicine And Acupuncture </em>1990 N
        3 4-7
      </p>
      <p>
        Lentz A. Considerations sur la prise du V _ S.{" "}
        <em>Bulletin de liaison de I’AMA</em>BF no. 5 Jun 1983
      </p>
      <p>
        Lentz A. Detection des energies parasympathique et sympathique avec les
        filtres 9, 64 et 44 A <em>Revue d’audculomedicine</em> no. 16 Jul 1979
        Journal Article French France
      </p>
      <p>
        Lentz A. Le blocage energetique. <em>Bulletin de liaison de I’AMABF</em>{" "}
        no. 7 Sept 1984 Jul 1983 Journal Article French France
      </p>
      <p>
        Lentz A. Les alos de la recherche en auriculomedecine.{" "}
        <em>Annales du G.L.E.M</em>. (1997) 63
      </p>
      <p>
        Magnin P. Di scours d’ouverture : L’auriculomedicine, son rele et sa
        place en medicine d’aujourd’hui.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM French
      </p>
      <p>
        Magnin P. L’auriculomedicine vue par le Recteur P. Magnin{" "}
        <em>Revue d’auriculomedicine</em> no. 21 Oct 1980 Journal Article French
        France
      </p>
      <p>
        Marignan M, Vulliez C. Le VAS enfin elucide ?{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 Mar 2000 GLEM
      </p>
      <p>
        Marignan M. Comment mettre en pratique certaines acquisitions de
        I’auriculomedecine en auriculotherapie{" "}
        <em>Bulletin Scientifique du GLEM</em> n’2 Journal Article French
      </p>
      <p>
        Martinez FV. <em>Los filtros, las tourelles novedas.</em> Proelsa SA
        Abril 1989 Proelsa SA p’ de Gracia 69 4′ dpcho 9 Barcelonna Spain
      </p>
      <p>
        Mastalier O. Diagnostic and treatment of disturbance fields using
        auriculomedicine. Abstracts of{" "}
        <em>ICMART’99 International Medical Acupuncture Symposium</em>
      </p>
      <p>
        Migneron JL. Filtres testeurs ( mise A jour ), proprietes des
        frontieres, etude du 44 A et 49 B{" "}
        <em>Fascicule du Cours superieur d’auriculomedecine</em> no. 9 Juin 1999
        GLEM Brochure French France
      </p>
      <p>
        Navach JH. Clinical correlation of the vascular autonomic system pulse
        <em>
          . First International Congress on Acupuncture and Auricular Medicine
        </em>
        , Mallorca, Spain September 20, 1980.
      </p>
      <p>
        Navach JH. Computer analysis of the VAS monitor pulse. VIII
        <em>. Germano-Latino Congress on Auricular Medicine</em>, Lyon, France
        September 11, 1981
      </p>
      <p>
        Navach JH. Illustrations of six additional acupuncture phases, anatomic
        representations and the biochemical mechanism of acupuncture points.{" "}
        <em>Nogier Seminar</em>, Montreal, Quebec October, 1984
      </p>
      <p>
        Navach JH. Infrared photo pulse sensor and dopplar investigation of the
        autonomic vascular system
        <em>
          . First International Congress of Acupuncture and Auriculo-Medicine
        </em>
        , Mallorca, Spain, September 19, 1980. 1980
      </p>
      <p>
        Navach JH. Measuring the physiological functions comprising the vascular
        autonomic system”.VIII Germano-Latino Congress on Auricular Medicine,
        Lyon, France September 10, 1981.
      </p>
      <p>
        Navach JH. The vascular autonomic system pulse, recording techniques
        <em>
          . First International Congress of Acupuncture and Auricular Medicine,
        </em>{" "}
        Mallorca, Spain September 19, 1980.
      </p>
      <p>
        Navach JH. The vascular autonomic system, physics and physiology. The
        VIII<em>. Germano-Latino Congress on Auricular Medicine</em>, Lyon,
        France September II, 1981
      </p>
      <p>
        Netland J. Le signal du pouts et sa capacite informatique.{" "}
        <em>Annales du G.L.E.M</em>. (1998)
      </p>
      <p>
        Niboyet JE. Les points d’acupuncture : notions electriques,
        histologiques et leurs debouches en neurophysiologie.{" "}
        <em>Cahiers de Biotherapie</em> no. 67 (1980)
      </p>
      <p>
        Niboyet JE. Rapport au ministre de la sante concernant les medicines
        alternatives. <em>Paes</em>, 1984. Book French
      </p>
      <p>
        Noger P. Gradient energetique. <em>Revue d’auriculomedicine</em> no. 30
        Jan 1983 Journal Article French France
      </p>
      <p>
        Nogier P. Action de la noradrenaline et de l’acetylchoine sur les
        informations du pavilion. <em>Revue d’auriculomedicine</em> no 14 Jan
        1979 Journal Article France
      </p>
      <p>
        Nogier P. Aires reflexes du pavilion. <em>Revue d’auriculomedicine</em>{" "}
        no. 4 Jul 1976 Journal Article French France
      </p>
      <p>
        Nogier P. Code employe sur les schemas.{" "}
        <em>Revue d’auriculomedicine</em> no. 2 Jan 1976 Journal Article French
        France
      </p>
      <p>
        Nogier P. Code employe sur les schemas.{" "}
        <em>Revue d’auriculomedicine</em> no. 2 Janv 1976 Journal Article French
        France
      </p>
      <p>
        Nogier P. Connaissance pratique du RAC.{" "}
        <em>Revue d’auriculomedicine</em> no. 13 Oct 1978 Journal Article French
        France
      </p>
      <p>
        Nogier P. Coup d’eventail sur l’auriculomedicine.{" "}
        <em>
          Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        France: 27,28,29 May 1994 GLEM French
      </p>
      <p>
        Nogier P. De I’auriculotherapie a I’auriculo-medecine.{" "}
        <em>Revue d’auriculomedicine</em> no. 7 Apr 1977 Journal Article French
        France
      </p>
      <p>
        Nogier P. <em>De l’auriculotherapie a l’auriculo medecine</em>.
        Maisonneuve, 1981. Book French
      </p>
      <p>
        Nogier P. De l’auriculotherapie a l’auriculo-medecine.{" "}
        <em>Revue d’auriculomedicine</em> no. 7 Apr 1977 Journal Article France
      </p>
      <p>
        Nogier P. De l’auriculotherapie a l’auriculomedecine.{" "}
        <em>Revue d’auriculomedicine</em> no. 21 Oct 1980 Journal Article French
        France
      </p>
      <p>
        Nogier P. Diagnostic et traitement des desequilibres neurovegetatifs.{" "}
        <em>Revue d’auriculomedicine </em>no. 14 Jan 1979 Journal Article French
        France
      </p>
      <p>
        Nogier P. Eneree, phases et lateralite <em>Revue d’auriculomedicine</em>{" "}
        no. 19 Apr 1980 Journal Article French France
      </p>
      <p>
        Nogier P. Etes-vous lateralise? <em>Revue d’auriculomedicine</em> no 14
        Jan 1979 Journal Article French France
      </p>
      <p>
        Nogier P. Etude des localisations nouvelles: ACTH-Cortisol.{" "}
        <em>Revue d’auriculomedicine</em> no. 22 Jan 1981 Journal Article French
        France
      </p>
      <p>
        Nogier P. Heredite et points genetiques.{" "}
        <em>Revue d’auriculomedicine</em> no. 24 Jul 1981 Journal Article French
        France
      </p>
      <p>
        Nogier P. Innervation de la plage F. <em>Revue d’auriculomedicine</em>{" "}
        no. 14 Jan 1979 Journal Article French France
      </p>
      <p>
        Nogier P. La perception du VAS. <em>Revue d’auriculomedicine</em> no. 28
        Jul 1982 Journal Article French France
      </p>
      <p>
        Nogier P. La recherche en auriculo-medicine.{" "}
        <em>Revue d’auriculomedicine</em> no 13 Oct l978 Journal Article French
        France
      </p>
      <p>
        Nogier P. Le RAC ou le VAS. <em>Revue d’auriculomedicine</em> no. 12 Jul
        1978 Journal Article French France
      </p>
      <p>
        Nogier P. Les localisations nouvelles. <em>Revue d’auriculomedicine</em>{" "}
        no. 24 Jul 1981 Journal Article French France
      </p>
      <p>
        Nogier P. Les oscillations. <em>Revue d’auriculomedicine</em> no 10 Jan
        1978 Journal Article French France
      </p>
      <p>
        Nogier P. L’evolution de la pratique medicale en auriculo-medecine.{" "}
        <em>Revue d’auriculomedicine</em> no. 5 Oct 1976 Journal Article French
        France
      </p>
      <p>
        Nogier P. L’evolution de la pratique medicale en auriculo-medecine.{" "}
        <em>Revue d’auriculomedicine</em> no. 5 Oct 1976 Journal Article French
        France
      </p>
      <p>
        Nogier P. Localisations nouvelles. <em>Revue d’auriculomedicine</em> no.
        26 Jan 1982 Journal Article French France
      </p>
      <p>
        Nogier P. Mise en evidence de 1’energie reticulee par les tests a
        l’aveugle. <em>Revue d’auriculomedicine</em> no. 29 Oct l982 Journal
        Article France
      </p>
      <p>
        Nogier P. Penthonium et systeme neuro-vegetatif.{" "}
        <em>Revue d’auriculomedicine</em> no 17 Oct 1979 Journal Article French
        France
      </p>
      <p>
        Nogier P. Peut-on identifier le sexe au pavilion?{" "}
        <em>Revue d’auriculomedicine</em> no 8 Jul 1977 Journal Article French
        France
      </p>
      <p>
        Nogier P. Points biotiques et points antibiotiques.{" "}
        <em>Revue d’auriculomedicine</em> no 8 Jul 1977 Journal Article French
        France
      </p>
      <p>
        Nogier P. Points reactifs et points ” reserve .”{" "}
        <em>Revue d’auriculomedicine</em> no. 30 Jan 1983 Journal Article French
        France
      </p>
      <p>
        Nogier P. Principes et applications i la correction des reseaux.{" "}
        <em>Revue d’auriculomedicine</em> no 15 Apr 1979 Journal Article
        French/Francais France
      </p>
      <p>
        Nogier P. Prise du pouls et filtre. <em>Revue d’auriculomedicine</em>{" "}
        no. 34 Jan 1984 Journal Article French France
      </p>
      <p>
        Nogier P. Quel est le mecanisme d’action d’un filtre pose sur la peau?{" "}
        <em>Revue d’auriculomedicine</em> no 8 Jul 1977 Journal Article France
      </p>
      <p>
        Nogier P. Qu’est-ce que I’auriculo-medecine ? ..{" "}
        <em>Revue d’auriculomedicine</em> no I Sept 1975 Journal Article French
        France
      </p>
      <p>
        Nogier P. Qu’est-ce que l’auriculomedecine?{" "}
        <em>Revue d’auriculomedicine</em> no. 21 Oct 1980 Journal Article French
        France
      </p>
      <p>
        Nogier P. Qu’est-ce qu’un champ magnetique polarise ?{" "}
        <em>Revue d’auriculomedicine</em> no. 15 Apr 1979 Journal Article French
        France
      </p>
      <p>
        Nogier P. Reactions du centre et de la peripherie et interpretation des
        modifications produites par la pose de penthonium sur le bras et sur le
        front. <em>Revue d’auriculomedicine</em> no 17 Oct 1979 Journal Article
        French France
      </p>
      <p>
        Nogier P. Reponses i un confrere et recherches personnelles.{" "}
        <em>Revue d’auriculomedicine</em> no. 13 Oct 1978 Journal Article French
        France
      </p>
      <p>
        Nogier P. Revolution dans les localisations auriculaires.{" "}
        <em>Revue d’auriculomedicine</em> no. 15 Apr 1979 Journal Article French
        France
      </p>
      <p>
        Nogier P. Theralaser et frequence F. <em>Revue d’auriculomedicine</em>{" "}
        no 13 Oct l978 Journal Article French France
      </p>
      <p>
        Nogier P. Traitement du terrain en canirologie.{" "}
        <em>Revue d’auriculomedicine</em> no. 22 Jan 1981 Journal Article French
        France
      </p>
      <p>
        Nogier P. Travaux originaux-Nouvelle methode pour faciliter les
        manipulations vertebrates. <em>Revue d’auriculomedicine</em> no. 17 Oct
        1979 Journal Article French France.
      </p>
      <p>
        Nogier P. Un correctif-. A propos des frequences D et E.{" "}
        <em>Revue d’auriculomedicine</em> no 7 Apr 1977 JournalArticle French
        France
      </p>
      <p>
        Nogier P. Un point aux effets multiples: le point dit ” genetique.”{" "}
        <em>Revue d’auriculomedicine</em> no. 22 Jan 1981 Journal Article France
      </p>
      <p>
        Nogier P. Une nouvelle approche du V _ S. (suite).{" "}
        <em>Revue d’auriculomedicine</em> no. 20 Jul 1980 Journal Article French
        France
      </p>
      <p>
        Nogier P. Une nouvelle approche du VAS.{" "}
        <em>Revue d’auriculomedicine</em> no. 19 Apr 1980 Journal Article French
        France
      </p>
      <p>
        Nogier P. Utilisation des champs magnetiques au niveau du pavlon de
        l’oreille. <em>Revue d’auriculomedicine</em> e 10 Jan 1978 Journal
        Article France
      </p>
      <p>
        Nogier P. Qu’est-ce que I’auriculo-medecine ? …{" "}
        <em>Revue d’auriculomedicine</em> no. 11 Sept 1975 Journal Article
        French France
      </p>
      <p>
        Nooerpsul <em>Curso superior de auiiculomedicina</em>. Proelsa SA junio
        1986 Proelsa SA p’ de Gracia 69 4′ decho 9 Barcelonna Spain, Espagne
        fta, P. book
      </p>
      <p>
        Pagano M. Enregistrement en temps reel du VAS. Application automatique
        pour la determination du remede homeopathique.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM French GLEM
      </p>
      <p>
        Piro C. L’oreille, cellule geante. <em>Revue d’auriculomedicine</em> no
        17 Oct 1979 Journal Article French France
      </p>
      <p>
        Piro C. Phases tissus et energie. <em>Revue d’auriculomedicine</em> no
        27 Apr 1982 Journal Article French France
      </p>
      <p>
        Privitera P. These. <em>Revue d’auriculomedicine</em> no. 35 Apr 1984
        Sicile JournalArticle French French
      </p>
      <p>
        Pujol H, Secondy A, Romieu G, Lapinsk H. Projet d’un essai controle sur
        I’apport de l’auirculomedecine dans le diagnostic en cancerologie.{" "}
        <em>Revue d’auriculomedicine </em>no 25 Oct 1981 Jounal Article France
      </p>
      <p>
        Reynaud A. Resultats therapeutiques en auriculo-medecine.{" "}
        <em>Revue d’auriculomedicine</em> no. 6 Jan 77 Journal Article French
        France
      </p>
      <p>
        Ribeiro DC. Feromonios, VAS, fotopercepcien cutanea y equilibrio sexual
        en la analgesia por acupuntura auricular.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapie et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM Portuguese
      </p>
      <p>
        Roths A. Frequence F en stomatologie. <em>Revue d’auriculomedicine</em>{" "}
        no. 19 Apr 1980 Journal Article French France
      </p>
      <p>
        Rouxeville Y.{" "}
        <em>Abrege de cours d’auriculotherapy et d’auriculomedicine. </em>GLEM
        49, rue Merciere 69002 Lyon
      </p>
      <p>
        Rouxeville Y. Abrege des cours d’auriculotherapie et d’auriculomedecine
        chez l’auteur ou au GLEM 49Lyon 1993 Book FrencWrangais
      </p>
      <p>
        Rouxeville Y. Auriculotherapie, auriculomedecine reponses i vos
        questions. <em>Bulletin Scientifique du GLEM</em> n’l nov 1988 Journal
        Article French
      </p>
      <p>
        Rouxeville Y. Etude clinique du Polartron ” Sud ” en traumatologie
        sportive. <em>Revue d’auriculomedicine</em> no. 19 Apr 1980 Journal
        Article French France
      </p>
      <p>
        Rouxeville Y. Hypotheses sur les phases, cartographies decrites par Paul
        Nogier et traitement de la douleur Congres de la Faformec 1999 (Paris) .
      </p>
      <p>
        Rouxeville Y. L’auriculomedicine, ” Energetique ” ou ” Scientifique ” ?{" "}
        <em>Annales du G.L.E.M</em>, (1997) 16
      </p>
      <p>
        Rouxeville Y. Les frequences + 20 et – 20.{" "}
        <em>Revue d’auriculomedicine</em> no 22 Jan 1981 Journal Article French
        France
      </p>
      <p>
        Rouxeville Y. Les frequences.comment agir?{" "}
        <em>Revue d’auriculomedicine</em> no 26 Jan 1982 Journal Article French
        France
      </p>
      <p>
        Rouxeville Y. Questions sur l’auriculomedecine. (site internet du GLEM){" "}
        <em>Annales du G.L.E.M.</em> (1996)
      </p>
      <p>
        Rouxeville Y. Theramagnetic et fonctions cerebrales{" "}
        <em>Revue d’auriculomedicine</em> no 35 Apr 1984 Journal Article French
        France
      </p>
      <p>
        Rouxeville Y. Thermometrie et champs magnetiques polarisds.{" "}
        <em>Revue d’auriculomedicine</em> no 25 Oct 1981 Journal Article French
        France
      </p>
      <p>
        Sagne R. Reflexions sur le traitement des cicatrices.{" "}
        <em>Revue d’auriculomedicine</em> no. 17 Oct 1979 JournalArticle French
        France
      </p>
      <p>
        Sanchez AA. Apport du VAS a la medicine contemporaire
        <em>
          . Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France Haug editeur Bruxelles. 27,28,29 Mal 1994 GLEM
      </p>
      <p>
        Sanchez AM. Les blocages vertebraux sequentiels.{" "}
        <em>Revue d’auriculomedicine</em> no. 27 Apr 1982 Journal Article French
        France
      </p>
      <p>
        Sanchez M, de Sanchez L. Champs magnetiques polarisds et reponse
        thermique reflexe. <em>Revue d’auriculomedicine</em> no. 27 Apr 1982
        Journal Article French France
      </p>
      <p>
        Santini Deux rapports sur les incidences d’un champ magnetique toumant
        sur le developpement tumoral. <em>Revue d’auriculomedicine</em> no. 19
        Apr 1980 Journal Article French France
      </p>
      <p>
        Schneider R. Action de la lumiere traversant un filtre.{" "}
        <em>Revue d’auriculomedicine</em> no. 3 1 Apr 1983 Journal Article
        French France
      </p>
      <p>
        Schwartz, GE, Russek LG, Grant KL, Rychener D, Ackerman J. Testing the
        vascular autonomic signal energy detection hypothesis: a dynamical
        energy systems approach under review
      </p>
      <p>
        Secondy A. Audition et prise du pouls. <em>Revue d’auriculomedicine</em>{" "}
        no. 27 Apr 1982 Journal Article French Maisonneuve SA France
      </p>
      <p>
        Secondy A. Foyer primaire et foyer secondaire.{" "}
        <em>Revue d’auriculomedicine</em> no. 16 Jul 1979 Journal Article French
        France
      </p>
      <p>
        Secondy A. Les deux points. <em>Revue d’auriculomedicine</em> no. 26 Jan
        1982 Journal Article French France 2.6.A
      </p>
      <p>
        Secondy A. Travaux originaux sur la lateralite.{" "}
        <em>Revue d’auriculomedicine</em> no. 25 Oct 1981 Journal Article French
        France
      </p>
      <p>
        Smith CW. Biolurm’nescence, Coherence and Biocommunication, presented at
        the <em>First International School of Biological Luminesence</em>, June
        20-23, 1989 Ksiaz Castle, Wroclaw, Poland.
      </p>
      <p>
        Smith CW. High-sensitivity biosensors and weak environment stimuli.
        Presented at the Joint Colloquium of the Ditectric
        <em>
          . Society Annual Meeting and 3rd University of Wales Conference on
          Biotechnology
        </em>{" "}
        April 17-19, 1985, Vol. 6, No. 3 Article 4: 2: 85
      </p>
      <p>
        Strittmatter B. L’importance des foyers dentaires non apparents en
        pratique quotidienne. Selecteve herd und storfeldtestmethoden under die
        ohffeflexzonen
        <em>
          . Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM French
      </p>
      <p>
        Strittmatter B. Selective testing of focuses by the use of
        ear-acupuncture (according to BAHR){" "}
        <em>
          Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedecine Lyon France
        </em>{" "}
        : Haug editeur Bruxelles. 27,28,29 May 1994 GLEM
      </p>
      <p>
        Strittmatter B. Selective testing of focuses by the use of
        ear-acupuncture (according to BAHR){" "}
        <em>
          Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France 27,28,29 May 1994 GLEM
      </p>
      <p>
        Tard G. Compte rendu de travaux de thermographie effectues sur le
        pavilion de l’oreille<em>. Revue d’auriculomedicine </em>no. 27 Apr 1982
        Journal Article French France
      </p>
      <p>
        Timoshevski S, Simonov A. A new device for pulse registration
        <em>. International J of Auricular Medicine</em> (IJAM) 1996
        <strong> </strong>
      </p>
      <p>
        Toureng JC. A propos des oscillations. <em>Revue d’auriculomedicine</em>{" "}
        no. 27 Apr 1982 Journal Article French France
      </p>
      <p>
        Toureng JC. Langage ternaire du pouls radial.{" "}
        <em>Annales du G.L.E.M.</em> (1997) 53
      </p>
      <p>
        Van Gelder AF. The role of low energy chakras in pathology.
        <em>
          {" "}
          Annales du Premier Symposium International d’Audculotherapie et
          d’Auriculomedicine{" "}
        </em>
        Lyon France. 27,28,29 May 1994 GLEM French
      </p>
      <p>
        Veenstra M. Ameliorer le coherence en utilisant les anneaux-tests GTP et
        Arginine. <em>Annales du G.L.E.M.</em> (1998)
      </p>
      <p>
        Veenstra M. The dynamics of a polaroid filter
        <em>
          . Annales du Troisieme Symposium International d’Auriculotherapie et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM English 2.5 _
      </p>
      <p>
        Vigneron JL. Le filtre testeur I an apres. Application aux filtres Lee
        <em>. Fascicule du Cours superieur d’auriculomedecine</em> no. 7 Oct
        1998 GLEM Brochure French France
      </p>
      <p>
        Vigneron JL. Le filtre testeur.{" "}
        <em>Fascicule du Cours supefieur d’auriculomedecine</em> no. 5 Jan 98
        GLEM Brochure French France
      </p>
      <p>
        Vigneron JL. Le refus de guefir en auriculomedicine.{" "}
        <em>Fascicule du Cours supefieur d’auriculomedecine</em> no. 7 Oct 1998
        GLEM Brochure French France
      </p>
      <p>
        Vigneron JL. Le refus de guerir en auriculomedicine.{" "}
        <em>Annales du G.L.E.M.</em> (1998)
      </p>
      <p>
        Vigneron JL. Le systeme du filtre testeur. <em>Annales du G.L.E.M.</em>{" "}
        (1997) 45
      </p>
      <p>
        Vigneron JL. The testing filter. <em>Coherence</em> 1998 : The 2nd
        international IAAMER congress on: auricular diagnostics &amp; therapy
        September 19-21, 1997 English Netherlands
      </p>
      <p>
        Vigneron JL. Traitement d’auriculomedicine et hypnose.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 French
      </p>
      <p>
        Vigoureux F, Piquemat M. ‘ICS: la memoire du sang
        <em>
          . Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France:. 27,28,29 May 1994 GLEM French
      </p>
      <p>
        Vuillez C. Incidence de frequence de l’environnement sur notre
        organisms. <em>Annales du G.L.E.M.</em> (1995)
      </p>
      <p>
        Vulliez C. Etudes mathematiques du signal du pouls appele RAC ou VAS.{" "}
        <em>Congres de Natal</em> 1997/ Site internet du GLEM Novembre 1997
        France
      </p>
      <p>
        Vulliez C. Mise en evidence du signal vasculaire
        <em>
          . Annales du Premier Symposium International d’Auriculotherapie et
          d’Auriculomedicine
        </em>{" "}
        Lyon France:. 27,28,29 May 1994 GLEM
      </p>
      <p>
        Vulliez C. Travail en double aveugle de confrontation entre la
        perception du pouls de Nogier par un observateur et par un capteur
        MetraVEB R.D. S. (76 % de resultats positifs)
      </p>

      <h2 id="sec2dot6">2.6 Acupuncture with Herbal Remedies and Homeopathy</h2>
      <p>
        Badgley LE. A new method for identifying therapeutically effective
        homeopathic remedies and acupuncture points.{" "}
        <em>Amer J of Acupuncture</em>, 1985, vol. 13, no l, 51-56 English
      </p>
      <p>
        Bricard A. Homeopathie et auriculomedicine. <em>Annales du G.L.E.M</em>.
        (1997) 34
      </p>
      <p>
        Bricard A. Tester les remedes homeopathiques par le pouls de Nogier.{" "}
        <em>Annales du G.L.E.M.</em> (1998) Bricot B. Choc physique et choc
        nerveux. <em>Revue d’auriculomedicine</em> no. 14 Jan 1979 Journal
        Article French France 2.5 _
      </p>
      <p>
        Fayeton S, Reynaud A. Possibilite d’identification de la dilution
        homeopathique par le RAC. <em>Revue d’auriculomedicine</em> no. 10 Jan
        1978 Journal Article French
      </p>
      <p>
        Fayeton S. Homeopathie et auriculo-medicine.{" "}
        <em>Revue d’auriculomedicine</em> no. 16 Jul 1979 Journal Article French
        France
      </p>
      <p>
        Fayeton S. Langage de l’inconscient, auriculomedicine et Homeopathie{" "}
        <em>Revue d’auriculomedicine</em> no. 32 Jul 1983 Journal Article French
        France
      </p>
      <p>
        Kubista E, Boschitch E, Spona J. Effect of ear acupuncture on the LM
        concentration in serum in patients with secondary amenorrhea.{" "}
        <em>Wiener Medizinische Wochenschrief</em>, Mar 15,1981.
      </p>
      <p>
        Lentz A. <em>Auriculomedecine et homeopathie </em>Gueniot Editeur /52201
        Langres, FR 1994. Book French
      </p>
      <p>
        Lentz A. L’auriculomedecine et les differentes facons de pratiquer
        l’homeopathie<em>. International J of Auricular Medicine</em> (IJAM)
        1996
      </p>
      <p>
        Lentz A. L’auriculomedicine et les differentes ragons de pratiquer
        l’homeopathie. <em>Annales du G.L.E.M.</em> (1995)
      </p>
      <p>
        Mullins M. Magnetically influence homeopathic remedies.{" "}
        <em>Auriculotherapy Congres de Natal 1997</em> Site internet du GLEM
      </p>
      <p>
        Ortega SA. La homeopatia a traves de la auriculomedicina.{" "}
        <em>Proelsa SA</em> pl de Gracia 69 4′ dpcho 9 Barcelonna Spain
      </p>
      <p>
        Straube EM. RAC-kontrollierte homoopathie: eine moglichkeit zur
        verbesserung der effektivitat der homoopatischen therapie.{" "}
        <em>
          Annales du Prenier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France:27,28,29 May 1994 French
      </p>

      <h2 id="sec3dot1">3.1 General Addiction, NADA Protocol</h2>
      <p>
        Ackerman RW. Auricular acupuncture treatment for chemical dependency.
        Paper presented to the{" "}
        <em>National Acupuncture Detoxification Association</em>, Inc..
        Vancouver, Washington, 1-34. 1992 Available from National Acupuncture
        Detoxification Association Clearinghouse, POB 1927, Vancouver, WA
        98668-1927
      </p>
      <p>
        Ackerman RW.{" "}
        <em>
          The experience of women receiving auricular acupuncture treatment for
          chemical dependency during pregnancy
        </em>
        . Santa Barbara (CA)]: The Fielding Institute; 1994. 301 p. Santa
        Barbara (CA)]: The Fielding Institute English
      </p>
      <p>
        Brewington V, Smith M, Lipton D. Acupuncture as a detoxification
        treatment: analysis of controlled research.{" "}
        <em>J of Substance Abuse Treatment</em> 1994 Vol. 11 pp. 289-307.
      </p>
      <p>
        Brumbaugh AG. Acupuncture: new perspectives in chemical dependency
        treatment. <em>J Subst Abuse Treat</em> 1993 Jan; 10 (l): 35-43 Medline
        93195972 Journal article review, tutorial USA
      </p>
      <p>
        Clark W. Trial of acupuncture detoxification (TRIAD): Final report
        prepared by TRIAD Research Staff, Delivered to the California State
        Legislature August 15, 1990 Available from National Acupuncture
        Detoxification Association Clearinghouse, POB 1927, Vancouver, WA
        98668-1927.
      </p>
      <p>
        Cui Meng. Advances in studies on acupuncture abstinence.{" "}
        <em>J of Tradit Chinese Medicine</em> 15(4)-.301-307,1995, 16(1)
        65-69,1996 .
      </p>
      <p>
        Culleton PD, Kiresuk TJ. Overview of substance abuse acupuncture
        treatment research
        <em>. J of Alternative &amp; Complementary Medicine</em>, 1996 Vol. 2,
        No. 1 pp. 149-165.
      </p>
      <p>
        Dale RA. Addictions and acupuncture: the treatment methods, formulae,
        effectiveness and limitations. <em>Amer J of Acupuncture</em> 1993 Vol.
        21, No. 3 pp. 247-267.
      </p>
      <p>
        Finn P, Newlyn AK.{" "}
        <em>
          Mami’s Drug Court: a different approach national institute of justice
          program
        </em>
        . Focus, NCJ 142412, 1993 (Available from U.S. Department of Justice,
        Office of Justice Programs, National Institute of Justice, Washington,
        D.C. 2053 1. or available from National Acupuncture Detoxification
        Association Clearinghouse, POB 1927, Vancouver, WA 98668-1927.)
      </p>
      <p>
        Font Riera Jose Francisco Lepez Espinosa Carlos Aldea Bueno. Tecnicas de
        deshabituacion obesidad-tabaquismo-drogadiccion.{" "}
        <em>Proelsa SA Mayo</em> 1986 69 4′ dpcho 9 Barcelonna Spain
      </p>
      <p>
        Gurevich M, Duckworth D, Imhof J, Katz JI. Is auricular acupuncture
        beneficial in the inpatient treatment of substance-abusing patients? A
        pilot study. <em>J Subst Abuse Treat </em>1996 Mar-, 13(2)-165-71
        Medline 97035020 Journal article English United States
      </p>
      <p>
        Inconnu .{" "}
        <em>
          Strategies for action combating drug and alcohol abuse in Dade county:
          an update
        </em>
        . Write to Herbert M. Klein, Associate Chief Judge, I I th Judicial
        Circuit, Miami Beach, Florida June 1990
      </p>
      <p>
        Keenan P. Treatment of pregnant substance abusers. Paper presented at
        the{" "}
        <em>National Acupuncture Detoxification Association Annual Meeting</em>,
        Miami, Florida, February, 1990. Available from National Acupuncture
        Detoxification Association Clearinghouse, POB 1927, Vancouver, WA
        98668-1927.
      </p>
      <p>
        Konefal J, Duncan R, Clemence C. Comparison of three levels of auricular
        acupuncture in an outpatient substance abuse program.{" "}
        <em>Altern Med J</em> 1995; 2 ( 5): 8-17,
      </p>
      <p>
        Konefal J, Duncan R, Clemence C. The impact of the addition of an
        acupuncture treatment program to an existing Metro-Dade County
        outpatient substance abuse treatment facility.{" "}
        <em>J of Addiction Disease</em> 1994 Vol. 13, No. 3 71-99.
      </p>
      <p>
        Konefal J.{" "}
        <em>Drug abuse detoxification study for risk behavior of AIDS</em>.
        Grant application to the Department of Health and Human Services, Public
        Health Service University of Miami. Available from University of Miami,
        School of Medicine, Department of Psychiatry, P.0. Box 0 1 6069, Miami,
        Florida 3 3 1 01
      </p>
      <p>
        Lane C.{" "}
        <em>Final evaluation report: acupuncture detoxification project</em>.
        Hooper Center, Central City Oregon, Alcohol and Drug Program 1988
      </p>
      <p>
        Lowe L.{" "}
        <em>
          A focus on acupuncture research compiled by the California Department
          of Corrections
        </em>
        . Paper presented at Fifth Annual Conference, National Acupuncture
        Detoxification Association March 18-20, 1994, San Francisco, CA. March
        18-20, 1994 Available from National Acupuncture Detoxification
        Association Clearinghouse, POB 1927, Vancouver, WA 98668-1927,
      </p>
      <p>
        Mallard A, Petitjean F. Thylisme chronique.{" "}
        <em>Revue d’auriculomedicine </em>no. 30 Jan 1983 Journal Article French
        France
      </p>
      <p>
        Patterson MA. Effects of neuroelectric therapy (N.E.T.) in drug
        addiction: interim report. <em>Bulletin of Narcotics</em> 1976 Vol. 28
        pp. 55-62
      </p>
      <p>
        Patterson MA.{" "}
        <em>
          Final report: the effectivenss of acupuncture in the treatment of drug
          dependency
        </em>
        . Submitted to the Montgomery Court of Common Pleas, Montgomery County,
        Ohio 1993
      </p>
      <p>
        Shakar M, Smith MO. The use of acupuncture in the treatment of drug
        addiction. <em>Amer J of Acupuncture</em>, 1979 Vol. 7, No. 3 pp.
        223-228
      </p>
      <p>
        Simon F.{" "}
        <em>
          The successful use of auricular acupuncture in the supported
          withdrawal and detoxification of substance abusers community drug
          advisory service
        </em>
        . St. Pauls Hospital Winchester, Hampshire, S022 5AA England
      </p>
      <p>
        Smith MO, Alvarez C, Smalls N.{" "}
        <em>
          Criminal justice referrals to acupuncture detoxification: pilot
          program. Shows encouraging results
        </em>
        . September 10, 1987 Available from Substance Abuse Division, Lincoln
        Hospital, Bronx, New York
      </p>
      <p>
        Smith MO, Kahn I. Acupuncture program for treatment of drug addicted
        persons. <em>Bulletin on Narcotics</em> 1988 XL(l) pp. 35-41.
      </p>
      <p>
        Smith MO, Ra K. Acupuncture and the treatment of chemical dependency and
        violence. Paper presented at the{" "}
        <em>Caribbean Mental Health Conference</em>, Nassau, Bahamas July 22-26,
        1985 Available from Substance Abuse Division, Lincoln Hospital, Bronx,
        New York
      </p>
      <p>
        Smith MO, Squires R, Aponte J, Rabinovitz N, Bonilla-Rodriguez R.
        Acupuncture treatment of drug addiction and alcohol abuse.{" "}
        <em>Amer J of Acupuncture</em>, 1982 Vol, 10, No. 2, pp. 161-166.
      </p>
      <p>
        Smith MO. Acupuncture and natural healing in drug detoxification.{" "}
        <em>Amer J of Acupuncture</em> 1979 Vol. 1, No. 7 pp. 97-107
      </p>
      <p>
        Smith MO. Acupuncture as a treatment for drug dependent mothers.
        Testimony presented to the <em>New York City Council</em>, April 11,
        1988
      </p>
      <p>
        Smith MO. Acupuncture helps programs more than patients. Paper presented
        at the{" "}
        <em>
          Annual Conference of the National Acupuncture Detoxification
          Association
        </em>{" "}
        1993 Available from National Acupuncture Detoxification Association
        Clearing House, POB 1927, Vancouver, WA 98668-1927.)
      </p>
      <p>
        Smith MO. Acupuncture treatment for substance abuse.{" "}
        <em>National Acupuncture Detoxification Association Clearing House</em>{" "}
        1987 Available from: National Acupuncture Detoxification Association
        Clearing House, POB 1927, Vancouver, WA 98668-1927.
      </p>
      <p>
        Smith MO. Lincoln Hospital Acupuncture Drug Abuse Program. Testimony
        presented to the{" "}
        <em>
          National Institute of Health Alternative Medicine and the National
          Wellness Coalition
        </em>{" "}
        (Dirksen Senate Office Building) May 21, 1993
      </p>
      <p>
        Smith MO. Raising healthy babies for the 90’s. National Acupuncture
        Detoxification Association Clearing House 1990 Available from National
        Acupuncture Detoxification Association Clearing House, POB 1927,
        Vancouver, WA 98668-1927.)
      </p>
      <p>
        Smith MO.{" "}
        <em>
          Relation of maternal treatment involvement (i.e., participation in
          substance abuse and prenatal services) to infant birth weight
        </em>
        . Unpublished report. 1992 (Available from Lincoln Clinic, Maternal
        Substance Abuse Services, 349 East 140th Street, Bronx, New York 10454.)
      </p>
      <p>
        Smith MO. The Lincoln Hospital Drug Abuse Program. Testimony presented
        to the{" "}
        <em>
          Select Committee on Narcotics of the House of Representatives of the
          United States
        </em>{" "}
        July 4, 1989 Available from Substance Abuse Division, Lincoln Hospital,
        Bronx, New York
      </p>
      <p>
        Smith MO. The Miami success story- transforming the criminal justice
        system with an acupuncture. Based Diversion Program,{" "}
        <em>National Acupuncture Detoxification Association Newsletter</em>{" "}
        September, 1990 Available from National Acupuncture Detoxification
        Association Clearing House, POB 1927, Vancouver, WA 98668-1927,
      </p>
      <p>
        Swan N. Experts divided on effectiveness of acupuncture as a drug abuse
        treatment. <em>NIDA Notes</em> September/October, 1992 p. 17
      </p>
      <p>
        Sytinsky IA, Galebskaya LV. Physiologo-biochemical bases of drug
        dependence treatment by electro- acupuncture.{" "}
        <em>Addiction Behavior</em> 1979 Vol. 4, No. 2 pp. 97-120
      </p>
      <p>
        Taub CB. Report on acupuncture substance abuse treatment adjunct. Feb
        1993 through Jun 1993, Jul 1993. Available through{" "}
        <em>Lincoln Hospital, Maternal Substance Abuse Services</em>, 349 East
        140th Street, Bronx, New York 10454.
      </p>
      <p>
        Taubert K. Diagnosis using of ear zeitschrift fur arztliche.{" "}
        <em>Fortbildung</em> 1992 no. 19 945-946
      </p>
      <p>
        Wen HL, Cheung YC. Treatment of drug addiction by acupuncture and
        electrical stimulation<em>. Asian J of Medicine</em> 1973 Vol. 9 pp.
        138-141 Reprinted in <em>Amer J of Acupuncture</em> Vol. 1, no. 2, 1973,
        p. 71-75.
      </p>
      <p>
        Wen HL. Clinical experience and mechanisms of acupuncture and electrical
        stimulation (AES) in the treatment of drug abuse.{" "}
        <em>Amer J of Chinese Medicine</em> 1980 Vol. 8, No. 4, pp. 349-353
      </p>
      <p>
        Whitehead D. Acupuncture and the treatment of addiction: a review and
        analysis<em>. International J of Addictions</em> 1978 Vol. 13, No. I pp.
        1-16.
      </p>

      <h2 id="sec3dot2">3.2 Alcohol Abuse, Alcoholism, Sedative Abuse</h2>
      <p>
        Bagnis JP. Contribution a la des intoxication alcoolique.{" "}
        <em>Revue d’auriculomedicine </em>no 13 Oct l978 Journal Article French
        France
      </p>
      <p>
        Bullock ML, Culliton PD. Olander RT. Controlled trial of acupuncture for
        severe recidivistic alcoholism. <em>The Lancet</em> June 24, 1989 pp.
        1435-1439.
      </p>
      <p>
        Bullock ML, Umen AJ, Culliton PD, Olander RT. Acupuncture treatment of
        alcoholic recidivism: a pilot study. <em>Alcohol Clin Exp Res</em> 1987
        Jun; 1 1(3):292-5.
      </p>
      <p>
        Lao HH. A retrospective study on the use of acupuncture for the
        prevention of alcoholic recidivism<em>. Amer J Acupunct</em> 1995; 23
        (l):29-33.
      </p>
      <p>
        Rampes H, Pereira S, Mortimer A, Manoharan S, Knowles M. Does
        electroacupuncture reduce craving for alcohol? A randomized controlled
        study. <em>Complement Ther Med</em> 1997-5(l)-.19-26.
      </p>
      <p>
        Sun S, Yu Z, Gao W, Wang C, Ding U, Gao F, Wan G, Jin Y, Cui Y. Clinical
        report of drinking intervention on 310 cases with auriculo acupuncture.{" "}
        <em>J of Tradit Chinese Medicine</em>, 1988, vol.8, no2, 123-124 Journal
        article English China
      </p>
      <p>
        Tabeeva DM. Autonomic nervous system function of alcoholics during
        acupuncture treatment<em>. Zh Nevropatol Psikhiatr</em> 1988 10 33-6
        Medline 89102209 Journal article Russian/Russe USSR
      </p>
      <p>
        Worner TM, Zeller B, Schwarz H, Zwas F, Lyon D. Acupuncture fails to
        improve treatment outcome in alcoholics. <em>Drug Alcohol Depend</em>{" "}
        1992 Jun- 30 ( 1) : 169-73. 1992.
      </p>

      <h2 id="sec3dot3">3.3 Opiate Abuse, Heroin, Morphine, Methadone</h2>
      <p>
        Choy YM, Tso WW, Fung KP, Leung KC, Tsang YF, Lee CY, Tsang D.
        Suppression of narcotic withdrawals and plasma ACTH by auricular
        electroacupunture. <em>Biochem Biophys Res Commun</em> 1978 May- 82 (l).
        305-9 Medline 78210687
      </p>
      <p>
        Cocchi R, Lorini G, Fusari A, Carrossino R. Experience with
        detoxification and weaning of heroin addicts by means of acupuncture,
        gabergic drugs and psychopharmacoiogic agents in low doses{" "}
        <em>Minerva Med</em> 1979 May; 70 (24): 1735-44 Medline 79200194
      </p>
      <p>
        Kroening RJ, Oleson TD. Rapid narcotic detoxification in chronic pain
        patients treated with auricular electroacupuncture and naloxone.
        Ntemational. <em>J of Addiction</em> 1985 Sep Vol. 20, No. 9 1347-60
        Medline 86084641
      </p>
      <p>
        Leung AS. Acupuncture treatment of withdrawal symptoms.{" "}
        <em>Amer J Acupunct</em> 1977-5(l) 43-50.
      </p>
      <p>
        Man PL, Chuang MY. Acupuncture in methadone withdrawal.{" "}
        <em>International J of Addiction</em> 1980 Vol. 15 pp. 921-926
      </p>
      <p>
        Margolin A, Avants SK, Chang P, Birch S, Kosten TR. A single-blind
        investigation of four auricular needle puncture configurations.{" "}
        <em>Amer J Chin Med</em> 1995; 23 (2): 105-14 Medline 96057886 Clinical
        Trial; Journal Article English United States
      </p>
      <p>
        Margolin A, Avants SK, Chang P, Kosten TR. Acupuncture for the treatment
        of cocaine dependence in methadone-maintained patients.{" "}
        <em>Amer J of Addiction</em> 1993 Vol. 2 pp. 194-201
      </p>
      <p>
        Nogier P. Traitement du terrain canckreux en auriculomedicine A propos
        du diagnostic et du tr revue d’auriculomedicine no. 27 Avrit 1982
        Journal Article French
      </p>
      <p>
        Washburn AM, Fullilove RE, Fulfilove MT, Keenan PA, McGee B, Morris KA,
        Sorensen JL, Clark WW. Acupuncture heroin detoxification: a single-blind
        clinical trial. <em>J Subst Abuse Tr</em>eat 1993 Jul- 10(4): 345-51
        1993 Jul Vol. 10 345-51 Medline 94016721 University of California, San
        Francisco. Clinical Trial-, Journal Article; Randomized Controlled Trial
        Englisih United States
      </p>
      <p>
        Wen HL, Clement-Jones V, McLaughlin L. et al. Acupuncture in heroin
        addicts: changes in met-enkephalin and B-endorphin in blood and
        cerebrospinal fluid. <em>Lancet</em> 1979 Vol. 2 380-383
      </p>
      <p>
        Wen HL, Teo SW. Experience in the treatment of drug addiction by
        electro-acupuncture. <em>Modern Medicine Asia</em> 1975 Vol. I I pp.
        23-24.
      </p>
      <p>
        Wen HL. Acupuncture and electrical stimulation (AES) outpatient
        detoxification. <em>Modern Medicine Asia</em> 1979 Vol. 15 pp. 39-43
      </p>
      <p>
        Wen HL. Fast detoxification of heroin addicts by acupuncture and
        electrical stimulation (AES) in combination with naloxone.{" "}
        <em>Comparative Medicine East-West</em> 1977 Vol. 5 pp. 257-263.
      </p>

      <h2 id="sec3dot4">
        3.4 Stimulant Abuse, Cocaine, Methamphetamine, Hallucinogens,
        Cannabinols, Marijuana
      </h2>
      <p>
        Avants SK, Margolin A, Chang P, Kosten TR, Birch S. Acupuncture for the
        treatment of cocaine addiction. Investigation of a needle puncture
        control. <em>J Subst Abuse Treat</em> 1995 May-Jun; 12 (3): 195-205.
      </p>
      <p>
        Avants SK, Margolin A, Kosten TR. Cocaine abuse in methadone maintenance
        programs: integrating pharmacotherapy with psychosocial interventions.{" "}
        <em>J Psychoactive Drugs</em> 1994-26 (2)-137-46.
      </p>
      <p>
        Bullock ML, Kiresuk TJ, Pheley AM, Culliton PD, Lenz SK. Auricular
        acupuncture in the treatment of cocaine abuse. A study of efficacy and
        dosing. <em>J Subst Abuse Tr</em>eat 1999 Jan; 16(l):31-8 Medline
        99105066
      </p>
      <p>
        Lipton DS, Brewington V, Smith M. Acupuncture for crack-cocaine
        detoxification: experimental evaluation of efficacy.{" "}
        <em>J Subst Abuse Treat</em> 1994 May- 11 (3): 205-15 Medline 94351776
        Clinical trial; Journal article Randomized Controlled Trial English
        United States
      </p>
      <p>
        Lipton DS, Brewington V, Smith M. Acupuncture for crack-cocaine
        detoxification:experimental evaluation of efficacy.{" "}
        <em>J Subst Abuse Treat</em> 1994 May-Jun 1(3): 205-15.
      </p>
      <p>
        Margolin A, Avants SK, Birch S, Falk CX, Kleber HD. Methodological
        investigations for a multisite trial of auricular acupuncture for
        cocaine addiction: a study of active and control auricular zones.{" "}
        <em>J Subst Abuse Treat</em> 1996 Nov; 13(6):471-81 Medline 97362680
        Clinical trial- Journal article Multicenter study; randomized controlled
        trial English United States
      </p>
      <p>
        Margolin A, Chang P, Avants SK, Kosten TR Effects of shAmer and real
        auricular needling: implications for trials of acupuncture for cocaine
        addiction. <em>Amer J Chin Med</em> 1993; 21(2):103-11 Medline 94056261.
        Clinical trial; Journal article English United States
      </p>
      <p>
        Otto KC, Quinn C, Sung YF Auricular acupuncture as an adjunctive
        treatment for cocaine addiction. A pilot study. <em>Amer J Addict</em>{" "}
        1998 Spr; 7(2):164-70 Medline 98260582
      </p>
      <p>
        Richard AJ, Montoya ID, Nelson R, Spence RT. Effectiveness of adjunct
        therapies in crack cocaine treatment<em>. J Subst Abuse Treat</em> 1995
        Nov-Dec- 12(6) 401-13.
      </p>
      <p>
        Swan N. N.Y.C. Clinic cites success in treatment cocaine abuse patients
        with acupuncture. NIDA Notes Sep / Oct 1992 p. 15-16
      </p>

      <h2 id="sec3dot5">3.5 Smoking Cessation, Nicotine Addiction</h2>
      <p>
        Audry M. <em>L’auricule i travers 3 programmes anti-tabac</em>. Facute
        de Medecine de Dijon no 71 1976
      </p>
      <p>
        Ballal SG, Khawaji YN. Auricular stimulation and acupuncture as an
        adjuvant to an anti-smoking programme: analysis of the results of a
        1-year experience. <em>Tuber Lung Dis</em> 1992 Dec; 73 (6): 396 Medline
        93184296
      </p>
      <p>
        Beigo B, Campacci R. Antismoking treatment by needle puncture of the
        ear. <em>Riabditazione</em> 1980;13 (4): 191-7. (Ita).
      </p>
      <p>
        Friedman J. Auricular acupuncture for smoking [letter].{" "}
        <em>Acupunct Electrother Res</em> 1992; 17(2):14950 Medline 92351824
      </p>
      <p>
        Gandhi R. The uses of auricular acupuncture in the field of substance
        misuse. <em>Psychiatr Care</em> 3 Suppl 1-40-1. 1996 I-.40-1.
      </p>
      <p>
        Gilbey V, Neumann B. Auricular acupuncture for smoking withdrawal.{" "}
        <em>Amer J Acupunct</em> 1977 Jul-Sep 5 (3): 23947.
      </p>
      <p>
        Grosbglas A. Letter: Auricular acupuncture and smoking.{" "}
        <em>Nouv Presse Med</em> 1975 Mar 4 (13): 980 Medline 75195898 French
      </p>
      <p>
        Jackotinguizonne C. Sevrage tabagique – etude de l’auriculotherapie.
        These Pads 7 Lariboisiere 1997 Bibliotheque interuniversitaire de
        medicine French
      </p>
      <p>
        Lebeau B, Vidal C, Billion A, Torcy M, Rochemaure J. Tobacco
        detoxication by acupuncture and group psychotherapy.{" "}
        <em>Rev Med Interne</em> 1986 Nov;7(5):471-6 Rev Med Interne 1986
        Nov-7(5):471-6 Medline 87119523 Journal article Fre
      </p>
      <p>
        Leung JP. Smoking cessation by auricular acupuncture and behavioral
        therapy. <em>Psychologia</em> 1991 Sep 34 (3): 177-87.
      </p>
      <p>
        Li QS, Liu ZY, Ma IU, Lu YY, Fang YA, Hou YZ, Cao SH, Zhang ZH. A
        preliminary study on the mechanism of ear-acupuncture for withdrawal of
        smoking. <em>J Tradit Chin Med</em> 1987 Dec;7 (4):2 43-7.
      </p>
      <p>
        Marignan M. Le traitement antitabac.{" "}
        <em>Sciences et Medecines Nouvelles </em>N’l 1989 GLEM Journal Article
        French.
      </p>
      <p>
        Martin GP, Waite PM. The efficacy of acupuncture as an aid to stopping
        smoking. <em>New Zealand Med J</em> 1981 Jun; 93 (686): 421-3 Medline
        81246050 English
      </p>
      <p>
        Nguyenvanminh . Sevrage anti-tabac par acupuncture et auriculotherapie:
        evaluation des resultats; annees 1981,1982,1983 These Rennes 1985
        Bibliothioque interuniversitaire de medecine (BMW Thesis French
      </p>
      <p>
        Nogier P. Editorial: Problemes actuels vus a travers
        l’auriculo-medicine. <em>Revue d’auriculomedicine</em> no 9 Oct 1977
        Journal Article French France
      </p>
      <p>
        Nogier P. L’ancetre du programme antitabac (1974).{" "}
        <em>Revue d’auriculomedicine</em> no. 22 Jan 1981 Journal Article French
        France
      </p>
      <p>
        Nogier P. Le counter des lecteurs, l’evolution de la methode et le
        programme anti-tabac. <em>Revue d’auriculomedicine</em> no 7 Apr 1977
        Journal Article French France
      </p>
      <p>
        Nogier P. Le programme antitabac et le cancer du poumon.{" "}
        <em>Revue d’auriculomedicine</em> no. 23 Apr 1981 Journal Article French
        France
      </p>
      <p>
        Nogier P. Reflexions sur le programme anti-tabac
        <em>. Revue d’auriculomedicine</em> no. 32 Jul 1983 Journal Article
        French France
      </p>
      <p>
        Privitera P. Claudication intermittente, crampe, auriculotherapy et
        programmes anti-tabac. <em>Revue d’auriculomedicine </em>no. 26 Jan 1982
        Journal Article French France
      </p>
      <p>
        Rossato M, Rossato P, Rossato A, Rossato G. Somatic and ear acupuncture
        in tabagism (nicotism) : a 20 years experience.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM French
      </p>

      <h2 id="sec3dot6">3.6 Weight Loss, Obesity</h2>
      <p>
        Alimi D. Neurophysiologie du controle alimentaire et auriculotherapy.{" "}
        <em>Annales du G.L.E.M.</em> (1997) 24
      </p>
      <p>
        Allison DB, Kreibich K, Heshka S, Heymsfield SB. A randomised
        placebo-controlled clinical trial of an acupressure device for weight
        loss. <em>Int J Obes Relat Metab Disord</em> 19(9) 1995 Sep 653-8.{" "}
        <em> </em>
      </p>
      <p>
        <em> </em>
      </p>
      <p>
        Apostolopoulos A, Karavi M. Overeating: treatment of obesity and anxiety
        by auricular acupuncture, an analysis of 800 cases.{" "}
        <em>Acupuncture in Medicine</em> Nov 1996 E-mail: Bmasadmin@aol.com
      </p>
      <p>
        Apostolopoulos A, Karavis M. Bulima control treatment of obesity and
        weight loss by auricular therapy in 800 cases.{" "}
        <em>Int J of Auricular Medicine</em> (IJAM) 1996
      </p>
      <p>
        Boucinhas JC. et IDM. L’auriculotherapie et l’acupuncture chinoise:
        etude comparative dans le traitement de l’obesite
        <em>
          . Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France:27,28,29 May 1994 GLEM
      </p>
      <p>
        Dung HC. Attempts to reduce body weight through auricular acupuncture.{" "}
        <em>Amer J of Acupuncture</em>,1986, vol.14, no 2, 117-122,
      </p>
      <p>
        Dung HC. Role of the vagus nerve in weight reduction through auricular
        acupuncture. <em>Amer J of Acupuncture</em>, 1986, vol. 14, no3,
        249-254, English
      </p>
      <p>
        Gu YS, Zheng XI, Cui SG, Chu H, Xu EM. Clinical observations on weight
        reduction by pressing auricular points with semen vaccariae report of
        473 cases. <em>J Tradit Chin Med </em>1989 Sep; 9(3):166 1989
      </p>
      <p>
        Haubursin P. Insuffisance cardiaque et obesite.{" "}
        <em>Revue d’auriculomedicine</em> no. 32 Jul 1983 Journal Article French
        France
      </p>
      <p>
        Huang MH, Yang RC, Hu SH. Preliminary results of triple therapy for
        obesity. <em>Int J Obes Relat Metab Disord</em> 1996 Sep; 20(9): 830-6
        journal article English
      </p>
      <p>
        Huang ZY. Ear-pressing combined with body needling in treatment of
        obesity: a clinical observation of 39 cases.{" "}
        <em>Int J Clin Acupunct</em> 1995 6 (3) 263-5
      </p>
      <p>
        Liu Z, Sun F, Li J, Han Y, Wei Q, Liu C. Application of acupuncture and
        moxibustion for keeping shape. <em>J Tradit Chin Med</em> 1998 Dec;
        18(4):265-71 Medline 99382971
      </p>
      <p>
        Bazzoni G. Interet de l’auriculotherapy dans l’obesite et le contre ole
        du comportement alimentaire
        <em>
          . Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM
      </p>
      <p>
        Mok MS, Parker LN, Voina S, Bray GA. Treatment of obesity by
        acupuncture. <em>Amer J Clin Nutr</em> 29(8) 1976 Aug 832-5.
      </p>
      <p>
        Richards D, Marley J. Stimulation of auricular acupuncture points in
        weight loss. <em>Aust FAmer Physicia</em>n 1998 Jul; 27 Suppi 20:S73-7
        Thesis English
      </p>
      <p>
        Shiraishi T, Onoe M, Kageyama T, Sameshima Y, Kojima T, Konishi S,
        Yoshimatsu H, Sakata T. Effects of auricular acupuncture stimulation on
        nonobese, healthy volunteer subjects. <em>Obes Res</em> 1995 Dec; 3
        Suppl 50:667S-673S Japan
      </p>
      <p>
        Shiraishi T. The effects of bilateral auricular stimulation on healthy
        volunteer and mild obese patients.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculothirapie et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM English
      </p>
      <p>
        Soong YS. The treatment of erogenous obesity employing auricular
        acupuncture. <em>Amer J Chin Med</em> 1975 Jul; 3 (3): 285-7 Medline
        76059099 Journal article English United States
      </p>
      <p>
        Sun Q, Xu Y. Simple obesity and obesity hyperlipemia treated with
        otoacupoint pellet pressure and body acupuncture.{" "}
        <em>J Tradit Chin Med</em> 1993 Mar; 13 (l): 22-6 English China
      </p>
      <p>
        Tang X. 75 cases of simple obesity treated with auricular and body
        acupuncture. <em>J Tradit Chin Med</em> 1993 Sep; 13 (3): 194-5 Medline
        94066545
      </p>
      <p>
        Tang X. 75 cases of simple obesity treated with auricular and body
        acupuncture. <em>J Tradit Chin Med</em> 1997 Mar; 17 (l): 55-6 1997 Mar
        1 55-6 English
      </p>
      <p>
        Tekeoglu I, Adak B, Ercan M, Sekeroglu R. The effect of auricular
        therapy on serum lipids in simple obesity <em>Coherence</em> 19987
        Journal Article English
      </p>
      <p>
        Vatanparast Z, Watzak M, Spacek A, Zwolfer W. Ear acupuncture combined
        with dietetic consultation for the purpose of weight reduction.{" "}
        <em>Dtsch Z Akupunkt</em> 1995 38(4) 95-9 German
      </p>
      <p>
        Xu B, Fei J. Clinical observation of the weight reducing effect of ear
        acupuncture in 350 cases of obesity.{" "}
        <em>J of Tradit Chinese Medicine,</em> 1985, vol. 5, no2, 87-88 English
      </p>
      <p>
        Zhan J. Observations on the treatment of 393 cases of obesity by semen
        pressure on auricular points. <em>J Tradit Chin Med</em> 1993 Mar; 13
        (l): 27-30 Medline 93274915
      </p>
      <p>
        Zhang ZZ. Weight reduction by auriculo acupuncture : a report of 110
        cases. <em>J of Tradit Chinese Medicine</em>, 1990, vol. 10, no 1, 17-18
        Medline, Journal article English China
      </p>

      <h2 id="sec4dot1">4.1 General Pain, Myofascial Pain, Fibromyalgia</h2>
      <p>
        Devlikamova FI. The effects of auriculotherapy and dry needling on
        myofascial pain syndrome. Abstracts of{" "}
        <em>ICMART’97 International Medical Acupuncture Symposium.</em> Kazalo
        Medical Academy, Central Hospital of Tatarstan, Russia .
      </p>
      <p>
        Dott P, Privitera P. Zona, causalgies et visceralgies associes en
        auriculotherapie. <em>Revue d’auriculomedicine </em>n’35 Apr 1984
        Journal Article French France .
      </p>
      <p>
        Haubursin P. Deux cas etonnants de correction de cicatrices.{" "}
        <em>Revue d’auriculomedicine </em>no. 32 Jul 1983 Journal Article French
        France
      </p>
      <p>
        Ji Y. 776 cases of pain treated with auriculopressure therapy.{" "}
        <em>J Tradit Chin Med</em> 1992 Dec-12(4)-275-6. 1992. .
      </p>
      <p>
        Kirsh K, Magora F. Auriculomedicine–a new method of pain management.{" "}
        <em>Harefuah</em>. 1987 Oct; 113 (7-8): 150-151 . Hebrew .
      </p>
      <p>
        Leung CY, et al. Effect of auriculo-acupuncture on pain.{" "}
        <em>Amer J Chin Med</em>, 1974 Jul 1974
      </p>
      <p>
        Mastalier O. Effective auricular reflex points for the treatment of pain
        and vegetative equilibration. <em>Coherence</em> 1998: The 2nd
        international IAAMER congress on: auricular diagnostics &amp; therapy
        Oisterwijk, The Netherlands September 19-21, 1997 issn 1565-0138
        Oberaudorf, Germany Abstract de congres Congress English Netherlands .
      </p>
      <p>
        Meas Y. Apport de l’auriculo-acupuncture dans le traitement de la
        douleur. Evaluation au Centre Anti-douleur du CHU de Nantes.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapie et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM Abstract de Congress French.
      </p>
      <p>
        Melzack R, Katz J. Auriculotherapy fails to relieve chronic pain. A
        controlled crossover study. <em>JAMA</em> 1984 Feb 24;251(8):1041-3
        Medline 84115170 clinical trial Journal Article, Randomized Controlled
        Trial , English
      </p>
      <p>
        Nogier P. Comment soulager les douleurs intolerables.{" "}
        <em>Revue d’auriculomedecine</em>. no. 22 Jan 1981 Journal Article
        French France
      </p>
      <p>
        Nogier P. Douleurs insupportables du plexus brachial.{" "}
        <em>Revue d’auriculomedicine </em>no. 22 Jan 1981 Journal Article French
        France
      </p>
      <p>
        Nogier P. Observations medicales -. Douleur symetrique.{" "}
        <em>Revue d’auriculomedicine </em>no. 13 Oct l978. Journal Article
        French France
      </p>
      <p>
        Pichard LE, Fermand SB. Apport de l’auriculotherapie dans les douleurs
        cancereuses sequellaires. <em>Annales du G.L.E.M.</em> (1997) 27
      </p>
      <p>
        Privitera P. Douleur viscerale en auriculomedicine.{" "}
        <em>Revue d’auriculomedicine</em> no. 22 Jan 1981 Journal Article French
        France France
      </p>
      <p>
        Rovere PM. Dall’agopuntura alla mayasomatologia nuove interpretazioni
        sull’agopunctura.{" "}
        <em>
          Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France: 27,28,29 May 1994 GLEM French
      </p>
      <p>
        Sanchez M, et A. La douleur viscerale et l’innervation des vaisseaux
        cerebraux. <em>Revue d’auriculomedicine</em> no. 28 Jul 1982 Venezuela
        Journal Article French France
      </p>
      <p>
        Van Gelder AF. Pathological points and their satellites, therapeutic
        consequences, especially in pain treatment.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM English
      </p>
      <p>
        Xu Y. Treatment of acute pain with auricular pellet pressure on ear
        shenmen as the main point. <em>J Tradit Chin Med</em> 1992 Jun;
        12(2):114-5 Medline 92356662.
      </p>

      <h2 id="sec4dot2">4.2 Back Pain, Sciatica, Lumbago, Hip, Buttocks</h2>
      <p>
        Kurland H D. Controversies in the relief of back pain auricular
        techniques: 20 year clinical perspective <em>Coherence </em>1998 : The
        2nd international IAAMER congress on: auricular diagnostics &amp;
        therapy Oisterwijk, The Netherlands September 19-21, 1997 issn 1565-0138
        Kenilworth, USA Abstract de Congress English Netherlands
      </p>

      <h2 id="sec4dot3">4.3 Migraines, Tension Headaches, Cluster Headaches</h2>
      <p>
        Baudet F. Migraine et auriculotherapy.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM
      </p>
      <p>
        Bossy J. Headache and ear acupuncture. First theoretical practical
        international seminary of complementary techniques. 1987. English. .
      </p>
      <p>
        Delpuech JP. Un cas de maigraine. <em>Revue d’auriculomedicine </em>no.
        22 Jan 1981 Journal Article French France
      </p>
      <p>
        Frimat M. Dix ans de migraine. <em>Bulletin scientifique du GLEM</em>{" "}
        no. 2 GLEM Journal Article French
      </p>
      <p>
        Massilunienne R. Auricular acupuncture in migraine treatment.{" "}
        <em>
          Annates du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM
      </p>
      <p>
        McKibbin LS, Downie R. Treatment of migraine headaches using auricular
        acupuncture techniques. <em>Laser Ther</em> 1993 5(l) 23-8
      </p>
      <p>
        Naguyen HF. Sclerose en plaque et cicatrice toxique.{" "}
        <em>Sciences et Medecines Nouvelles</em> N’l 1989 GLEM Journal Article
        French
      </p>
      <p>
        Rouxeville Y. Migrain.e <em>Revue d’auriculomedicine</em> no 32 Jul 1983
        Journal Article French France
      </p>
      <p>
        Yinlian L. 43 cases of migraine treated by auricular point pression
        method. <em>Chin J Acupunct Moxibustion</em> 1990 3(l) 57-9
      </p>

      <h2 id="sec4dot4">
        4.4 Neck and Shoulder Tension, Cervical Pain, Torticollis, Whiplash,
        Frozen Shoulder, Bursitis
      </h2>
      <p>
        Brenner T, Horvath M, Guidetti G. New aspects of the neuroreflexotherapy
        in the treatment of cervical syndrom and balance disorders
        <em>
          . Annales du Troisieme Symposium International d’Auriculotherapie et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM
      </p>
      <p>
        Martinez M. Torticolis spasmodique. <em>Revue d’auriculomedicine</em> no
        32 Jul 1983 Journal Article French France
      </p>

      <h2 id="sec4dot5">
        4.5 Extremities Pain: Foot, Ankle, Knee, Hand, Wrist, Carpal Tunnel,
        Tennis Elbow Pain
      </h2>
      <p>
        Pohakova A. The use of auriculotherapy in the rehabilitation of the
        patients with locomotive disorders controlled by electroacupuncture
        diagnostics. Annales du Troisieme Symposium International
        d’Auriculotherapy et d’Auriculomedicine 2000 Lyon France 26,27,28 May
        2000 GLEM English
      </p>
      <p>
        Razafitsalama D. Douleur traumatique de la jambe. Revue
        d’auriculomedicine no. 3 1 Apr 1983 Journal Article French France
      </p>
      <p>
        Strom H. Effect of electro-acupuncture of the ear on joint movement and
        pain after meniscectomy. A controlled triple-blind study. Ugeskr Laeger
        26;139(39) 1977 Sep 2326-9 Danish
      </p>

      <h2 id="sec4dot6">4.6 Arthritis: Osteoarthritis, Rheumatoid Arthritis</h2>
      <p>
        Boucinhas JC. Results of auricular colorpuncture on articular traumatic
        pain.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM English .
      </p>
      <p>
        Navach JH. Identification of patients with food sensitive osteoarthritis
        symptoms by HLA phenotype
      </p>

      <h2 id="sec4dot7">
        4.7 Dental Pain, TMJ Disorder, Toothaches, Gingivitis, Trigeminal
        Neuralgia, Facial Pain
      </h2>
      <p>
        Armani J. Applications cliniques dentaires.{" "}
        <em>Revue d’auriculomedicine</em> no 15 Apr 1979 Journal Article French
        France
      </p>
      <p>
        Armani J. De l’auriculo-medicine i ses applications dentaires.{" "}
        <em>Bailliare</em>, Paiis 1987. book French
      </p>
      <p>
        Armani J. Premier bilan de 1’emploi de l’auriculomedicine en art
        dentaire. <em>Revue d’auriculomedicine</em> no 26 Jan 1982 Journal
        Article French France
      </p>
      <p>
        Armani J. Traitement des gingivites en auriculo-dentaire.{" "}
        <em>Revue d’auriculomedicine</em> no 16 Jul 1979 Journal Article French
        France
      </p>
      <p>
        Armani J. Traitement indolore des caries du collet et traitement des
        parodontopathies par ]es champs magnetiques polarisds{" "}
        <em>Revue d’auriculomedicine</em> no 22 Jan 1981 Journal Article French
        France
      </p>
      <p>
        Bichet C. De l’auriculotherapie a l’auriculomedecine en
        odonto-stomatologie Lyon 1985{" "}
        <em>Bibliotheque interuniversitaire de medicine</em> (BIUMThesis French
      </p>
      <p>
        Bobrov OE, et al. Several problems of surgical treatment in acute
        biliary pancreatitis. <em>Klin Khir.</em> 1991-1 5.20-23. 91342069.
        Russian
      </p>
      <p>
        Bourdiol R. <em>Les neuralgies faciales en auriculotherapie</em>.{" "}
        <em>Journees de Besancon</em>, 1970. Book French .
      </p>
      <p>
        Chung H. Auricular injection of physiological saline for anesthesia for
        tooth extraction: report of 1,250 cases.{" "}
        <em>Chung Hua I Hsueh Tsa Chili</em> 1973; 20:94 Medline 74011884.
      </p>
      <p>
        Colin E. L’auriculomedicine en medicine dentaire.{" "}
        <em>Revue d’auriculomedicine</em> no. 26 Jan 1982 Journal Article French
        France
      </p>
      <p>
        Debard A. Thermographie de regulation et auriculomedicine en
        odontologie.
        <em>
          {" "}
          Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France: 27,28,29 May 1994 GLEM French<strong> </strong>
      </p>
      <p>
        Debard S. Le champ perturbateur dentaire, un probleme incontoumable.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM
      </p>
      <p>
        Delamarche M. L’auriculotherapie et l’odontostomatologie.{" "}
        <em>
          These Nancy 1996 Bibliotheque Interuniversitaire de Medicine (BILTM){" "}
        </em>
        French , 1973.
      </p>
      <p>
        Gueunet Y. Etude de l’interet pratique de l’auriculotherapie par le
        diascope en art dentaire{" "}
        <em>
          These Nancy 1996 Bibliotheque Interuniversitaire de Medicine (BILTM){" "}
        </em>
        French
      </p>
      <p>
        Jones JL. Craniomandibular disorders, neurophysiology, and
        auriculotherapy. <em>Basal Facts</em> 1987;9(4):127-31 Medline 89117539
        journal article English
      </p>
      <p>
        Kurland H. Reflex sympathetic dystrophy relieved by He-Ne laser
        auriculotherapy- a case history.{" "}
        <em>International J of Auricular Medicine</em> 1995
      </p>
      <p>
        Lapeer GL. Auriculotherapy in dentistry. <em>Cranio</em> 1986 Jul;4 (3):
        266-75 Medline 86272144 Journal article Eng
      </p>
      <p>
        Lapeer GL. Trigeminal neuralgia: treatment failure with auriculotherapy:
        two case reports. <em>Cranio</em> 1990 Jan; 8 (l):55-9 Medline 91275202
        Journal article English.
      </p>
      <p>
        Laurent A. Une nevralgie trigeminale. <em>Revue d’auriculomedicine </em>
        no. 17 Oct 1979 Journal Article French France .
      </p>
      <p>
        Mastalier O. Aurikulomedizin und ganzheitliche zahnheilkunde.{" "}
        <em>International J of Auricular Medicine</em> (IJAM) ISSN 0793-3150
        1996
      </p>
      <p>
        Milhet P. Applications de l’auriculotherapie en odonto-stomatologie{" "}
        <em>
          These Montpellier 1989 Bibliotheque Interuniversitaire de Medicine
          (BIUM)
        </em>{" "}
        Thesis French
      </p>
      <p>
        Nogier P, Corcelle A. Orientation des travaux Lyonnais sur I’analgesie
        dentaire. <em>Revue d’auriculomedicine </em>no. 17 Oct 1979 Journal
        Article French France.
      </p>
      <p>
        Nogier P. Correspondance des differentes dents avec certaines parties du
        pavilion de l’oreille. <em>Revue d’auriculomedicine</em> no. 15 Apr 1979
        Journal Article France
      </p>
      <p>
        Nogier P. Identification de la maladie aux cent visages.{" "}
        <em>Revue d’auriculomedicine</em> no. 27 Apr 1982 Journal Article French
        France
      </p>
      <p>
        Nogier P. Observations medicales: nevralgie faciale.{" "}
        <em>Revue d’auriculomedicine </em>no. 13 Oct l978 Journal Article French
        France
      </p>
      <p>
        Nogier P. Une douleur de la face. <em>Revue d’auriculomedicine </em>no.
        29 Oct l982 Journal Article French France
      </p>
      <p>
        Nogier P.<em> Revue d’auriculomedicine</em> no. 15 Apr 1979 Journal
        Article French France
      </p>
      <p>
        Novak A. Fracture du coude. <em>Revue d’auriculomedicine </em>no. 32 Jul
        1983 Journal Article French France
      </p>
      <p>
        Oca C, Ellie J, Doutremepuich Ch, Fontan F. Electro-auriculo-acupuncture
        balancee dans la chirurgie cardiaque chez 1’enfant, travail de la
        clinique. <em>Chirurgicale des maladies cardiaques</em>{" "}
        <strong> </strong>
      </p>

      <p>
        Oca C, Ellie J, Doutremepuich CM, Fontan F.
        L’electro-auriculo-acupuncture balancee dans la chirurgie cardiaque chez
        1’enfant. Ro1e des endorphines. <em>Revue d’auriculomedicine</em> no. 26
        Jan 1982 Journal Article French France
      </p>
      <p>
        Pic H. Approche de la consultation en auriculodentaire.{" "}
        <em>Annales du G.L.E.M.</em> (1996)
      </p>
      <p>
        Razafitsalama D. Douleur trijeminale d’origine inconnue.{" "}
        <em>Revue d’auriculomedicine</em> no. 31 Apr 1983 Journal Article French
        France
      </p>
      <p>
        Romoli M. Variations electromyographiques dans le bruxisme apres
        stimulation auriculaire.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM French
      </p>
      <p>
        Roths A. De l’interet du traitement par frequences en auriculo-dentaire.{" "}
        <em>Revue d’auriculomidecine</em> no. 17 Oct 1979 Journal Article French
        France
      </p>
      <p>
        Sagne R. Observation curieuse et instructive d’une neuralgie
        trigeminale. <em>Revue d’auriculomedicine </em>no. 18 Jan 1980 Journal
        Article French
      </p>
      <p>
        Schneider R. Un foyer dentaire<em>. Revue d’auriculomedicine</em> no. 30
        Jan 1983 Journal Article French France
      </p>
      <p>
        Steidl L, Debef J, Jandova D, Kasparek J, Tmecka J. Trigeminofacial
        reflex. III. Effect of auriculotherapy.{" "}
        <em>Acta Univ Palacki Olomuc Fac Med</em> 1987 117 141-50 Medline 892443
        73 Journal article
      </p>
      <p>
        Touati E. Vauriculotherapie peut-elle etre utile a
        l’odonto-stomatologie. Paris 5 montrouge 1988{" "}
        <em>Bibliotheque Interuniversitaire de Medecine (BILM</em> Thesis French
      </p>
      <p>
        Valery LP Acupuncture and auriculotherapy and its applications in the
        field of dentistry <em>Chir Dent Fr</em> 1972 Jun 7;42(119):63 -5
        Medline 72240134 journal article French
      </p>
      <p>
        Vuilliez C. Peut-on diagnostiquer et traiter un foyer dentaire par le
        laser? <em>Revue d’auriculomedicine</em> no. 24 Jul 1981 Journal Article
        French France
      </p>
      <p>
        Vulliez C, Nogier R.{" "}
        <em>Precis pratique de lasertherapie en odontostomatologie.</em> 1995
        GLEM book French
      </p>
      <p>
        Vulliez C. Douleur de la face: action du laser infrarouge a frequences
        variables. <em>Revue d’auriculomedicine </em>no. 28 Jul 1982 Journal
        Article French
      </p>
      <p>
        Vulliez C. Ions metaliques en odotonstomatologie.{" "}
        <em>Annales du G.L.E.M.</em> (1996)
      </p>
      <p>
        Wojak W. Control and therapy of the bite by acupuncture according to the
        TMJ and the role of the muscles of the vertebral column in this
        particular case.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM English Wong CW.{" "}
        <em>Acupuncture by the ear</em>. Cheong Kee Book Co 1974
      </p>

      <h2 id="sec4dot8">
        4.8 Analgesia, Anesthesia, Surgery, Post-Operative Pain, Post-Operative
        Complications
      </h2>
      <p>
        Asis D. Analgesia postoperatoria con auriculoterapia en artroscopia de
        Rodillia. Annales du Premier Symposium International d’Auriculotherapie
        et d’Auriculomedecine Lyon France -. Haug editeur Bruxelles. 27,28,29
        May 1994 GLEM French.
      </p>
      <p>
        Baum J, Schilling A. Combined-electrostimulation-hypalgesia in surgery
        of the lumbar vertebral column. A tentative evaluation of this method
        (author’s transl). <em>Anaesthesist</em> 1979 May 28 (5):227-36 Medline
        79229627 German.
      </p>
      <p>
        Borzeix G, Labos M, Harte C. Recherche de transfert serique d’analgesie
        (ITERC). <em>Revue d’auriculomedicine </em>no. 24 Jul 1981 Journal
        French France.
      </p>
      <p>
        Bourdiol R. Analgesie en neuro-radiologie par stimulation du pavilion de
        l’oreille. <em>Revue d’auriculomedicine </em>no. 2 Jan 76 Journal
        Article French France.
      </p>
      <p>
        Broedersdorf F. Auricular-electric-stimulation-anaesthesia (AESA).{" "}
        <em>Coherence</em> 1998 : The 2nd international IAAMER congress on:
        auricular diagnostics &amp; therapy September 19-21, 1997 Oisterwijk,
        The Netherlands issn 1565-0138 Germany Abstract de congres/Congress
        English Netherlands.
      </p>
      <p>
        Ceccherelli F, Ambrosio F, Adami MG, et al. Failure of high frequency
        auricular electrical stimulation to relieve postoperative pain after
        cholecystectomy. Results not improved by administration of aprotinin{" "}
        <em>Dtsch Z Akupunktur</em> 1985 87-92 28(4) German.
      </p>
      <p>
        Ceccherelli F, Manani G, Ambrosio F, Angel A, Valenti S, Facco E, Giron
        GP. Influence of acupuncture on the postoperative complications
        following ketamine anesthesia. The importance of manual stimulation of
        point R and shen menn, <em>Acupunct Electrother Res</em> 1981;
        6(4):255-64 Medline 82226928.
      </p>
      <p>
        Dalal S, Shetty N. Clinical application of acupuncture moxibustion.
        Peking, China, 99-101 <em>Acubase Disponible a la Biu de Nimes</em>:
        English.
      </p>
      <p>
        Darwin CR. Analgesia por acupuntura.{" "}
        <em>
          Annales du Premier Symposium International d’Auriculotherapie et
          d’Auriculomedecine
        </em>{" "}
        Lyon France: Haug editeur Bruxelles. 27,28,29 May 1994 GLEM.
      </p>
      <p>
        Facco E, Manani G, Angel A, Vincenti E, Tambuscio B, Ceccherelli F,
        Troletti G, Ambrosio F, Giron GP. Comparison study between acupuncture
        and pentazocine analgesic and respiratory post-operative effects.{" "}
        <em>Amer J Chin Med</em> 1981 Aut; 9(3)-.225-35 Medline 83253048.
      </p>
      <p>
        Jiang J. Clinical study and application of auricular magnet anesthesia
        for the operation of the thyroid.<em> Chen Tzu Yen Chiu </em>1995-
        20(3):4-8 1995 3 4-8 Medline 96333697.
      </p>
      <p>
        Kozma A. Auriculotherapy-a method for inducing analgesia in the
        stomatological practice<em>. Rev Chir Oncol Radiol</em> 1987 Apr/Jun 34
        (2): 139-49 Medline 89265952 journal article.
      </p>
      <p>
        Lequang T, Badaoui R, Riboulot M, Verhaeghe P, Ossart M. Postoperative
        analgesia by auriculotherapy during laparoscopic cholecystectomy .
        <em>Cah Anesthesiol</em> 1996;44 (4) : 289-92 Medline 97186248. Journal
        Article French.
      </p>
      <p>
        Lewis GB. An alternative approach to premedication : comparing
        diazepAmer with auriculotherapy and a relaxation method.{" "}
        <em>Amer J of Acupuncture</em>, 1987, vol, 15, no 3, 205-214.
      </p>
      <p>
        Martynova GI, Kurabtseva ON, Malyshev AV, Komissarov VI. The role of
        non-traditional methods of analgesia in the postoperative period.{" "}
        <em>Anesteziol Reanimatol</em> 1990 Mar; (2):50-1 Medline 90379547.
      </p>
      <p>
        Mastroianni A. The treatment of postoperative pain with the use of
        semipermanent auricular needles. <em>Panminerva Med</em> 1985 Jan;
        27(l)-39-42 1985 Jan 1 39-42 Medline 85297390.
      </p>
      <p>
        Meas Y. A propos d’un cas d’analgesie chirurgicale par auriculomedecine.{" "}
        <em>Sciences et Medecines Nouvelles</em> Vol I N’3 GLEM Journal Article
        French.
      </p>
      <p>
        Meas Y. L’analgesie par auriculotherapie et auriculomedecine. Annales du
        Premier Symposium International d’Auriculotherapie et d’Auriculomedicine
        Lyon France : Haug editeur Bruxelles. 27,28,29 May 1994 GLEM French.
      </p>
      <p>
        Navach JH. Accumulation of electromagnetically sensitive organic
        compounds at sites of surgical injury.
      </p>
      <p>
        Piro C. Compte rendu d’une analgesie par auriculotherapie.{" "}
        <em>Revue d’auriculomedicine </em>no. 16 Jul 1979 Journal Article French
        France.
      </p>
      <p>
        Wang FH, Chen CL, Chen MC, Wang PY, Lin JM, Jih KS. Auricular
        electroacupuncture for post thoracotomy pain.{" "}
        <em>Chung Hua I Hsueh Tsa Chih</em> 1988 May; 41(5):349-56 Medline
        89119194.
      </p>
      <p>
        Wu H, Bi L, Shen P, Li Z, Zhu P. Clinical observation and mechanism
        study on application of auricular-pressing pill for postoperative
        analgesia. <em>J Tradit Chin Med</em> 1997 Mar; 17 (l):26-31 Medline
        99366293.
      </p>
      <p>
        Wu H, Bi L, Xu C, Zhu P. Analgesic effect of pressure on
        auriculoacupoints for postoperative pain in 102 cases.{" "}
        <em>J Tradit Chin Med</em> 1991 Mar; 1l (l) -22-5.
      </p>
      <p>
        Wu H, Bi LY, Xu CS, Zhu PT. Clinical observation of 50 cases of
        postoperative incisional pain treated by auricularacupoint pressure.{" "}
        <em>J Tradit Chin Med</em> 1989 Sep; 9(3):187-9 Medline 90135291.
      </p>
      <p>
        Xudong G. Clinical study on analgesia for biliary colic with ear
        acupuncture at point Erzhong. <em>Amer J Acupunct</em> 1993; 21 (3):
        237-9.
      </p>
      <p>
        Zanini F. Current role of acupuncture in analgesic therapy.{" "}
        <em>Minerva Med</em> 1983 Apr 21;74( 17):961-7 Medline 83193059 Journal
        article Italian.
      </p>

      <h2 id="sec4dot9">4.9 Burns, Wound Care</h2>
      <p>
        Lewis SM, Clelland JA, Knowles CJ, Jackson JR, Dimick AR. Effects of
        auricular acupuncture-like transcutaneous electric nerve stimulation on
        pain levels following wound care in patients with burns: a pilot study.{" "}
        <em>J Burn Care Rehabil</em> 1990 Jul- 11(4)-322-9 Medline 90383219.
        Controlled Clinical Trial Review, English
      </p>

      <h2 id="sec6dot1">6.1 General Psychiatry and Psychology</h2>
      <p>
        Atwood T. Acudetox as an alternative treatment for symptom management of
        serious mental illness. Convegno Intemazionale NADA-1997 (Milano, Italy)
        1997 812
      </p>
      <p>
        Boucher J. Ma pratique des points psychologiques.{" "}
        <em>Revue d’auriculomedicine</em> no 16 Jul 1979 Journal Article French
        France
      </p>
      <p>
        Helena H. Action of auriculotherapy upon psychic evolution in boy with
        psychomotor retardation.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France
      </p>
      <p>
        Hofman SW. Topography of reflex zones of head and ear in relation with
        clinical psychopathology <em>Inl J of Auricular Medicine</em> 1995
      </p>
      <p>
        Leclerc B. Les cephalees. <em>Annales du G.L.E.M.</em> (1996)
      </p>
      <p>
        Lentz A. Psychisme et Auriculomedicine.{" "}
        <em>Bulletin de liaison de I’AMABF </em>no. 1 Mar 1982
      </p>
      <p>
        Nogier P. Les points psychiques (suite).{" "}
        <em>Revue d’auriculomedicine</em> no. 5 Oct 1976 Journal Article French
        France
      </p>
      <p>
        Nogier P. Les problemes du sommeil. <em>Revue d’auriculomedicine</em>{" "}
        no. 26 Jan 1982 Journal Article French France
      </p>
      <p>
        Nogier P. Points psychologiques. <em>Revue d’auriculomedicine</em> no. 4
        Jul 1976 Journal Article French France
      </p>
      <p>
        Nogier P. Reflexion a propos de la localisation des points psychiques.{" "}
        <em>Revue d’auriculomedicine</em> no. 4 Jul 1976 Journal Article French
        France
      </p>
      <p>
        Para F. Emotive stress and the carpal tunnel syndrome auriculotherapy,
        clinical and electrophysiological evaluation.{" "}
        <em>
          Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France: Haug editeur Bruxelles. 27,28,29 May 1994 GLEM
      </p>
      <p>
        Torti E. Diagnosis and treatment of psycho-affective disorders
        <em>
          . Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM English
      </p>
      <p>
        Veenstra M. Alzheimer’s disease and ADHD in relation to sleep disorder.{" "}
        <em>Coherence</em> 1998 : the 2nd international IAAMER congress on:
        auricular diagnostics &amp; therapy September 19-21, 1997 Oisterwijk,
        Netherlands
      </p>

      <h2 id="sec6dot2">6.2 Schizophrenia, Psychosis, Hallucinations</h2>
      <p>
        Nogier P. Manifestations schizophriniques.{" "}
        <em>Revue d’auriculomedicine</em> no. 8 Jul 1977 Journal Article French
        France
      </p>
      <p>
        Shi ZX. Observation on the curative effect of 120 cases of auditory
        hallucination treated with auricular acupuncture. J Tradit Chin Med 1989
        Sep; 9 (3): 176-8 Medline 90135286 Journal article English China
      </p>
      <p>
        Shi ZX. Observation on the therapeutic effect of 120 cases of
        hallucination treated with auricular acupuncture.{" "}
        <em>J Tradit Chin Med</em> 1988 Dec; 8 (4): 263-4 Medline 89237272
      </p>

      <h2 id="sec6dot3">6.3 Depression, Mood Disorders</h2>
      <p>
        Han JS. Electroacupuncture: an alternative to anti-depressants for
        treating affective diseases? <em>International J of Neuroscience</em>{" "}
        1986 Vol. 29 pp. 79-92
      </p>
      <p>
        Luo HC, et al. A comparative study of the treatment of depression by
        electroacupuncture and amitriptyline. China.
      </p>
      <p>
        Luo HC, Shen YC, Jia YK. Clinical study of electro-acupuncture on 133
        patients with depression in comparison with tecylic amitriptyline.{" "}
        <em>Chung Hsi J Chieh Ho Tsa Chih</em> 1988 Vol 8, No. 2, 77-80, 68
      </p>
      <p>
        Van Gelder A. Depression and the mental body. <em>Coherence</em> 1/98:
        the 2nd international IAAMER congress on: auricular diagnostics &amp;
        therapy. September 19-21, 1997 Oisterwijk, The Netherlands Rotterdam,
        English Netherlands
      </p>

      <h2 id="sec6dot4">
        6.4 Insomnia, Anxiety, Stress, Psychosomatic Disorders
      </h2>
      <p>
        Dahout C. Insomnie. <em>Revue d’auriculomedicine</em> no 32 Jul 1983
        Journal Article French France
      </p>
      <p>
        Deipuech JP. Auriculomedicine et maladie psychosomatique.{" "}
        <em>Revue d’auriculomedicine</em> no 27 Apr 1982 Journal Article French
        France
      </p>
      <p>
        Lee TN. Lidocaine injection of auricular points in the treatment of
        insomnia. <em>Amer J Chin Med</em> 1977 Spr-1 5 (l): 71-7 Medline
        77154533 Journal article English United States
      </p>
      <p>
        Leib S. Psychosomatische und somatopsychische probleme in der
        aurikulomedizin<em>. International J of Auricular Medicine</em> 1995
      </p>
      <p>
        Li J. Chrono-acupuncture (zi wu liu zhu) treatment for sleeplessness.{" "}
        <em>Coherence</em> 1/98: The 2nd international IAAMER congress on:
        auricular diagnostics &amp; therapy Oisterwijk, The Netherlands
        September 19-21, 1997 English Netherlands
      </p>
      <p>
        Lian N, Yan Q. Insomnia treated by auricular pressing therapy.{" "}
        <em>J Tradit Chin Med</em> 1990 Sep 3 174-5 Medline 91116900
      </p>
      <p>
        Navach JH. Designs of psychosomatic and somatopsychic disorders by use
        of Wrattan filters, phases V, X, and the VAS. Nogier Seminar, Montreal,
        Quebec October, 1984
      </p>
      <p>
        Tabeeva DM, Akhtiamov IS. Effect of auricular acupuncture on the
        organization of night sleep <em>Klin Med</em> (Mosk) 1980 Oct; 58 (10):
        102-5 Medline 81073191 Russian
      </p>
      <p>
        Van Gelder A. Sleep disorders and the causal body. <em>Coherence</em>{" "}
        1998 the 2nd international IAAMER congress on: auricular diagnostics
        &amp; therapy September 19-21, 1997 Oisterwijk, English Netherlands
      </p>
      <p>
        Yang CL. Clinical observation of 62 cases of insomnia treated by
        auricular point imbedding therapy. <em>J Tradit Chin Med</em> 1988 Sep;
        8 (3): 190-2 Medline 89111607
      </p>

      <h2 id="sec7dot1">
        7.1 Asthma, Bronchitis, Rhinitis, Sinusitis, Coughs, Hiccups
      </h2>
      <p>
        Bahr FR. Bronchial asthma and auriculo-acupuncture (author’s transl).{" "}
        <em>Prax Klin Pneumol</em>, 1979 Apr, 33 Suppi I:, 689-94 Medline
        79223734 Journal article German
      </p>
      <p>
        Braemer C. La sinusite <em>Revue d’auriculomedicine</em> no. 10 Jan 78
        Journal Article French France
      </p>
      <p>
        Ciu Y. Needling auricular point heart in treatment of dysphonia- report
        of 170 cases. <em>Int J Clin Acupunct</em> 1993; 4(3): 273-6.
      </p>
      <p>
        Danielovi D, Milan K. Validation of bronchodilator effect of
        auriculotherapy
        <em>
          . Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM English
      </p>
      <p>
        Delpuech JP. Un cas de tracheite chronique.{" "}
        <em>Revue d’auriculomedicine</em> no. 23 Apr 1981 Journal Article French
        France
      </p>
      <p>
        Dvorkin E. Pharmacucupuncture using HEEL drugs in respiratory diseases
        <em>. International J of Auricular Medicine</em> : 2nd annual conference
        of the medical society of acupunture of the Israeli Medical Association
        1995 Bat-Yam, Israel English
      </p>
      <p>
        Hu J. Clinical observation on 25 cases of hormone dependent bronchial
        asthma treated by acupuncture<em>. J Tradit Chin Med</em> 1998 Mar;
        18(l): 27-30 Medline 99366312
      </p>
      <p>
        Leclerc, B. Un point miraculeux contre les ronflements.{" "}
        <em>Annales du G.L.E.M.</em> (1998)
      </p>
      <p>
        Li X, Jingqiu Y, Qi B. Treatment of hiccough with auriculo acupuncture
        and auriculo traitement du hoquet par auriculopuncture et pression de
        points auriculairespressure a report of 85 cas.{" "}
        <em>J of Tradit Chinese Medicine</em>, 1990, vol. 10, no 4, 257-259
        Journal article English China
      </p>
      <p>
        Mitrofanova NI, Zagriadskii VA, Durinian RA. Auriculotherapy in the
        treatment of bronchial asthma. <em>Ter Arkh</em> 1977;49 (3): 127-9
        Medline 77175242 Journal article Rus
      </p>
      <p>
        Nezabudkin SN, Kachan AT, Fedoseev GB, Gamaiunov KP. The reflexotherapy
        of patients with respiratory allergoses. <em>Ter Arkh</em> 1992; 64
        (l)-64-7 1992 1 64-7 Medline 92397221 Journal article Russian
      </p>
      <p>
        Razafitsalama D. Sinusite ethmoidale. <em>Revue d’auriculomedicine</em>{" "}
        no. 31 Apr 1983 Journal Article French France
      </p>
      <p>
        Shulan L. 47 cases of severe hiccup treated by auricular acupuncture.{" "}
        <em>Chin J Acupunct Moxibustion</em> 1990 3 (1) : 55-6.
      </p>
      <p>
        Yan S. 14 cases of child bronchial asthma treated by auricular plaster
        and meridian instrument.
      </p>
      <p>
        Yang Z. Observation clinique sur la regularisation de la fonction
        respiratoire par I’auriculo acupuncture Selection des theses de la revue
        d’acupuncture de shanghai,numero special pour les maladies internes,
        1987,32-34 Shanghai : Association d’acupuncture de Shanghai Acubase
        Disponible a la BIU de Nimes
      </p>

      <h2 id="sec7dot2">
        7.2 Cardiovascular Disorders, Coronary Disorders, Angina, Cardiac
        Arrhythmias, Tachycardia
      </h2>
      <p>
        Jianhua M, Yonsian X, Ningning Z, Jin Q, Moxun D. The effect of
        electroacupuncture at auricular heart area on the eletrocardiogrAmer
        [electrocardiogram] and the cardiac function
        <em>. World J Acupunct Moxibustion</em> 1992 Dec 2 (4) 19-22.
      </p>
      <p>
        Laforgue D. Auriculo-medecine et troubles du rythme.{" "}
        <em>Revue d’auriculomedicine</em> no. 12 Jul 1978 Journal Article French
        France
      </p>
      <p>
        Laforgue D. Auriculo-medicine et trouble du rythme.{" "}
        <em>Revue d’auriculomedicine</em> no. 11 Apr 1978 Journal Article French
        France
      </p>
      <p>
        Meerson FZ, Beloshitskil PV, Radzievskil SA, Vorontsova FY, Didenko VE.
        Influence of transauricular electroacupuncture on ischemic and
        reperfusion arrhythmias in middle mountain conditions.{" "}
        <em>Doki Biol Sci</em> 1989 304 (1-6) 122-4.
      </p>
      <p>
        Radzievskii SA, Vorontsova E. The effect of electroacupuncture and
        acupuncture on ischetac and reperfiision cardiac arrhythmias.{" "}
        <em>Vopr Kurortot Fizioter Lech Fiz Kult</em> 1989 Nov; (6): 7-9 Medline
        90194783 JournalArticle Russian
      </p>
      <p>
        Sanchez M. et A. Deux cas de troubles vasculaires des membres
        inferieurs. <em>Revue d’auriculomedicine</em> no 26 Jan 1982 Journal
        Article French France
      </p>
      <p>
        Sobetskiy V. Tabagism treatment by reflexotherapy and auricular therapy
        of stage I and stage II hypertonic disease.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM English
      </p>
      <p>
        Zhou JR. Effect of auriculo-acupuncture plus needle embedding in heart
        point on left cardiac, humoral and endocrine function.{" "}
        <em>Chung Kuo Chung Hsi I Chieh Ho Tsa Chih</em>, 1993 Mar, 13:3, 153-4,
        132 Clinical Trial; Journal Article; Randomized Controlled Trial Chinese
        China
      </p>
      <p>
        Zhou XQ, Liu JX. Metrological analysis for efficacy of acupuncture on
        angina pectoris. <em>Chung Kuo Chung Hsi I Chieh Ho Tsa Chih</em>, 1993
        Apr, 13:4, 212-4. Clinical Trial; Journal Article; Randomized Controlled
        Trial Chinese
      </p>

      <h2 id="sec7dot3">
        7.3 Hypertension, Blood Pressure, Sympathomimetic Vascular Effects
      </h2>
      <p>
        Akhmedov TI, Vasilev IM, Masliaeva LV. The hemodynamic and neurohumoral
        correlates of the changes in the status of hypertension patients under
        the influence of acupuncture. <em>Ter Arkh</em> 1993; 65(12):22-4
        Medline 94196477 Russian
      </p>
      <p>
        Braverman SE. Essential vascular hypertension.{" "}
        <em>Medical Acupuncture </em>Spring / Summer 1998 Volume 10 No. 1
      </p>
      <p>
        Frinerman E, Dvorkin E. Hemodynamic changes during puncture of
        beta-blocker analogue auricular point.{" "}
        <em>International J of Auricular Medicine</em> (IJAM) 1995
      </p>
      <p>
        Gaponiuk P, Leonova MV. The clinical efficacy of auricular
        electroacupuncture in treating hypertension patients.{" "}
        <em>Vopr Kurortol Fizioter Lech Fiz Kult</em> 1990 Jan; (1): 13-5
        Medline 90246780 Russian
      </p>
      <p>
        Gaponiuk P, Sherkovina TJ, Leonova MV. Clinical effectiveness of
        auricular acupuncture treatment of patients with hypertensive disease
        acupuncture in medicine. Vol. XI No 1 May 1993 Page 29 BMAS, Newton
        House, Newton Lane, Lower Whitley, Warrington, Cheshire, WA
      </p>
      <p>
        Gaponiuk P, Sherkovina TJ, Leonova MV, Krasnikov VE. Clinical
        effectiveness of auricular acupuncture therapy with hypertension
        patients. <em>Vopr Kurortol Fizioter Lech Fiz Kult</em> 1988 Jul
        (4):16-9 Medline 89059346 Russian
      </p>
      <p>
        Gaponiuk P, Sherkovina TJ, Leonova MV. Acupuncture stimulation of the
        auricular points in hypertension patients with hypoand eukinetic types
        of blood circulation. <em>Vopr Kurortol Fizioter Lech Fiz Kult</em> 1987
        Jul; (4):53-4 Medline 88072172 Russian
      </p>
      <p>
        Gaponiuk P, Sherkovina TJ. The clinical and physiological foundation of
        auricular acupuncture therapy in patients with hypertensive disease.{" "}
        <em>Acupuncture in Medicine</em> VOL XII No I May 1994 BMAS, Newton
        House..
      </p>
      <p>
        Gaponiuk PI, Leonova MV, Sherkovina TI, Iotova VG. The effect of
        auricular electroacupuncture on the initial manifestations of cerebral
        circulatory failure in hypertension patients.{" "}
        <em>Vopr Kurortol Fizioter Lech Fiz Kult</em> 1990 Nov (6): 31-4 Medline
        91173610 Russian
      </p>
      <p>
        Huang HQ, Liang SZ. Improvement of blood pressure and left cardiac
        function in patients with hypertension by auricular acupuncture.{" "}
        <em>Chung Hsi I Chich Ho Tsa Chili</em> 1991 Nov- 11 (11): 654-6, 643-4
        Medline 92257676 Chinese
      </p>
      <p>
        Leclerc B. HTA et Auriculotherapie. <em>Annales du G.L.E.M</em>. (1996)
      </p>
      <p>
        Monaenkov AM, Lebedeva OD, Deena IF. Use of graded bicycle ergometry as
        a method for the objective evaluation of the efficacy of reflexotherapy
        in the early stages of hypertension. <em>Ter Arkh</em> 1984, 56:9, 34-6
        Medline 85090914 Journal Article German
      </p>
      <p>
        Pal’tseva IS, Fisenko LA; Abbakumov SA. Change in central hemodynamics
        and systolic phase structure as affected by reflexotherapy in patients
        with neurocirculatory dystonia. <em>Kardiologiia</em>, 1985 Aug, 25 8,
        49-53 Medline 86063656 JournalArticle Russian
      </p>
      <p>
        Romeu G, Asis D, Pautasso O, Gaydou A. Efecto de la auriculoterapia en
        la hipertension arterial. Congres de Natal 1997/ Site internet du GLEM
        Arterial Hypertension Section, Argentina. Abstract de Congress Spanish
      </p>
      <p>
        Sherkovina T, Gaponiuk P. Effect of auricular acupuncture therapy on
        central hemodynamics in patients with hypertension.{" "}
        <em>Vopr Kurortol Fizioter Lech Fiz Kult</em> 1988 Jan- (I)-20-2 Medline
        88237278 Russian
      </p>
      <p>
        Spacek A, Huemer G, Grubhofer G, Lackner FX, Zwolfer W, Kress HG. The
        use of ear acupuncture (P29-PAD, Occiput) in the case of a drop in blood
        pressure following the administration of thiopental.{" "}
        <em>Dtsch Z Akupunkt</em> 39(l) 1996 18-22 German
      </p>
      <p>
        Tabeeva DM, Shagieva LK. Comparative analysis of the efficacy of
        different methods of acupuncture in the hyperand hypokinctic types of
        circulation in hypertensive patients. <em>Zh Nevropatol Psikhiatr</em>{" "}
        1984; 84 (l): 47-50 Medline 84149452 Russian
      </p>
      <p>
        Zhou R, Zhang Y, Wang J, Chang H, Fang J, Chen E. Anti hypertensive
        effect of auriculo acupoint pressing therapy clinical analysis of 274
        cases.. <em>J of Tradit Chinese Medicine</em>, 199l, vol. 11, no 3,
        189-192 Sep English
      </p>

      <h2 id="sec7dot4">
        7.4 Gastro-Intestinal, Constipation, Diarrhea, Colitis, Ulcer, IBD,
        Hemorrhoids, Epigastric
      </h2>
      <p>
        Antonov AM, Mosiagin VV, Iaitskii NA, Grinenko NN, Antonova IA. The use
        of auricular puncture in the combined treatment of acute cholecystitis
        in elderly persons. estn <em>Khir Im II Grek</em> 1995; 154 (3): 104-5
        Medline 96290221.
      </p>
      <p>
        Borozan S, Petkovic G. Ear acupuncture has a hypotonic effect on the
        gastrointestinal tract. <em>Vojnosanit Pregi</em> 1996 Jan; 53 (l): 31-3
        Medline 97317285 Serbo-Croatian
      </p>
      <p>
        Chen G. How to enhance the therapeutic efficacy of auriculo point seed
        pressing method in the treatment of cholelithiasisfra: comment
        renforcer. <em>J of Tradit Chinese Medicine</em>, 199l, vol. 1l, no 4,
        263 -271 Medline Journal Article English China
      </p>
      <p>
        Degtiareva II, Kharchenko NV. Nondrug methods in the combined treatment
        of peptic ulcer patients<em>. Lik Sprava</em> 1992 Sep; (9): 76-80
        Medline 93127635 Journal article Russian
      </p>
      <p>
        Flament C. Une crise d’hemorroides. <em>Revue d’auriculomedicine </em>no
        31 Apr 1983 Journal Article French France
      </p>
      <p>
        Hep A, Presek J, Dolina J,Ondrousek L, Dlte P. Treatment of esophageal
        motility disorders with acupuncture of the ear (preliminary report).{" "}
        <em>Vnitr Lek</em> 1995 Jul; 41 (7): 473-5 Medline 96058455 Journal
        article Czech. Czech Republic
      </p>
      <p>
        Hu J. Acupuncture treatment of epigastric pain.{" "}
        <em>J Tradit Chin Med</em> 1995 vol 3 p. 238-240.
      </p>
      <p>
        Martinez M. Pyrosis post-prandial. <em>Revue d’auriculomedicine</em> no.
        32 Jul 1983 Journal Article French France
      </p>
      <p>
        Mounir RJ. La auriculomedicinea en el tratamiento del colon irritable.{" "}
        <em>Proelsa SA</em> 1987 Spain
      </p>
      <p>
        Secondy A. Sommeil et maladies. <em>Revue d’auriculomedicine</em> no. 14
        Jan 1979 Journal Article French France
      </p>
      <p>
        Wang T. Xiao S. Auricular acupoint pellet pressure therapy in the
        treatment of cholelithiasis. <em>J Tradit Chin</em> <em>Med</em> 1990
        Jun; 10 (2) : 126-31 Medline 90362900
      </p>
      <p>
        Zulueta C. Nuevo punto de auriculoterapia para mejorar el aprendizaje
        escolar y la memoriam.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM Spanish
      </p>

      <h2 id="sec7dot5">
        7.5 Liver Disease, Cirrhosis, Bilary Stones, Gall Bladder Disorders,
        Appendicitis
      </h2>
      <p>
        Lebel M. Problems of the gallbladder and treatment with
        auriculomedicine.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM English
      </p>
      <p>
        Li Y, Tang X, Zhang Y, Wu F. The effect of stimulating the auricular
        liver-gall acupoint with electrode on synaptic of nucleus originis
        dorsalis nervi vagi in rabbits. <em>Chen Tzu Yen Chiu</em> 1992; 17 (3):
        201-6 Journal article Chinese China
      </p>
      <p>
        Zhang R, Ma SZ, Zhang TQ. The effect of auricular-plaster therapy on
        gallstone expulsion and on expansioncontraction function of the biliary
        system-a clinical analysis of 57 cases. J Tradit Chin Med 1986 Dec;
        6(4):263-6 Medline 87256082
      </p>

      <h2 id="sec7dot6">
        7.6 Urological Disorders of Kidney or Bladder, Prostate Problems,
        Enuresis
      </h2>
      <p>
        Ben H, Zhu Y. The effect of electro-acupuncture at auricular and body
        acupoints on the curve changes of the pressure-volume of urinary bladder
        and the electric activity of pelvic nerves of rat.{" "}
        <em>Chen Tzu Yen Chiu</em> 1995; 20(2):51-4 Medline 96296507 Journal
        article Chinese China
      </p>
      <p>
        Leclerc B. L’enuresie en pratique journalire sur 17 cas en 2 ans.{" "}
        <em>Annales du G.L.E.M.</em> (1998)
      </p>
      <p>
        Limonat de Kerimel Y. Un cas rare d’enuresie.{" "}
        <em>Revue d’audculomedicine</em> no. 31 Apr 1983 Journal Article French
        France
      </p>
      <p>
        Mallard A, Petitjean F. A propos d’une enuresie.{" "}
        <em>Revue d’auriculomedicine</em> no. 32 Jul 1983 Journal Article French
        France
      </p>
      <p>
        Milani L. Cases of enuresis nocturna treated with single reflexotherapy.
        Clinical and therapeutic evaluation <em>Minerva Med</em> 1976 Nov 24; 67
        (57): 3753-6 Medline 77077623 Journal article Italian
      </p>
      <p>
        Tian L, Yuan S, Ba E, Chen H, Zhou Z. <em>J Tradit Chin Med,</em> 1995
        Mar, 15:1, 34-7 Medline 95302779 Journal Article; Randomized Controlled
        Trial English China
      </p>
      <p>
        Wang Q, Li Z, Wang Y. Clinical observation on 103 cases of enuresis
        treated by auricular point pression therapy.{" "}
        <em>Chin J Acupunct Moxibustion</em> 1991 4(2) 109-11
      </p>

      <h2 id="sec7dot7">
        7.7 Gynecology, Dysmenorrhea, PMS, Menopause, Pelvic Pain
      </h2>
      <p>
        Bondi N, Albo R. Dysmenorrhea. Acupuncture treatment of 40 cases coming
        to our attention. Clinical note <em>Minerva Med</em> 1981 Sep;
        72(33):2227-30 Medline 82036327 Journal article Italian Italy
      </p>
      <p>
        Lewers D, Clelland JA, Jackson JR, Vamer RE, Bergman J. Transcutaneous
        electrical nerve stimulation in the relief of primary dysmenorrhea.{" "}
        <em>Phys Ther</em> 1989 Jan; 69 (l):3 -9 Medline 89099343 Spain clinical
        trial; journal article
      </p>
      <p>
        Lozano F. Auriculotherapy and dismenorhea.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM Spanish Lu H.{" "}
        <em>A complete textbook of auricular acupuncture.</em> Vancouver, B, C.
        Canada: Academy of Oriental Heritage. 1975 book
      </p>
      <p>
        Oleson T, Flocco B. Randomized control study of premenstrual syndromes
        triggered with ear, hand and foot reflexology.{" "}
        <em>Obstetrics and Gynecology</em>, 86, No. 6, 1993, 906-911
      </p>
      <p>
        Sedlacek PR, Clelland JA, Knowles C, Jackson JR, Varner RE. Electrical
        conductance at auricular acupuncture points during dysmenorrhea.{" "}
        <em>Clin J Pain</em> 1988;4(3):183-90.
      </p>

      <h2 id="sec7dot8">
        7.8 Obstetrics, Labor, Pregnancy, Infertility, Impotency, Uterine
        Contractions, Post-Partum
      </h2>
      <p>
        Aleksandrina EV, Zharkin AF, Gaprova AS. The acupuncture prevention of
        anomalies in labor strength in pregnant women of a risk group.{" "}
        <em>Akush Ginekol</em> (Mosk) 1992; (8-12) : 22-4 Medline 93182741
        Journal article Russian Russia
      </p>
      <p>
        Fiches G. L’explosion du kyste de l’ovaire.{" "}
        <em>Revue d’auriculomedicine</em> no. 30 Jan 1983 Journal Article French
        France
      </p>
      <p>
        Gerhard I, Postneek F. Auricular acupuncture in the treatment of female
        infertility. <em>Gynecol Endocrinol</em> 1992 Sep; 6 (3): 171-81 Medline
        93071204 Germany. journal article English
      </p>
      <p>
        Gerhard I, Postneek F. Possibilities of therapy by ear acupuncture in
        female sterility.<em> Geburtshilfe Frauenheilkd</em> 1988 Mar;
        48(3):165-71 Medline 88225945
      </p>
      <p>
        Jin Y, Wu L, Xia Y Clinical study on painless labor under drugs combined
        with acupuncture analgesia.<em> Chen Tzu Yen Chiu</em> 1996; 21(3):9-17
        1996 3 9-17 Medline 98048580
      </p>
      <p>
        Khider Application de l’auriculotherapy en obsteteque.{" "}
        <em>Revue d’auriculomedicine</em> no. 23 Apr 1981 Journal Article French
        France
      </p>
      <p>
        Khider Conclusions actuelles sur 1’etude de l’action de
        l’auriculomedicine sur la contraction uterine au cours de la grossesse
        et de l’accouchement. <em>Revue d’auriculomedicine</em> no. 25 Oct 1981
        Journal Article French France
      </p>
      <p>
        Khider Obsteteque.<em> Revue d’auriculomedicine</em> no. 20 Jul 1980
        Journal Article France
      </p>
      <p>
        Leclerc B. Efficacite de l’auriculotherapy dans les “stefilites”
        idiopathiques. <em>Annales du G.L.E.M.</em> (1997) 21
      </p>
      <p>
        Martin J, Laval M. Amsellem et Bricot B. Kyste de l’ovaire,
        auriculomedicine et polartron unidirectionnel.{" "}
        <em>Revue d’auriculomedicine</em> no. 35 Apr 1984 Journal Article France
      </p>
      <p>
        Qin GF, Tang HJ. 413 cases of abnormal fetal position corrected by
        auricular plaster therapy. <em>J Tradit Chin Med</em> 1989 Dec; 9(4):23
        5-7 Medline 90205168
      </p>
      <p>
        Wang M. 42 cases of climacteric syndrome treated with auricular pellet
        pressure. <em>J Tradit Chin Med</em> 1991 Sep-, 11(3):196-8 Medline
        92085705
      </p>

      <h2 id="sec8dot1">8.1 General Endocrinology and Hormones</h2>
      <p>
        Delpuech JP. Les transferts melaniques.{" "}
        <em>Revue d’auriculomedicine</em> no. 27 Apr 1982 Journal Article French
        France
      </p>
      <p>
        Guo W, Zhu H. Clinical observation in treating 32 diabetic patients with
        ear-point plaster therapy. <em>Int J Clin Acupunct</em> 1993 4(l) 97-9
      </p>
      <p>
        Pepelyaev V. Auriculotherapy of thyroid gland diseases in patients
        suffeeng from Chernobyl catastroph{" "}
        <em>International J of Auricular Medicine</em> : 2nd annual conference
        of the medical society of acupunture of the Israeli Medical Association
        1995 Mozyr, Belarus Abstract de congres/Congress English
      </p>
      <p>
        Spagnotetti T., Liotti M., Tutino L., Marcucci F. Ear acupuncture and
        endocrine secretion.{" "}
        <em>Bollettino Sicieta Italiana Biologia Spermtntale</em>. 1982. Mar 15.
        58
      </p>

      <h2 id="sec8dot2">8.2 Diabetes, Pancreatitis, Hypoglycemia</h2>
      <p>
        Bobrov OE, Radzikhovskii AP, Loboda DI, Ogorodnik PV, Chmel VB,
        Ligonenko AV. Several problems of surgical treatment in acute biliary
        pancreatitis. <em>Klin Khir</em> 1991 (5) : 20-3 Medline 91342069
        Journal article Russian
      </p>
      <p>
        Solun MN, Liaifer AI. Acupuncture in the treatment of diabetic
        angiopathy of the lower extremities Probi .Endokrinol (Mosk) 1991 Jul;
        37 (4): 20-3 Medline 92158899 Journal article Russian USSR
      </p>

      <h2 id="sec8dot3">
        8.3 Thyroid Disorder, Thyroxine, Adrenal Disorder, ACTH, Cortisol
      </h2>
      <p>
        Detpuech J.P. Internt des filtres adrenaline et acetylcholine.{" "}
        <em>Revue d’auriculomedicine</em> no. 23 Apr 1981 Journal Article French
        France
      </p>
      <p>
        Nogier P, Mallard A, Petitjear F. Poliradiculonevfite: virus de la
        rougeole et hormone de croissance<em>. Revue d’auriculomedicine</em> no
        30 Jan 1983 Journal Article French
      </p>
      <p>
        Wen HL, Ho WK, Wong HK, Mehal ZD, Ng YH, Ma L. Changes in
        adrenocorticotropic hormone (ACTH) and cortisol levels in drug addicts
        treated by a new and rapid detoxification procedure using acupuncture
        and naloxone. <em>Comp Med East West</em> 1979 Vol. 6, No. 3 pp.
        241-245.
      </p>
      <p>
        Wen HL, Ho WK, Wong HK, Mehal ZD, Ng YH, Ma L. Reduction of
        adrenocorticotropic hormone (ACTH) and cortisol in drug addicts treated
        by acupuncture and electrical stimulation (AES).{" "}
        <em>Comp Med East West</em> 1978 Vol. 6, no. 1 pp. 61-66.
      </p>

      <h2 id="sec8dot4">
        8.4 Allergies, Immunity, Hypersensitivity, Anti-Inflammatory Disoirders,
        Colds, Flus, Infections
      </h2>
      <p>
        Chen Y, Hu X. Auriculo acupuncture in 15 cases of discoid lupus
        erythematosus <em>J of Tradit Chinese Medicine</em>, 1985, vol.5, no 4,
        261-262 journal article
      </p>
      <p>
        Coutte A. Auriculotherapie et maladie de Gougerot-Sjogren
        <em>
          . Annales du Premier Symposium International d’Auriculotherapy et
          d’Audculomedicine
        </em>{" "}
        Lyon France: Haug editeur Bruxelles. 27,28,29 May 1994 GLEM
      </p>
      <p>
        De Sousa A. L’allergie cutanee. <em>Revue d’auriculomedicine </em>no. 35
        Apr 1984 Journal Article French.
      </p>
      <p>
        Flament C. L’allergie au sucre. <em>Revue d’auriculomedicine </em>no. 31
        Apr 1983 Journal Article French
      </p>
      <p>
        Flament C. L’allergie au sucre (resume).{" "}
        <em>Revue d’auriculomedicine </em>no. 29 Oct 1982 Journal Article French
        France.
      </p>
      <p>
        Julienne B, Mallard A. Allergies, intolerance et toxicite alimentaires.{" "}
        <em>Annales du G.L.E.M</em>. (1998)
      </p>
      <p>
        Julienne B; Mallard A. Auriculomedecine, intolerance, allergie et
        toxicite alimentaires.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine</em> no 4 Novembre
        l997 Brochure French France
      </p>
      <p>
        Kenyon JN, Lewith GT. The auriculo-cardiac reflex as a diagnostic method
        for food and chemical allergy testing<em>. Amer J of Acupuncture</em>{" "}
        July September, 1982 Vol. 10 pages 239-243
      </p>
      <p>
        Lebel M. The importance of identifying food / substance intolerance in
        auriculomedicine
        <em>
          . Annales du Premier Symposium International d’Audculotherapie et
          d’Auriculomedicine
        </em>{" "}
        Lyon France: 27,28,29 May 1994 GLEM
      </p>
      <p>
        Ma XP. Regulatory action of needle-embedding at auricular points on
        serum lipids in hyperlipidemia<em>. Int J Clin Acupunct</em> 1994 5(3)
        267-72.
      </p>
      <p>
        Nogier P. Un cas d’allergie extraordinaire (suite).{" "}
        <em>Revue d’auriculomedicine </em>no. 12 Jul 1978 Journal Article French
        France..
      </p>
      <p>
        Nogier P. Un cas d’allergie extraordinaire.{" "}
        <em>Revue d’auriculomedicine </em>no. 8 Jul 1977 Journal Article French
        France .
      </p>
      <p>
        Nogier R. Les intoldrances au laitage chez I’adulte.{" "}
        <em>Bulletin Scientifique du GLEM</em> n’l nov 1988 GLEM Journal Article
        French
      </p>
      <p>
        Razafitsalama D. Zona. <em>Revue d’auriculomidecine</em> no. 31 Apr 1983
        Journal Article French France
      </p>
      <p>
        Schneider R. Zona. <em>Revue d’auriculomddecine</em> no. 31 Apr 1983
        Journal Article France
      </p>
      <p>
        Vasilenko AM, Kirilina EA, Sarybaeva DV. Prevention and correction of
        stress-induced immunodeficiency by atrial electroacupuncture.{" "}
        <em>Patol Fiziol Eksp Ter</em> 1989 May; (3):2 14 Medline 90016446
        Journal article Russian USSR
      </p>
      <p>
        Vulliez C. Les risques allergiques et toxiques de l’utilisation des
        metaux en bouche. <em>Annales du G.L.E.M</em>. (1995)
      </p>

      <h2 id="sec8dot5">8.5 Cancer, Oncology</h2>
      <p>
        Alimi D. Analyse ouverte de 20 dossiers de patients, suivis et traites
        (pour des douleurs sequellaires post neoplasiques) par.
        Auriculotherapie, <em>J of Pain and Symptom Management</em> Rev 2000
        Journal Article English
      </p>
      <p>
        Aung SH. Clinical use of auricular acupuncture in oncology
        <em>
          . Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000
      </p>
      <p>
        Brule FS. Treatment of chronic cancer pain. Contribution of acupuncture,
        auriculotherapy and mesotherapy. <em>Soins</em> 1993 Jan; (568):3 9-40
        Soins. Medline 94135350 Journal article French.
      </p>
      <p>
        Delpuech JP. Le filtre tumoral: reactions auriculaires de terrain.{" "}
        <em>Revue d’auriculomedicine</em> no. 28 Jul 1982 JournalAilicle French
        France
      </p>
      <p>
        Nogier P. A propos du diagnostic et du traitement du terrain cancereux
        en auriculomedicine. <em>Revue d’auriculomedicine</em> no. 27 Apr 1982
        Journal Article French France
      </p>
      <p>
        Nogier P. L’auriculo-medecine peut-elle apporter une solution au
        diagnostic precoce du cancer? <em>Revue d’auriculomedicine</em> no 16
        Jul 1979 Journal Article France
      </p>
      <p>
        Nogier P. Tests nouveaux concemant le cancer.{" "}
        <em>Revue d’auriculomedicine</em> no. 27 Apr 1982 Journal Article France
      </p>
      <p>
        Park F, Jakub D, Matulova M, Schreiber M. Cervical spine blockage
        auriculopressure first aid. Peripheral palsy of n. facialis
        electromyography suitable length of acupuncture treatment.
      </p>
      <p>
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM English
      </p>
      <p>
        Riviere A. Place de l’auriculomedicine dans le suivi de la maladie
        cancereuse
        <em>
          . Annales du Premier Symposium International d’Auriculotherapy et
          d’Audculomedicine
        </em>{" "}
        Lyon France 27,28,29 May 1994 GLEM
      </p>
      <p>
        Saussus E. Action de l’auriculotherapie sur les douleurs terminates dun
        cancereux. <em>Revue d’auriculomedicine </em>no. 6 Jan 1977 Journal
        Article French France
      </p>
      <p>
        Secondy A. Auriculo-medecine et diagnostic du cancer.{" "}
        <em>Revue d’auriculiomedecine</em> no. 18 Jan 1980 Journal Article
        French France
      </p>
      <p>
        Secondy A. Auriculo-medicine et diagnostic du cancer.{" "}
        <em>Revue d’auriculomedicine </em>no. 18 Jan 1980 Journal Article French
        France
      </p>
      <p>
        Secondy A. Protocole d’examen pour un diagnostic du cancer en double
        aveugle. <em>Revue d’auriculomedicine</em> no. 9 Oct 1977 Journal
        Article French France
      </p>

      <h2 id="sec9dot1">9.1 Veterinary Acupuncture and Animal Studies</h2>
      <p>
        Alimi D. Le halo vital hypotheses chronobiologioues
        <em>
          . Annates du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France : 27,28,29 May 1994 GLEM French
      </p>
      <p>
        Auriculodiagnosis of acute diarrhoea in the dog an experimental study
        <em>. International J of Auricular Medicine</em> (IJAM)
      </p>
      <p>
        Braemer C. L’application de l’auriculomedicine en medicine veten’naire
        et pour la protection des plantes.{" "}
        <em>
          Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France : 27,28,29 May 1994 GLEM
      </p>
      <p>
        Kruger C. Localisation des points auriculaires et premieres experiences
        d’auriculotherapy en medicine vetefinaire.{" "}
        <em>Revue d’auriculomedicine</em> no. 20 Jul 1980 Journal Article French
        Maisonneuve France
      </p>
      <p>
        Li Y, Tang X, Zhang Y, Wu F. The effect of stimulating the auricular
        liver-gall acupoint with electrode on synaptic.of nucleus originis
        dorsalis nervi vagi in rabbits. <em>Chen Tzu Yen Chiu</em> 1992-
        17(3):201-6 Journal article Chinese China
      </p>
      <p>
        Lubbe AM. Comment on auriculotherapy in canine thoracolumbar disc
        disease [letter; comment]. <em>J S Afr Vet Assoc</em> 1990 Dec;
        61(4)-187 Medline 97193519
      </p>
      <p>
        Navach JH. Accelerated healing of fractures in horses by electromagnetic
        stimulation.
      </p>
      <p>
        Navach JH. Accelerated healing of surgical fractures in cattle by
        electromagnetic stimulation.
      </p>
      <p>
        Navach JH. Animal models demonstrating electromagnetic effects upon
        vertebrate animals utilizing rodents
        <em>. International Congress of Acupuncture and Applied Techniques</em>,
        Sorrento, Italy September 10, 1982
      </p>
      <p>
        Nogier P; Corcelle J. Recherches sur le lapin. Travaux du GLEM a l’ITERC{" "}
        <em>Revue d’auriculomedicine</em> no. 3 Apr 76 Journal Article France
      </p>
      <p>
        Nogier PA, Corcelle J, Cahn MB. Experiences sur le lapin i l’institut de
        therapeutique experimentale et de recherches cliniques (ITERC).{" "}
        <em>Revue d’auriculomedicine</em> no. 18 Jan 1980 Journal Article French
        France
      </p>
      <p>
        Nogier R, Nogier P, C1ement G. Recherche d’eventuelles modifications de
        la transmission d’influx somesthesiques sous 1’effet dune stimulation de
        la peau chez le lapin vigile. <em>Revue d’auriculomedicine</em> no. 34
        Jan 1984 Journal Article French France
      </p>
      <p>
        Nogier R, Nogier P, Santini R, Menezo Y, Khatchadoufian C. Influence de
        l’illumination de la peau sur les agnes biogenes du plasma chez le
        lapin. Revue d’auriculomedicine no. 29 Oct 1982 Journal Article French
        France
      </p>
      <p>
        Nogier R, Santini R, Menezo Y. VAS. Stimulation lumineuses cutanees chez
        le lapin. Leur influence sur les taux d’amines vasopressives
        plasmatiques. <em>Revue d’auriculomedicine</em> no. 25 Oct 1981 Journal
        Article French France
      </p>
      <p>
        Panzer RB, Chrisman CL. An auricular acupuncture treatment for
        idiopathic canine epilepsy: a preliminary report.{" "}
        <em>Amer J Chin Med</em> 1994; 22 (i): 11-7. Journal article English
        United States
      </p>
      <p>
        Portnov FG. Electro auriculo puncture diagnosis and therapy.{" "}
        <em>World Conference on Acupuncture Moxibustion, Paris</em>, 1990, 39
        English
      </p>
      <p>
        Still J. A clinical study of auriculotherapy in canine thoracolumbar
        disc disease [see comments].<em> J S Afr Vet Assoc</em> 1990
        Sep-,61(3):102-5 English
      </p>
      <p>
        Still J. Auriculotherapy and canine thoracolumbar disc disease [letter].{" "}
        <em>J S Afr Vet Assoc</em> 1991 Mar; 62 (l): 3 J Medline 91269263
        English
      </p>
      <p>
        Still J. Role of the nervous system in the appearance of the ear
        acupuncture points in the dog<em>. Acta Vet.</em> Brno Mar-Jun, 1986
        Vol. 55, No. 2 pp. 55-64
      </p>
      <p>
        Still J. Veterinary ear acupuncture.{" "}
        <em>J of Auricular Medicine and Acupuncture</em>. 1994. No. l2-14. 9.1.A
      </p>
      <p>
        Xu GS, Liu WZ. Double phasic modulatory effects of auricular point
        electroacupuncture on gastrointestinal electric activity in rabbits.{" "}
        <em>Chung Hsi I Chieh Ho Tsa Chih</em> 1988 Nov; 8 (11): 671-3, 646
        Medline 89275348 <strong> </strong>
      </p>

      <p>
        Zhang Y, Li Y, Tang X, Ji C, Chen L. The effect of stimulating the
        auricular liver-gall point on the size of gallbladder of the rabbit.{" "}
        <em>Chen Tzu Yen Chiu</em> 1993, 18 (l):7 3-4 Journal article Chinese
        China
      </p>
      <p>
        Zhang Y, Yang K, Yu X, Zhang H, Ye X,Tian J. A study on the effect of
        stimulating auricular points on the biliary tract.{" "}
        <em>Chen Tzu Yen Chiu</em> 1992; 17 (l): 39-41 Medline 93008907 Journal
        article Chinese China
      </p>

      <h2 id="sec9dot2">
        9.2 Experimental Pain Threshold and Induced Physical Symptoms
      </h2>
      <p>
        Ceccherelli F, Gagliardi G, Seda R, Giron G. Ear acupuncture and pain
        threshold animal and human experimentation.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM.
      </p>
      <p>
        Ceffa GC, Chio C, Gandini G. Muscular tensions of the back studied with
        telethermography- changes induced with static measures and auricular
        acupuncture. preliminary report. <em>Minerva Med</em> 1980 Mar-, 71
        (12): 899-903 Medline 80188676 Journal article Italian Italy
      </p>
      <p>
        Dolgikh VG, Reshetniak VK. Changes in the jaw-opening reflex during
        anesthesia resulting from auricular electrostimulation.{" "}
        <em>Biull Eksp Biol Med</em> 1987 May-, 103 (5) 520-1 1987 Medline
        87242815
      </p>
      <p>
        Johnson MI, Hajela VK, Ashton CH, Thompson JW. The effects of auricular
        transcutaneous electrical nerve stimulation (TENS) on experimental pain
        threshold and autonomic function in healthy subjects. <em>Pain</em> 1991
        46 (3) 337-42.
      </p>
      <p>
        King CE, Clelland JA, Knowles CJ, Jackson JR. Effect of helium-neon
        laser auriculotherapy on experimental pain threshold. <em>Phys Ther</em>{" "}
        1990 Jan;70 (1):24-30 Medline 90099590 Journal Article Randomized
        Controlled Trial English
      </p>
      <p>
        Krause AW, Clelland JA, Knowles CJ, Jackson JR. Effects of unilateral
        and bilateral auricular transcutaneous electrical nerve stimulation on
        cutaneous pain threshold. <em>Phys Ther</em> 1987 Apr; 67(4):507-11 1987
        Apr 4 507-11 Medline 87175904 Clinical Trial; Journal Article;
        Randomized Controlled Trial English United States
      </p>
      <p>
        Lein DH, Clelland JA, Knowles CJ, Jackson JR. Comparison of effects of
        transcutaneous electrical nerve stimulation of auricular, somatic, and
        the combination of auricular and somatic acupuncture points on
        experimental pain threshold [see comments] <em>Phys Ther</em> 1989 Aug-,
        69 (8):671-8 Medline 89316043 Journal Article- Randomized Controlled
        Trial English
      </p>
      <p>
        Longobardi AG, Clelland JA, Knowles CJ, Jackson JR. Effects of auricular
        transcutaneous electrical nerve stimulation on distal extremity pain: a
        pilot study. <em>Phys Ther</em> 1989 Jan 69 (l): 10-7 Medline 89099340
        Randomized Controlled Trial, English.
      </p>
      <p>
        Moskovets ON. Effect of auricular electroacupuncture on the motor
        manifestations of nociceptive reactions. <em>Biull Eksp Biol Med</em>{" "}
        1980 Apr; 89(4):401-3 Medline 80221439
      </p>
      <p>
        Noling LB, Clelland JA, Jackson JR, Knowles CJ. Effect of transcutaneous
        electrical nerve stimulation at auricular points on experimental
        cutaneous pain threshold <em>Phys Ther</em> 1988 Jul, 68 (7): 1145
        Medline 88158257 Journal article; Randomized Controlled Trial English
      </p>
      <p>
        Oliveri AC, Clelland JA, Jackson J, Knowles C. Effects of auricular
        transcutaneous electrical nerve stimulation on experimental pain
        threshold. <em>Phys Ther</em> 1986 66(l) Jan 1 12-6 Medline 86094707
        Journal article; Randomized Controlled Trial English United States
      </p>
      <p>
        Rabischong et al. <em>Experimental basis of acupuncture analgesia</em>.
        La Nouvelle Presse Medicale T4-no. 28 sept 1975 Sept 1975 French
      </p>
      <p>
        Tekeoglu I, Adak B, Ercan M. Suppression of experimental pain by
        auriculopressure. <em>Acupuncture in Medicine</em> May 1996.
      </p>

      <h2 id="sec9dot3">
        9.3 Endorphin Release, Enkephalins, Dynorphins, Naloxone Reversal,
        Angiotensin, Substance P
      </h2>
      <p>
        Blum K, Briggs AH, Trachtenberg MC, Delailo L, Wallace JE. Enkephalinase
        inhibition: regulation of ethanol intake in genetically predisposed
        mice. <em>Alcohol</em> 1987 Nov Dec;4 (6) 449-56.
      </p>
      <p>
        Bragin EO, Dionne R, Ng L, Moody T, Pert K. Changes in the content of
        opiate-like substances in auricular electroacupuncture anesthesia of
        rats. <em>Vopr Med Khim</em> 1982 Jul; 28(4):102-5 Medline 82279124
        Journal article Russian USSR
      </p>
      <p>
        Fedoseeva OV, Kalyuzhnyi LV. New peptide mechanism of
        auriculo-acupuncture electro-analgesia: role of angiotensin II,
        angiotensin. <em>Acupuncture and Electro Therapeutics Research</em>,
        1990,vol.15,no l,1-8,15 English
      </p>
      <p>
        Kaliuzhnyi LV, et al; Angiotensin mechanism of auriculo-acupuncture
        dental analgesia. <em>Biull Eksp Biol Med</em>, 1990 Jul [Medline
        Abstract] .
      </p>
      <p>
        Kaliuzhnyi LV, Kozlov A. Action of an enkephalinase blocker on the
        effect of acupuncture in acupuncture sensitive and resistant rabbits.{" "}
        <em>Biull Eksp Biol Med</em>, 1991 Dec, 1 12:12, 571-3 Medline Journal
        article Russian/Russe USSR
      </p>
      <p>
        Masala A, Satta G, Alagna S, Zolo TA, Rovasio PP, Rassu S. Suppression
        of electroacupuncture (EA)-induced beta-endorphin and ACTH release by
        hydrocortisone in man. Absence of effects on EA-induced anaesthesia.{" "}
        <em>Acta Endocrinol</em> (Copenh) 1983 Aug; 103(4):469-72 Medline
        83304735 English
      </p>
      <p>
        Ng LK, Douthitt TC, Thoa NB, Albert CA. Modification of
        morphine-withdrawal syndrome in rats following transauricular
        electrostimulation: an experimental paradigm for auricular
        electroacupuncture. <em>Biol Psychiatry</em> 1975 Oct; 10 (5): 575-80
        Medline 76040277 Journal article English United States
      </p>
      <p>
        Ng LK, Thoa NG, Douthitt TC, Albert CA. Experimental auricular
        electroacupuncture in morphinedependent rats: behavioral and biochemical
        observations. <em>Amer J Chin Med</em> 1975 Oct, 3 (4): 335-41 Medline
        76085186 Journal article English United States
      </p>
      <p>
        Ng LK. Auricular acupuncture in animals: effects of opiate withdrawal
        and involvement of endorphins. <em>J Altem Complement Med</em> 1996 Spr;
        2 (l): 61-3 Medline 98051827
      </p>
      <p>
        Pert A, Dionne R, Ng L, Bragin E, Moody TW, Pert CB. Alterations in rat
        central nervous system endorphins foflowing transauricular
        electroacupuncture. <em>Brain Research </em>1981 Nov-, 224(l):83-93
        Medline 82025011 Journal article English Netherlands
      </p>
      <p>
        Raevskaia OS, Grishanin GG. Effects of auricular electrostimulation and
        naloxone on nociceptive sensitivity in rabbits.{" "}
        <em>Biull Eksp Biol Med</em> 1990 Oct; 110(10):339-41 Medline 91120892
        Journal article Russian USSR
      </p>
      <p>
        Raevskaia OS. Nociceptive sensitivity of rabbits in varying localization
        of pain stimuli and naloxone administration.{" "}
        <em>Patol Fiziol Eksp Ter</em> 1992 Sep- (5-6):7-9 Medline 93261751
        Journal article Russian
      </p>
      <p>
        Simmons MS, Oleson TD. Auricular electrical stimulation and dental pain
        threshold. <em>Anesth Prog</em> 1993; 40(l):149 Medline 94241429 Journal
        article; Randomized Controlled Trial English United States
      </p>
      <p>
        Wen HL, Ho WK, Ling N, et al. Immunoassayable beta-endorphin level in
        the plasma and CSF of heroin addicted and normal subjects before and
        after electroacupuncture. <em>Amer J of Chinese Medicine</em> 1980 Vol.
        8, no. 1-2 pp. 154-159.
      </p>
      <p>
        Wen HL, Ng YH, et al. Acupuncture in narcotic withdrawal: a preliminary
        report on biochemical changes in the blood and urine of heroin.{" "}
        <em>Addicts Bulletin on Narcotics</em> 1970 Vol. XXII, no. 9 pp. 31-39.
      </p>
      <p>
        Wen HL, Ng YH, Ho WK, Fun KP, Wong HK, Ma L, Wong HC. Acupuncture in
        narcotic withdrawal: a preliminary report on biochemical changes in the
        blood and urine of heroin addicts. <em>Bulletin of Narcotics</em>{" "}
        Apr-June 1978 Vol. 30, no.2 pp. 31-39.
      </p>

      <h2 id="sec9dot4">
        9.4 Body Physiology, Biochemistry, Neuroanatomical Studies, Neuron
        Firing Activity
      </h2>
      <p>
        Asamoto S, Takeshige C. Activation of the satiety center by auricular
        acupuncture point stimulation. <em>Brain Res Bull</em> 1992 Aug 2 157-64
        Medline 92404933 Tokyo, Japan. Journal article English United States
      </p>
      <p>
        Bossy J, Golewshi G. Maurel JC, Seoane M. Innervation and
        vascularization of the auricular correlate with the loci of the
        auriculotherapy. <em>Acupunture electro ther Res</em>. Int. J., 2 (1977)
        247- 257
      </p>
      <p>
        Bossy J. Anatomical and embryological considerations on the human
        auricula.{" "}
        <em>
          Annales du Premier Symposium International d’Auriculotherapie et
          d’Auriculomedecine
        </em>{" "}
        Lyon France 27,28,29 May 1994 GLEM
      </p>
      <p>
        Bossy J. Anatomie comparee de l’oreille externe.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 French GLEM
      </p>
      <p>
        Bossy J. <em>Le rameau auriiculaire du X distribution, trajet</em>.
        1958. Book French
      </p>
      <p>
        Bossy J. <em>Schemas de neuro-anatomie vigot</em>. editeur, 1965. Book
        French
      </p>
      <p>
        Bourdiol RJ. <em>Hypotheses neuro-anatomiques en auriculotherapie</em>.
        Lyon Medical, 1972. French
      </p>
      <p>
        Bourdiol RJ. La projection des nerfs craniens sur l’auricule.{" "}
        <em>Revue d’auriculomedicine</em> no 5 Oct 1976 Journal Article French
        France
      </p>
      <p>
        Bourdiol RJ. Le para-sympathique. <em>Revue d’auriculomedicine</em> no 3
        Apr 1976 Journal Article French France
      </p>
      <p>
        Bourdiol RJ. Le systeme nerveux central en auriculo-medecine (a suivre).{" "}
        <em>Revue d’auriculomedicine</em> no 6 Jan 1977 Journal Article French
        France
      </p>
      <p>
        Bourdiol RJ. Le systeme nerveux central en auriculo-medecine (suite).{" "}
        <em>Revue d’auriculomedicine</em> no 7 Apr 1977 Journal Article French
        France
      </p>
      <p>
        Bourdiol RJ. Le systeme nerveux central en auriculo-medicine (suite).{" "}
        <em>Revue d’auriculomedicine</em> no 8 Jul 1977 JournalArticle French
        France
      </p>
      <p>
        Bourdiol RJ. Le tragus. <em>Journees Gennano-Latines</em>– Lyon, 1976.
        1976. French
      </p>
      <p>
        Bourdiol RJ. Les plexus. <em>Revue d’auriculomedicine</em> no 4 Jul 1976
        Journal Article French France
      </p>
      <p>
        Bragin E, Batueva NN, Monaenkov KA. Role of catecholamine neurons in the
        reticular lateral nuclei in regulating sensitivity to pain during
        exposure to reflex stimuli. <em>Biull Eksp Biol Med</em> 1983 May;
        95(5):19-21 Medline 83205236 Journal article Russian
      </p>
      <p>
        Bragin E, Batueva NN, Vasilenko GF. Role of giant cell nuclei of the
        reticular formation in mechanisms of analgesia during auricular
        electroacupuncture and action of morphine <em>Biull Eksp Biol Med</em>{" "}
        1988 Oct; 106 (10):390-2 Medline 89051174 Russian
      </p>
      <p>
        Bragin E, Vasilenko GF, Batueva NN, Belitskaia RA, Shumova OV. The role
        of catecholaminergic group A5 neurons in analgesia induced by auricular
        electroacupuncture and in electrodermal pain stimulation.{" "}
        <em>Biull Eksp Biol Med</em> 1989 Mar; 107(3):310-2 Medline 89229335
        Russian
      </p>
      <p>
        Bragin E, Vasilenko GF, Durinjan RA. The study of the central grey
        matter in mechanisms of different kinds of analgesia: effects of
        lesions. <em>Pain</em> 1983 May; 16 (l): 33-40 Medline 83246133 Journal
        article English Netherlands
      </p>
      <p>
        Bragin EO, Batueva NN, Durinian RA. Role of the somatic monoaminergic
        systems in the mechanisms of regulation of pain sensitivity during
        reflex stimulation. <em>Biull Eksp Biol Med</em> 1983 Oct; 96(10):9-12
        Medline 84025020 Journal article Russian USSR
      </p>
      <p>
        Bricot B. Etude de 1’efficacite du traitement des zones de projection
        des commissures interhemispheriques dans les troubles de 1’equilibre et
        objectivation en stabilometrie.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 French
      </p>
      <p>
        Bucek R.{" "}
        <em>
          Lehrbuch der ohrakupunktur: eine synopsis der franzesischen,
          chinesischen und russischen schulen
        </em>
        . Heidelberg- Haug. 1994 book
      </p>
      <p>
        Cho HM.{" "}
        <em>
          Methode physiologlque simple pour isoler ]es points de correspondences
          somatiques de I’ oreille exteme et applications cliniques journees
          germano latines
        </em>
        . Lyon, 1978. 1978. French
      </p>
      <p>
        Dung HC. Acupuncture points of the cervical plexus.{" "}
        <em>Amer J Chin Med</em> 1984 Sum- 12 (1-4):94-105 1984 Sum 1-4 94-105
        Medline 85043663 Journal article English United States
      </p>
      <p>
        Dvorkin E, Malinovsky L, Hanzlova J, Mayer I, Felman G, Dubinsky G. Does
        an auricular point have it’s own morphological substratum?{" "}
        <em>Coherence</em> 1998 : The 2nd international IAAMER congress on:
        auricular diagnostics &amp; therapy September 19-21, 1997 Oisterwijk
      </p>
      <p>
        Gonzalo LM, Rotinen S.{" "}
        <em>Descending projections from the first three myelomeres.</em>
      </p>
      <p>
        9.4 _ Han J S. Physiology of acupuncture: review of thirty years of
        research. <em>J of Alternative and Complementary Medicine</em> 1997 Vol.
        3, Supplement I pp. SIOI-SIO8.
      </p>
      <p>
        Heine H. Anatomic der ohrakupuncturpunkte.{" "}
        <em>
          Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France. 27,28,29 May 1994 GLEM French <strong>Abstract</strong>
      </p>
      <p>
        Imanishi N, Nakajima H Aiso S. Arterial anatomy of the ear.{" "}
        <em>Okajimas Folia Anat Jpn</em> 1997 Mar- 73(6)-313-23{" "}
        <strong>Abstract </strong>
      </p>
      <p>
        Ishibashi S. The effect of auricular electroacupuncture on the neuronal
        activity of the thalamic and hypothalamic neurons of the rat.{" "}
        <em>Acupuncture and Electro Therapeutics Research</em>, 1986,Vol. 11, no
        1, 15-23, 20r Medline Japan 813 Journal article United States
      </p>
      <p>
        Julienne B, Mallard A. Centres fonctionnels sagittaux.{" "}
        <em>Fascicule du Cours Superieur d’Auriculomedecine</em>. no. I Oct 1996
        GLEM French
      </p>
      <p>
        Khramov RN Karpuk NI Vorobev VV Galchenko AA Kosarskii LS. The
        electrical activity of the hypothalamus in exposure to millimeter-wave
        radiation at biologically active points<em>. Biull Eksp Biol Med</em>{" "}
        1993 Sep; 116 (9) 263-5 Medline 94162581 Journal article Russian Russia
      </p>
      <p>
        Lentz A. Neuromediateurs et modcies de circulation d’energie
        <em>
          . Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France. 27,28,29 May 1994 GLEM French
      </p>
      <p>
        Magnin P. Le systeme limbique et l’integration de l’information.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine 2000
        </em>{" "}
        Lyon France 26,27,28 May 2000 GLEM French
      </p>
      <p>
        Magnin P. Paleancephale et systeme limbique.{" "}
        <em>Fascicule du Cours Supefieur d’auriculomedecine </em>no. 3 May 1997
        Brochure French France
      </p>
      <p>
        Malinovsky L, Dvorkin E, Hanzlova J, Mayer I, Malinovska V, Dubinsky G,
        D’Andrea V. Ultrastructure of the thalamic representation in the human
        auricle<em>. International J of Auricular Medicine</em> (IJAM) ISSN
        0793-3150 1/96
      </p>
      <p>
        Mallard A, Petitjean F. A propos des commissures interhemispheriques.{" "}
        <em>Revue d’auriculomedicine</em> no. 35 Apr 1984 Journal Article French
        France
      </p>
      <p>
        Mallard A, Petitjean F. Les commissures interhemispheriques en
        auriculomedecine. <em>Revue d’auriculomedicine</em> no. 34 Jan 1984
        Journal Article French France
      </p>
      <p>
        Meizerov EE, Reshetniak VK Dudnian RA. Reflex suppression of evoked
        nociceptive responses in the parafascicular complex and posterior
        ventromedial nucleus of the thalamus in cats during electroacupuncture
        <em>. Biull Eksp Biol Med</em> 1981 Aug; 92 (6):12-4 Medline 82047175
        Journal article Russian USSR
      </p>
      <p>
        Moskovets ON, Reshetniak VK, Durinian RA. Electroacupuncture inhibition
        of nociceptive responses in the caudal trigeminal nucleus.{" "}
        <em>Biull Eksp Biol Med</em> 1980; 89 (l):7-9 Medline 80198784 Journal
        article Russian
      </p>
      <p>
        Navach JH. Electromagnetic field mappings of the primate thalamus.{" "}
        <em>Nogier Seminar</em>, Montreal, Quebec October, 1984
      </p>
      <p>
        Nogier P. Mal des transports et mal des montagnes, action
        neuro-vegetative de l’hypothalamus<em>. Revue d’auriculomedicine</em>{" "}
        no. 19 Apr 1980 JournalArticle French France
      </p>
      <p>
        Reshetniak VK, Chuvin BT. Modulating effect of electric acupuncture
        stimulation on the bioelectdcal activity of neurons of specific and
        nonspecific thalamic nuclei. <em>Biull Eksp Biol Med</em> 1986 May-,
        101(5):515-7 Medline 86216564 Journal article Russian USSR
      </p>
      <p>
        Reshetniak VK, Meizerov EE, Durinian RA. Effect of electroacupuncture on
        the integration of nociceptor and non-nociceptor afferent pathways in
        the second somatosensory cortex of the cerebral hemisphere{" "}
        <em>Biull Eksp Biol Med</em> 1982 Mar; 93 (3): 11-3 Medline 82232431
        Journal article Russian USSR
      </p>
      <p>
        Reshetniak VK, Meizerov EE, Durinian RA. Reflex changes in the function
        of the cerebral cortex and central gray matter after electroacupuncture.{" "}
        <em>Biull Eksp Biol Med</em> 1982 Mar; 93(3):5-7 Medline 82232456
        Journal article Russian USSR
      </p>
      <p>
        Rotinen SJ.{" "}
        <em>
          Conexiones espinales de la pars caudalis del nucleo espinal del
          trigemino.
        </em>{" "}
        Tesis doctoral
      </p>
      <p>
        Shiraishi T, Onoe M, Kojima T, Sameshima Y, Kageyama T. Effects of
        auricular stimulation on feeding-related hypothalamic neuronal activity
        in normal and obese rats. <em>Brain Res Bull</em> 1995;36(2):141-8
        Medline 95202488 Department of Neurophysiology, Tokai University School
        of Medicine, Kanagawa, Japan. Journal article
      </p>
      <p>
        Shiraishi T. Electrophysiological study of auriculotherapy- effects of
        auricle stimulation on the feeding related hypothalamic neuronal
        activity in normal and obese rats.{" "}
        <em>
          Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France : 27,28,29 May 1994 GLEM French
      </p>
      <p>
        Troshin OV. A clinico-neurophysiological analysis of the single action
        of laser puncture. <em>Lik Sprava</em> 1994 May; (5-6):148-53 Medline
        95133274 Russian
      </p>
      <p>
        Zhu B, Wang Y, Xu W. Effect of electroacupuncture on peripheral
        microcirculation in acute experimental arthritic rats.{" "}
        <em>Chen Tzu Yen Chiu</em> 1993; 18 (3): 219-22 Journal article Chinese
        China
      </p>
      <p>
        Zhu YG, Ye YY, Mo YW. The effect of electroacupuncture on the visceral
        auricular point response in rabbits Chen Tzu Yen Chiu 1986;
        11(3):234-40, 180 Medline 87131605 Clinical, theorical and fondamental
        research
      </p>

      <h2 id="sec9dot5">
        9.5 EEG, Evoked Potentials, MRI Scans, PET Scans, SPECT
      </h2>
      <p>
        Ackerman JM. A follow up of the vascular autonomic response using the
        electroencephalogram. <em>Congres de Natal</em> 1997 Site internet du
        GLEM
      </p>
      <p>
        Ackerman JM. A study of the vascular autonomic response using the
        electroencephalogram.{" "}
        <em>
          Symposium International of Auriculo-Therapy and Auriculo-Medicine
        </em>
        , Haug International, Bruxells, 1994 page 24.
      </p>
      <p>
        Ackerman JM. A study of the vascular autonomic response using the
        electroencephalograms
        <em>
          . Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France: 27,28,29 May 1994 GLEM
      </p>
      <p>
        Alimi D. Essai de la stimulation auriculaire sur l’imagerie cerebrale
        recueillie par I.R.M. fonctionnelle.{" "}
        <em>
          Annales du Troisieme Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        2000 Lyon France 26,27,28 May 2000 GLEM French
      </p>
      <p>
        Caracausi SR, Lorenzini R, Pilloni C, Tognali F, Sciaretta G. Spectrum
        analysis of the electroencephalogrAmer during electrohypoalgesia
        (combined with electroacupuncture) and pharmacological anesthesia.{" "}
        <em>Minerva Med </em>1981 Sep 15;72 (33) 2209-14 Italian .
      </p>
      <p>
        Garkavenko VV, Vashchenko EA, Limanskii IP. Changes in somatosensory
        evoked potentials in patients with vertebrogenic pain syndromes treated
        by electroacupuncture. <em>Fiziol Zh</em> 1989 May; 35 (3): 12-6 Medline
        89290069 Journal article Russian
      </p>
      <p>
        Liao TJ, Nakanishi H, Nishikawa H. The effect of acupuncture stimulation
        of the middle latency auditory evoked potential.{" "}
        <em>Tohoku J Exp Med</em> 1993 Jun; 170(2):103-12 Medline 94090603
        Japan. Journal article English Japan
      </p>
      <p>
        Nogier PM. <em>Projections viscerales de la conque</em>. Joumees de
        Besangon, 1970.. French
      </p>
      <p>
        Pilloni C, Caracausi RS, Tognali F, Sbarbaro V. EEG evaluation of
        patients undergoing extracorporeal circulation under analgesic and
        electrohypoalgesia with auricular acupuncture.{" "}
        <em>Minerva Anestesiol</em> 1980 Mar; 46(3)-3 71-86 Medline 81075497
        Italian
      </p>
      <p>
        Vigneron JL. Messages conscients et inconscients: detection i la pointe
        noire
        <em>
          . Annales du Premier Symposium International d’Auriculotherapy et
          d’Auriculomedicine
        </em>{" "}
        Lyon France GLEM
      </p>
      <p>
        Wen HL, Lai SW, Wen DY, Ho WK. Changes of cortical somatosensory evoked
        potential by acupuncture. <em>Amer J of Acupuncture </em>July-September,
        1988, Vol. 16, No. 3 p. 255-261
      </p>
    </Article>
  );
};

export default ArticleInternationalAcupunctureBibliography;
